package com.dlsm.controller;


import com.dlsm.model.AjaxResult;
import com.dlsm.model.export.ActivityDTO;
import com.dlsm.model.export.XfzbDTO;
import com.dlsm.model.vo.ActivityVO;
import com.dlsm.model.vo.CustomQuery;
import com.dlsm.model.vo.MatterQuery;
import com.dlsm.model.vo.ZdyQuery;
import com.dlsm.service.ActivityService;
import com.dlsm.service.MatterService;
import com.dlsm.utils.AhrdUitls;
import com.dlsm.utils.ExcelUtil;
import com.dlsm.utils.Result;
import com.dlsm.utils.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.lang.reflect.Field;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.*;

/**
 * 活动管理controller
 *
 * @author xunfeng
 * @date 2022-03-02
 */
@CrossOrigin
@Controller
@RequestMapping("/ahrd/activity")
public class ActivityController {

    @Autowired
    private ActivityService activityService;

    @Autowired
    private MatterService matterService;

    /**
     *  查询信访总量分析
     */
    @CrossOrigin
    @GetMapping("/petitionLetterGrossAnalyse")
    @ResponseBody
    public Result petitionLetterGrossAnalyse(String userId,String deptIdList,String startTime,String endTime ) throws ParseException {
        Map<String, Object> map = activityService.petitionLetterGrossAnalyse(deptIdList,userId,startTime,endTime);
        Result<Map<String,Object>> objectResult = new Result<>();
        objectResult.setData(map);
        return objectResult;
    }

    @CrossOrigin(origins = "*", maxAge = 3600)
    @PostMapping("/excel")
    public AjaxResult excludeExcel(HttpServletResponse response, @RequestParam(value = "merge",required = false) List<String> merge, @RequestParam(value = "alone",required = false)List<String> alone ){
        List<ActivityDTO> list = activityService.selectByActivityDtoToExport(new ActivityVO());
        //添加序号
        Integer a = 1;
        for (int i = 0; i < list.size(); i++) {
            if(i > 0 ){
                if(!(list.get(i).getId()).equals(list.get(i-1).getId())){
                    a++;
                }
                list.get(i).setNumber(a.toString());
            }else {
                list.get(i).setNumber(a.toString());
            }
        }
        if(alone != null && alone.indexOf("abstract") != -1){
            alone.add("matterAbstract");
        }
        ExcelUtil.excludeOrIncludeWrite(response, list, ActivityDTO.class, merge, alone);
        return AjaxResult.success();
    }

    /**
     *    导出-信访指标统计表
     * @param response
     * @param activityVO
     * @return
     * @throws ParseException
     */
    @CrossOrigin(origins = "*", maxAge = 3600)
    @PostMapping("/xfzbExcel")
    public AjaxResult excludeExcelXfzb( HttpServletResponse response, ActivityVO  activityVO,String orgName) throws ParseException, IOException {
        List<XfzbDTO> xfzbDTOS = activityService.excludeExcelXfzb(activityVO);
        String templateName="信访指标统计表";
        ExcelUtil.excludeOrIncludeWrite3(response, xfzbDTOS, XfzbDTO.class, new ArrayList<>(), new ArrayList<>(),templateName,orgName);
//        导出到本地
//        ExcelUtil.excludeOrIncludeWriteLoacl2(response, xfzbDTOS, XfzbDTO.class, new ArrayList<>(), new ArrayList<>(),templateName,orgName);
        return AjaxResult.success("信访指标统计表");
    }

    /**
     * 信访登记统计表（省、市级用）
     * @return
     */
    @PostMapping("/excludeXfdj")
    @ResponseBody
    public AjaxResult excludeExcelXfdj(HttpServletResponse response,ActivityVO activityVO){
        LinkedList<Map> list = activityService.excludeExcelXfdj(activityVO,Integer.valueOf(activityVO.getType()));
        String fileName = "市县人大信访部门信访登记统计表(市级用)";
        String orgName = activityVO.getOrgName();
        if(StringUtils.isEmpty(activityVO.getType())){
            return AjaxResult.error("type值为空！");
        }else if ("2".equals(activityVO.getType())){
            fileName = "全省三级人大信访部门信访登记统计表(省级用)";
        }
        ExcelUtil.excludeTepm(response , fileName, list,orgName);
        return AjaxResult.success(fileName);
    }

    /**
     *  自定义查询导出
     */
    @PostMapping("excludeZDY")
    @ResponseBody
    public AjaxResult excludeZDY(HttpServletResponse response ,@RequestBody ZdyQuery zdyQuery){
        if (StringUtils.isEmpty(zdyQuery.getType())){
            return AjaxResult.error("type为空!");
        }
        zdyQuery.setCheckOrg();
        List<String> alone = zdyQuery.getAlone();
        if(alone != null && alone.indexOf("abstract") != -1){
            alone.add("matterAbstract");
        }
        List<ActivityDTO> list = activityService.excludeZDY(zdyQuery);
        if(alone.contains("contentClassify")){
            alone.add("contentClassify1");
            alone.add("contentClassify2");
            alone.add("contentClassify3");
            alone.add("contentClassify4");
            alone.add("contentClassify5");
            alone.remove("contentClassify");
        }
        list.stream().forEach(p->{
            p.setMainPerson(p.getName());
            p.setIsAccept("1".equals(p.getIsAccept()) ? "否" : "是");
            p.setIsAcceptPerson("1".equals(p.getIsAcceptPerson()) ? "否" : "是");
            p.setIsAnswer("1".equals(p.getIsAnswer()) ? "是" : "否");
        });
        //设置序号
        AhrdUitls.setNumber(list,zdyQuery.getMerge());
        ExcelUtil.excludeOrIncludeWrite(response, list, ActivityDTO.class, zdyQuery.getMerge(), alone);
        return AjaxResult.success(list.size());
    }

    /**
     * 信访人所有信访事项查询
     */
    @PostMapping("excludeXFRSX")
    @ResponseBody
    public AjaxResult excludeXFRSX(HttpServletResponse response , MatterQuery matterQuery){

        List<ActivityDTO> list = activityService.excludeXFRSX(matterQuery);
        //设置序号
        AhrdUitls.setNumber(list,matterQuery.getMerge());
        List<String> alone = matterQuery.getAlone();
        if(alone != null && alone.indexOf("abstract") != -1){
            alone.add("matterAbstract");
        }
        if(alone.contains("contentClassify")){
            list = activityService.checkContentClassify(list);
            alone.add("contentClassify1");
            alone.add("contentClassify2");
            alone.add("contentClassify3");
            alone.add("contentClassify4");
            alone.add("contentClassify5");
            alone.remove("contentClassify");
        }
        list.stream().forEach(p->{
            p.setMainPerson(p.getName());
            String valaue = "是";
            if("1".equals(p.getIsAccept())){
                valaue = "否";
            }
            p.setIsAccept(valaue);
            String valaue2 = "是";
            if("1".equals(p.getIsAcceptPerson())){
                valaue2 = "否";
            }
            p.setIsAcceptPerson(valaue2);
        });
        ExcelUtil.excludeOrIncludeWrite(response, list, ActivityDTO.class, matterQuery.getMerge(), alone);
        return AjaxResult.success(list);
    }
}
