package com.dlsm.controller;


import com.alibaba.excel.EasyExcel;
import com.alibaba.excel.ExcelWriter;

import com.alibaba.excel.write.metadata.WriteSheet;
import com.alibaba.excel.write.metadata.fill.FillWrapper;
import com.dlsm.model.*;

import com.dlsm.model.dto.ActivityDto;
import com.dlsm.model.dto.ActivityDto1;
import com.dlsm.model.dto.MatterDto;
import com.dlsm.model.export.GradeExport;
import com.dlsm.model.export.MatterDTO2;
import com.dlsm.model.export.PersonExport;
import com.dlsm.model.vo.ActivityVO2;
import com.dlsm.model.vo.AffiliationMatterVO;
import com.dlsm.service.ActivityService;
import com.dlsm.service.ExportService;
import com.dlsm.service.MatterService;
import com.dlsm.utils.*;
import com.dlsm.utils.excel.AhrdCellWriteHandler;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.core.io.ClassPathResource;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;


import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.io.InputStream;
import java.text.ParseException;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;


/**
 * 固定报表导出
 */
@CrossOrigin
@Controller
@RequestMapping("/fixedExport")
public class ExportController {

    @Autowired
    private ExportService exportService;

    @Autowired
    private MatterService matterService;

    @Autowired
    private ActivityService activityService;

    /**
     * 信访人信息导出
     */
    @GetMapping("/person")
    @ResponseBody
    public void  LetterList( HttpServletResponse response,Long id ,String orgName){
        //信访人基本信息
        Person person  = exportService.selectPerson(id);

        if (StringUtils.isNotEmpty(person.getPostalRegionID()) && StringUtils.isNotEmpty(person.getPostal())) {
            Dictionary  dictionary = exportService.selectDictonaryByDictValue("DQ",person.getPostalRegionID());
            if (dictionary != null && person.getPostal().indexOf(dictionary.getDescription()) == -1) {
                person.setPostal(person.getPostalRegion() + person.getPostal());
            }
            dictionary = exportService.selectDictonaryByDictValue("DQ", dictionary.getParentValue());
            if (dictionary != null && person.getPostal().indexOf(dictionary.getDescription()) == -1) {
                person.setPostal(dictionary.getDescription() + person.getPostal());
            }
            if (StringUtils.isNotEmpty(dictionary.getParentValue())) {
                dictionary = exportService.selectDictonaryByDictValue("DQ", dictionary.getParentValue());
                if (dictionary != null && person.getPostal().indexOf(dictionary.getDescription()) == -1) {
                    person.setPostal(dictionary.getDescription() + person.getPostal());
                }
            }
        }
        //本系统相关记录 反映的信访事项信息
        Map<String, Object> map =exportService.personInitial(id);
        String dytime = DateTimeUtils.getDayMonthYear(new Date());
        map.put("orgName",orgName);
        map.put("dytime",dytime);
        ExcelWriter excelWriter = null;
        try {
        String templateName = "信访人信息摘录单";
        String suffix = ".xlsx";
        InputStream   inputStream = new ClassPathResource("/static/temp/excel/" + templateName + suffix).getInputStream();

        response.setContentType("multipart/form-data");
        response.addHeader("Content-Disposition", "attachment;filename=" + System.currentTimeMillis() + ".xlsx");
        excelWriter = EasyExcel.write(response.getOutputStream()).withTemplate(inputStream).build();
        WriteSheet writeSheet = EasyExcel.writerSheet().build();
        excelWriter.fill(person, writeSheet);
        excelWriter.fill(map, writeSheet);
        excelWriter.fill(map.get("list"), writeSheet);

        } catch (IOException e) {
            e.printStackTrace();
        }finally {
            // 关闭流
            excelWriter.finish();
        }
    }


    /**
     * 人民群众信访事项摘录单
     */
    @GetMapping("/abstract")
    @ResponseBody
    public void  LetterList1( HttpServletResponse response, HttpServletRequest request, String id,String orgName)  {
        MatterDto matterDto = matterService.MessageAbstract(id);
        ExcelWriter excelWriter = null;
        try {
            String dytime = DateTimeUtils.getDayMonthYear(new Date());
            Map<String,String> map=new HashMap<>();
            map.put("orgName",orgName);
            map.put("dytime",dytime);
            String templateName = "人民群众信访事项摘录单";
            String suffix = ".xlsx";
            InputStream  inputStream = new ClassPathResource("/static/temp/excel/" + templateName + suffix).getInputStream();

            response.addHeader("Content-Disposition", "attachment;filename=" + System.currentTimeMillis() + ".xlsx");
            response.setContentType("multipart/form-data");
            excelWriter = EasyExcel.write(response.getOutputStream()).withTemplate(inputStream).build();
            WriteSheet writeSheet = EasyExcel.writerSheet().build();
            excelWriter.fill(matterDto, writeSheet);
            excelWriter.fill(map, writeSheet);
        } catch (IOException e) {
            e.printStackTrace();
        }finally {
            // 关闭流
            excelWriter.finish();
        }
    }




    /**
     * 同件联名信署名人员名单   同批集体（群体）访参加走访人员名单
     * 同一个接口
     */
    @GetMapping("/network")
    @ResponseBody
    public Result Same(HttpServletResponse response, String id,String orgName)  {
        Map<String, Object> map = exportService.networkList(id);
        String dytime = DateTimeUtils.getDayMonthYear(new Date());
        map.put("orgName",orgName);
        map.put("dytime",dytime);
        String templateName = "";
        Object mode = map.get("mode");
        //  // 联名信  1    集体访 2  其他没有对应的类型 3
        if (mode.toString().equals("1")){
             templateName = "同件联名信署名人员名单";
            method(response,  map, templateName);
            Result result=new Result();
            return result;
        }else if (mode.toString().equals("2")){
            templateName = "同批集体（群体）访参加走访人员名单";
            method(response, map, templateName);
            Result result=new Result();
            return result;
        }else {
            Result result=new Result();
            result.setCode(0);
            result.setMsg("未找到符合的集体访或同件联名信");
            return result;
        }
    }

    private void method(HttpServletResponse response, Map<String, Object> map, String templateName) {
        ExcelWriter excelWriter =null;
        try {
            String suffix = ".xlsx";
            InputStream  inputStream = new ClassPathResource("/static/temp/excel/" + templateName + suffix).getInputStream();

            response.setContentType("multipart/form-data");
            response.addHeader("Content-Disposition", "attachment;filename=" + System.currentTimeMillis() + ".xlsx");
            excelWriter = EasyExcel.write(response.getOutputStream()).withTemplate(inputStream).build();
            WriteSheet writeSheet = EasyExcel.writerSheet().build();
            excelWriter.fill(map, writeSheet);
            Object peopleVo = map.get("peopleVo");
            excelWriter.fill(peopleVo, writeSheet);
        } catch (IOException e) {
            e.printStackTrace();
        }finally {
            excelWriter.finish();
        }
    }


    /**i
     * 同一信访事项涉及的参与集体（群体）走访和联名信署名的人员名单.
     */
    @GetMapping("/morePerson")
    @ResponseBody
    public void  MoreList( HttpServletResponse response, String id,String orgName)  {
        Map<String, Object> map = matterService.morePersonList(id);
        String dytime = DateTimeUtils.getDayMonthYear(new Date());
        map.put("orgName",orgName);
        map.put("dytime",dytime);
        ExcelWriter excelWriter = null;
        try {
        String templateName = "同一信访事项涉及的参与集体（群体）走访和联名信署名的人员名单";
        String suffix = ".xlsx";
        InputStream  inputStream = new ClassPathResource("/static/temp/excel/" + templateName + suffix).getInputStream();

            response.setContentType("multipart/form-data");
        response.addHeader("Content-Disposition", "attachment;filename=" + System.currentTimeMillis() + ".xlsx");
        excelWriter = EasyExcel.write(response.getOutputStream()).withTemplate(inputStream).build();
        WriteSheet writeSheet = EasyExcel.writerSheet().build();
        excelWriter.fill(map, writeSheet);
        excelWriter.fill(map.get("newperson"), writeSheet);

        } catch (IOException e) {
            e.printStackTrace();
        }finally {
            excelWriter.finish();
        }
    }


    /**
     * 人民群众信访（活动）登记摘录单
     */
    @GetMapping("/peopleActivity")
    @ResponseBody
    public void  peopleActivity( HttpServletResponse response,  String id,String orgName)  {
        Map<String, Object> map =  exportService.peopleActivity(id);
        String dytime = DateTimeUtils.getDayMonthYear(new Date());
        map.put("orgName",orgName);
        map.put("dytime",dytime);
        ExcelWriter excelWriter = null;
        try {
            String templateName;
            List<MatterDto> list1 = (List<MatterDto>) map.get("list1");
            List<MatterDto> list2 = (List<MatterDto>) map.get("list2");
            List<MatterDto> list3 = (List<MatterDto>) map.get("list3");
            if (StringUtils.isNotEmpty(list2) && StringUtils.isNotEmpty(list3) ){
                 templateName = "人民群众信访（活动）登记摘录单3";
            }else if (StringUtils.isNotEmpty(list2) && StringUtils.isEmpty(list3) ){
                templateName = "人民群众信访（活动）登记摘录单2";
            }else {
                templateName = "人民群众信访（活动）登记摘录单1";
            }

            String suffix = ".xlsx";
            InputStream  inputStream = new ClassPathResource("/static/temp/excel/" + templateName + suffix).getInputStream();

            response.setContentType("multipart/form-data");
            response.addHeader("Content-Disposition", "attachment;filename=" + System.currentTimeMillis() + ".xlsx");
            excelWriter = EasyExcel
                    .write(response.getOutputStream())
                    .registerWriteHandler(new AhrdCellWriteHandler()) //添加自定义样式
                    .withTemplate(inputStream).build();
            WriteSheet writeSheet = EasyExcel.writerSheet().build();
            excelWriter.fill(map, writeSheet);
            excelWriter.fill(new FillWrapper("matterDto1",list1), writeSheet);
            if (StringUtils.isNotEmpty(list2) && StringUtils.isEmpty(list3) ){
                excelWriter.fill(new FillWrapper("matterDto2",list2), writeSheet);
            }else if (StringUtils.isNotEmpty(list2) && StringUtils.isNotEmpty(list3) ){
                excelWriter.fill(new FillWrapper("matterDto2",list2), writeSheet);
                excelWriter.fill(new FillWrapper("matterDto3",list3), writeSheet);
            }
        } catch (IOException e) {
            e.printStackTrace();
        }finally {
            excelWriter.finish();
        }
    }


    /**
     * 导出文件方法
     */
    public void export(String filePath, String fileName, HttpServletResponse response, HttpServletRequest request) {


        try {
            response.setCharacterEncoding("utf-8");
            response.setContentType("multipart/form-data");
            response.setHeader("Content-Disposition",
                    "attachment;fileName=" + FileUtils.setFileDownloadHeader(request,fileName));
            FileUtils.writeBytes(filePath+fileName, response.getOutputStream());
        } catch (IOException e) {
            e.printStackTrace();
        }
        FileUtils.deleteFile(filePath+fileName);
    }


    /**
     * 各层级代表反映信访事项情况表(三级通用)
     */
    @GetMapping("/Grade")
    @ResponseBody
    public Result  Grade( HttpServletResponse response,  GradeExport gradeExport) {
        if (gradeExport.getStartTime() == null) {
            Result result = new Result();
            result.setCode(0);
            result.setMsg("时间不能空");
            return result;
        } else {
            Map<String, Object> map = null;
            try {
                map = exportService.GradeExportList(gradeExport);
                String dytime = DateTimeUtils.getDayMonthYear(new Date());
                map.put("dytime",dytime);
                map.put("orgName",gradeExport.getOrgName());
            } catch (ParseException e) {
                e.printStackTrace();
            }
            //Grade   a 省b  市 c县
            String grade = (String) map.get("Grade");
            String templateName;
            if (grade.equals("a")) {
                templateName = "各层级代表反映信访事项情况表(三级通用)2";
            } else if (grade.equals("b")) {
                templateName = "各层级代表反映信访事项情况表(三级通用)3";
            } else {
                templateName = "各层级代表反映信访事项情况表(三级通用)4";
            }

            ExcelWriter excelWriter = null;
            try {
                String suffix = ".xlsx";
                InputStream inputStream = new ClassPathResource("/static/temp/excel/" + templateName + suffix).getInputStream();

                response.setContentType("multipart/form-data");
                response.addHeader("Content-Disposition", "attachment;filename=" + System.currentTimeMillis() + ".xlsx");
                excelWriter = EasyExcel.write(response.getOutputStream()).withTemplate(inputStream).build();
                WriteSheet writeSheet = EasyExcel.writerSheet().build();
                List<GradeExport> list1 = (List<GradeExport>) map.get("gradeExports");
                List<GradeExport> list2 = (List<GradeExport>) map.get("provinceExports");
                excelWriter.fill(new FillWrapper("list1", list1), writeSheet);
                excelWriter.fill(new FillWrapper("list2", list2), writeSheet);
                if (grade.equals("b")) {
                    List<GradeExport> list3 = (List<GradeExport>) map.get("cityExports");
                    excelWriter.fill(new FillWrapper("list3", list3), writeSheet);
                } else if (grade.equals("c")) {
                    List<GradeExport> list3 = (List<GradeExport>) map.get("cityExports");
                    List<GradeExport> list4 = (List<GradeExport>) map.get("countyExports");
                    excelWriter.fill(new FillWrapper("list3", list3), writeSheet);
                    excelWriter.fill(new FillWrapper("list4", list4), writeSheet);
                }
                List<GradeExport> list = (List<GradeExport>) map.get("sumGrade");
                excelWriter.fill(new FillWrapper("list", list), writeSheet);
                excelWriter.fill(map, writeSheet);
            } catch (IOException e) {
                e.printStackTrace();
            } finally {
                excelWriter.finish();
            }
        }
        Result result = new Result();
        return result;
    }
    /**
     * 本级代表反映信访事项情况统计表（三级通用）
     */
    @PostMapping("/behalfList")
    @ResponseBody
    public void  behalfList( HttpServletResponse response,  AffiliationMatter affiliationMatter) {
        Map<String, List<ActivityDto>> map = null;
        Map<String, String> map1 = new HashMap<>();
        ExcelWriter excelWriter = null;
        try {
            map = activityService.behalfList(affiliationMatter);
            String dytime = DateTimeUtils.getDayMonthYear(new Date());
            map1.put("dytime",dytime);
            map1.put("orgName",affiliationMatter.getOrgName());
            String templateName = "本级代表反映信访事项情况统计表(三级通用)";
            String suffix = ".xlsx";
            InputStream inputStream = new ClassPathResource("/static/temp/excel/" + templateName + suffix).getInputStream();
            response.setContentType("multipart/form-data");
            response.addHeader("Content-Disposition", "attachment;filename=" + System.currentTimeMillis() + ".xlsx");
            excelWriter = EasyExcel.write(response.getOutputStream()).withTemplate(inputStream).build();
            WriteSheet writeSheet = EasyExcel.writerSheet().build();
            excelWriter.fill(map, writeSheet);
            List<ActivityDto> list1 = map.get("list1zpc");   //代表来信来访合计 批次
            List<ActivityDto> list2 = map.get("list2zrs");   //代表来信来访合计 人数
            List<ActivityDto> list3 = map.get("list7lfydpc");  //代表来访引导来访批次
            List<ActivityDto> list4 = map.get("list8lfydrs");   //代表来访引导来访人数
            List<ActivityDto> list5 = map.get("list3dblfpc"); //代表来访批次
            List<ActivityDto> list6 = map.get("list4dblfrs");  //代表来访人数
            List<ActivityDto> list7 = map.get("list5dbydpc");  //代表引导批次
            List<ActivityDto> list8 = map.get("list6dbydrs");  //代表引导人数
            List<ActivityDto> list9 = map.get("list11lxzx");       //代表来信转信
            List<ActivityDto> list10 = map.get("list9lx");        //代表来信
            List<ActivityDto> list11 = map.get("list10zx");        //代表转信
            excelWriter.fill(new FillWrapper("Dto1", list1), writeSheet);
            excelWriter.fill(new FillWrapper("Dto2", list2), writeSheet);
            excelWriter.fill(new FillWrapper("Dto3", list3), writeSheet);
            excelWriter.fill(new FillWrapper("Dto4", list4), writeSheet);
            excelWriter.fill(new FillWrapper("Dto5", list5), writeSheet);
            excelWriter.fill(new FillWrapper("Dto6", list6), writeSheet);
            excelWriter.fill(new FillWrapper("Dto7", list7), writeSheet);
            excelWriter.fill(new FillWrapper("Dto8", list8), writeSheet);
            excelWriter.fill(new FillWrapper("Dto9", list9), writeSheet);
            excelWriter.fill(new FillWrapper("Dto10", list10), writeSheet);
            excelWriter.fill(new FillWrapper("Dto11", list11), writeSheet);
            excelWriter.fill(map1, writeSheet);



        } catch (ParseException e) {
            e.printStackTrace();
        } catch (IOException e) {
            e.printStackTrace();
        }finally {
            excelWriter.finish();
        }
    }


    /**
     * 人大常委会及机关、工委领导接访阅信情况统计表(三级通用)
     */
    @PostMapping("/leadList")
    @ResponseBody
    public void  leadList( HttpServletResponse response,  AffiliationMatter affiliationMatter){
        Map<String, List<ActivityDto>> map = null;
        Map<String, String> map1 = new HashMap<>();
        ExcelWriter excelWriter = null;
        try {
            map = activityService.leadList(affiliationMatter);
            String dytime = DateTimeUtils.getDayMonthYear(new Date());
            map1.put("dytime",dytime);
            map1.put("orgName",affiliationMatter.getOrgName());
        String templateName = "人大常委会及机关、工委领导接访阅信情况统计表(三级通用)";
        String suffix = ".xlsx";
        InputStream inputStream = new ClassPathResource("/static/temp/excel/" + templateName + suffix).getInputStream();
        response.setContentType("multipart/form-data");
        response.addHeader("Content-Disposition", "attachment;filename=" + System.currentTimeMillis() + ".xlsx");
        excelWriter = EasyExcel.write(response.getOutputStream()).withTemplate(inputStream).build();
        WriteSheet writeSheet = EasyExcel.writerSheet().build();
        excelWriter.fill(map, writeSheet);
        List<ActivityDto> list1 = map.get("list1jfyxpc");   //领导接访及阅信总计 批次
        List<ActivityDto> list2 = map.get("list2jfyxrs");   //领导接访及阅信总计 人数
        List<ActivityDto> list3 = map.get("list7ycwjg");  //常委会及机关或工委领导接访   批次
        List<ActivityDto> list4 = map.get("list8cwjgrs");   //常委会及机关或工委领导接访      人数
        List<ActivityDto> list5 = map.get("list3CwjfPc"); //常委会领导接访   批次
        List<ActivityDto> list6 = map.get("list4CwjfRs");  //常委会领导接访      人数
        List<ActivityDto> list7 = map.get("list5Jgjfpc");  //机关或工委领导接访   批次
        List<ActivityDto> list8 = map.get("list6jgjfrs");  //机关或工委领导接访  人数
        List<ActivityDto> list9 = map.get("list11Yxcwjg");       //常委会及机关领导阅信
        List<ActivityDto> list10 = map.get("list9Cwyx");        //常委会领导阅信
        List<ActivityDto> list11 = map.get("list10Jgyx");        //机关或工委领导阅信
        excelWriter.fill(new FillWrapper("Dto1",list1), writeSheet);
        excelWriter.fill(new FillWrapper("Dto2",list2), writeSheet);
        excelWriter.fill(new FillWrapper("Dto3",list3), writeSheet);
        excelWriter.fill(new FillWrapper("Dto4",list4), writeSheet);
        excelWriter.fill(new FillWrapper("Dto5",list5), writeSheet);
        excelWriter.fill(new FillWrapper("Dto6",list6), writeSheet);
        excelWriter.fill(new FillWrapper("Dto7",list7), writeSheet);
        excelWriter.fill(new FillWrapper("Dto8",list8), writeSheet);
        excelWriter.fill(new FillWrapper("Dto9",list9), writeSheet);
        excelWriter.fill(new FillWrapper("Dto10",list10), writeSheet);
        excelWriter.fill(new FillWrapper("Dto11",list11), writeSheet);
        excelWriter.fill(map1, writeSheet);

        } catch (ParseException e) {
            e.printStackTrace();
        }catch (IOException e) {
            e.printStackTrace();
        }finally {
            excelWriter.finish();
        }
    }

    /**
     * 本级及下一级人大领导接访阅信统计表（省、市级用）
     */
    @PostMapping("/NpcCongress")
    @ResponseBody
    public Result  NpcCongress( HttpServletResponse response,  AffiliationMatter affiliationMatter)  {
        Map<String, Object> map = null;
        try {
            map = activityService.NpcCongressList(affiliationMatter);
            String dytime = DateTimeUtils.getDayMonthYear(new Date());
            map.put("dytime",dytime);
            map.put("orgName",affiliationMatter.getOrgName());
        } catch (ParseException e) {
            e.printStackTrace();
        }
        String state = (String)map.get("state");
        if (state.equals("scopeIn")){
            ExcelWriter excelWriter = null;
            try {
                String templateName = "本级及下一级人大领导接访阅信统计表（省、市级用）";
                String suffix = ".xlsx";
                InputStream inputStream = new ClassPathResource("/static/temp/excel/" + templateName + suffix).getInputStream();
            response.setContentType("multipart/form-data");
            response.addHeader("Content-Disposition", "attachment;filename=" + System.currentTimeMillis() + ".xlsx");
             excelWriter = EasyExcel.write(response.getOutputStream()).withTemplate(inputStream).build();
            WriteSheet writeSheet = EasyExcel.writerSheet().build();
            excelWriter.fill(map.get("list"), writeSheet);
            excelWriter.fill(map, writeSheet);
            // 千万别忘记关闭流
            } catch (IOException e) {
                e.printStackTrace();
            }finally {
                excelWriter.finish();
                Result result=new Result();
                return result;
            }
        }else {
            //判断如果 不是 省 市 的单位
            Result result=new Result();
            result.setCode(0);
            result.setMsg("只有省，市单位才可以导出");
            return result;
        }
    }


    /**
     * 依法分类处理情况统计表（三级通用）
     */
    @PostMapping("/exclFLtj")
    @ResponseBody
    public AjaxResult  exclFLtj( HttpServletResponse response,  AffiliationMatter affiliationMatter)  {
        ExcelWriter excelWriter = null;

        try {
            Map<String, String> map = new HashMap<>();
            String dytime = DateTimeUtils.getDayMonthYear(new Date());
            map.put("dytime",dytime);
            map.put("orgName",affiliationMatter.getOrgName());
            List<ActivityDto> list =  exportService.exclFLtjList(affiliationMatter);
            String templateName = "依法分类处理情况统计表（三级通用）";
            String suffix = ".xlsx";
            InputStream inputStream = new ClassPathResource("/static/temp/excel/" + templateName + suffix).getInputStream();
            response.setContentType("multipart/form-data");
            response.addHeader("Content-Disposition", "attachment;filename=" + System.currentTimeMillis() + ".xlsx");
            excelWriter = EasyExcel.write(response.getOutputStream()).withTemplate(inputStream).build();
            WriteSheet writeSheet = EasyExcel.writerSheet().build();
            excelWriter.fill(list, writeSheet);
            excelWriter.fill(map, writeSheet);
        }catch (ParseException  e) {
                e.printStackTrace();
         } catch (IOException e) {
            e.printStackTrace();
        }finally {
            excelWriter.finish();
        }
        return  AjaxResult.success();
    }
    /**
     * 初重反映信访事项统计表(三级通用)
     */
    @PostMapping("/exclCcXfTj")
    @ResponseBody
    public AjaxResult  exclCcXfTj( HttpServletResponse response, LeadBehalf leadBehalf)  {
        ExcelWriter excelWriter = null;
        try {
            Map<String,String> map =new HashMap<>();
            String dytime = DateTimeUtils.getDayMonthYear(new Date());
            map.put("dytime",dytime);
            map.put("orgName",leadBehalf.getOrgName());
            List<ActivityDto> list =  exportService.exclCcXfTjList(leadBehalf);
            String templateName = "初重反映信访事项统计表(三级通用)";
            String suffix = ".xlsx";
            InputStream inputStream = new ClassPathResource("/static/temp/excel/" + templateName + suffix).getInputStream();
            response.setContentType("multipart/form-data");
            response.addHeader("Content-Disposition", "attachment;filename=" + System.currentTimeMillis() + ".xlsx");
            excelWriter = EasyExcel.write(response.getOutputStream()).withTemplate(inputStream).build();
            WriteSheet writeSheet = EasyExcel.writerSheet().build();
            excelWriter.fill(list, writeSheet);
            excelWriter.fill(map, writeSheet);
        }catch (ParseException  e) {
            e.printStackTrace();
        } catch (IOException e) {
            e.printStackTrace();
        }finally {
            excelWriter.finish();
        }
        return  AjaxResult.success();
    }

    /**
     * 信访事项所属系统统计表（三级通用）
     */
    @PostMapping("/exclXtXfTj")
    @ResponseBody
    public AjaxResult  exclXfSsxt( HttpServletResponse response, AffiliationMatter affiliationMatter)  {
        ExcelWriter excelWriter = null;
        Map<String,String> map =new HashMap<>();
        String dytime = DateTimeUtils.getDayMonthYear(new Date());
        map.put("dytime",dytime);
        map.put("orgName",affiliationMatter.getOrgName());
        try {
            List<ActivityDto1> list =  exportService.exclXfSsxtList(affiliationMatter);
            String templateName = "信访事项所属系统统计表（三级通用）";
            String suffix = ".xlsx";
            InputStream inputStream = new ClassPathResource("/static/temp/excel/" + templateName + suffix).getInputStream();
            response.setContentType("multipart/form-data");
            response.addHeader("Content-Disposition", "attachment;filename=" + System.currentTimeMillis() + ".xlsx");
            excelWriter = EasyExcel.write(response.getOutputStream()).withTemplate(inputStream).build();
            WriteSheet writeSheet = EasyExcel.writerSheet().build();
            excelWriter.fill(list, writeSheet);
            excelWriter.fill(map, writeSheet);
        }catch (ParseException  e) {
            e.printStackTrace();
        } catch (IOException e) {
            e.printStackTrace();
        }finally {
            excelWriter.finish();
        }
        return  AjaxResult.success();
    }

    /**
     * 重复反映信访事项排查表(三级通用)
     *
     * @param request
     * @param response
     * @param matterDTO2
     */
    @PostMapping("/matterExclude")
    @ResponseBody
    public void matterExclude(HttpServletRequest request, HttpServletResponse response,@RequestBody MatterDTO2 matterDTO2) {
        List<Map<String, Object>> mapList = exportService.matterExclude(matterDTO2);
        String templateName = "重复反映信访事项排查表(三级通用)";
        String orgName = matterDTO2.getOrgName();
        ExcelUtil.excludeTepm(response,templateName,mapList,orgName);
//        ExcelUtil.excludeTepmToLocal(response,templateName,mapList,orgName);
    }


    /**
     * 信访老户排查表
     *
     * @param personExport
     * @param response
     * @param request
     */
    @PostMapping("/matterOldUser")
    @ResponseBody
    public void matterOldUser(@RequestBody PersonExport personExport, HttpServletResponse response, HttpServletRequest request) {
        List<Map<String, Object>> mapList = exportService.matterOldUser(personExport);
        String templateName = "信访老户排查表(三级通用)";
        String orgName = personExport.getOrgName();
        ExcelUtil.excludeTepm(response , templateName, mapList,orgName);
//        ExcelUtil.excludeTepmToLocal(response,templateName,mapList,orgName);
    }


    /**
     * 信访事项所属系统统计表（三级通用）
     */
    @PostMapping("/exclSdXfTj")
    @ResponseBody
    public AjaxResult  exclSdXfTj( HttpServletResponse response, AffiliationMatterVO matterVO)  {
        ExcelWriter excelWriter = null;
        Map<String,String> map =new HashMap<>();
        String dytime = DateTimeUtils.getDayMonthYear(new Date());
        map.put("dytime",dytime);
        map.put("orgName",matterVO.getOrgName());
        try {
            List<ActivityDto1> list =  exportService.exclSdXfTj(matterVO);
            String templateName = "信访事项属地统计表（三级通用）";
            String suffix = ".xlsx";
            InputStream inputStream = new ClassPathResource("/static/temp/excel/" + templateName + suffix).getInputStream();
            response.setContentType("multipart/form-data");
            response.addHeader("Content-Disposition", "attachment;filename=" + System.currentTimeMillis() + ".xlsx");
            excelWriter = EasyExcel.write(response.getOutputStream()).withTemplate(inputStream).build();
            WriteSheet writeSheet = EasyExcel.writerSheet().build();
            excelWriter.fill(list, writeSheet);
            excelWriter.fill(map, writeSheet);
        }catch (ParseException  e) {
            e.printStackTrace();
        } catch (IOException e) {
            e.printStackTrace();
        }finally {
            excelWriter.finish();
        }
        return  AjaxResult.success();
    }
}







