package com.dlsm.controller;


import com.dlsm.model.AjaxResult;
import com.dlsm.model.export.ActivityDTO;
import com.dlsm.model.export.XfzbDTO;
import com.dlsm.model.vo.MatterVO;
import com.dlsm.model.vo.ZdyQuery;
import com.dlsm.model.vo.MatterQuery;
import com.dlsm.service.ActivityService;
import com.dlsm.service.MatterService;
import com.dlsm.utils.AhrdUitls;
import com.dlsm.utils.ExcelUtil;
import com.dlsm.utils.Result;
import com.dlsm.utils.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.text.ParseException;
import java.util.*;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * 事项管理controller
 *
 * @author xunfeng
 * @date 2022-03-02
 */
@CrossOrigin
@Controller
@RequestMapping("/ahrd/matter")
public class MatterController {
    private final String[] LDDB = new String[]{"001002001","001002002","001003","002002001","002002002","002003","001004","002006"};
    private final String[] LMFY = new String[]{"001002","002002"};
    @Autowired
    private MatterService matterService;
    @Autowired
    private ActivityService activityService;
    /**
     *  查询反映内容分类分析
     */
    @CrossOrigin
    @GetMapping("/reactionContentClassify")
    @ResponseBody
    public Result reactionContentClassify(String deptIdList, String userId, String startTime, String endTime, String identifying) throws ParseException {
        Map<String, Object> map = matterService.reactionContentClassify(deptIdList,userId,startTime,endTime,identifying);
        Result<Map<String,Object>> objectResult = new Result<>();
        objectResult.setData(map);
        return objectResult;
    }


    /**
     *  热点问题分析
     */
    @CrossOrigin
    @GetMapping("/hotSpot")
    @ResponseBody
    public Result HotSpot(String deptIdList,String userId,String startTime,String endTime,String registerTypeIdList,String identifying) throws ParseException {
        Map<String, Object> map = matterService.hotSpot(deptIdList,userId,startTime,endTime,registerTypeIdList,identifying);
        Result<Map<String,Object>> objectResult = new Result<>();
        objectResult.setData(map);
        return objectResult;
    }

    /**
     *  导出-重复信访查询
     * @param matterQuery
     * @return
     */
    @PostMapping("/excludeRepeatXf")
    @ResponseBody
    public AjaxResult excludeExcelRepeatXf(MatterQuery matterQuery, HttpServletResponse response){
       List<ActivityDTO> list =  matterService.selectRepeatXf(matterQuery);
       list = list.stream().collect(Collectors.collectingAndThen(Collectors.toCollection(() ->new TreeSet<>(Comparator.comparing(ActivityDTO::getMrId))),ArrayList::new));
        List<String> merge = matterQuery.getMerge() == null ? new ArrayList<>():matterQuery.getMerge();
        merge.add("count");
        //添加序号
        Integer a = 1;
        for (int i = 0; i < list.size(); i++) {
            if(i > 0 ){
                if(!(list.get(i).getMrId()).equals(list.get(i-1).getMrId()) || merge==null || merge.isEmpty()){
                    a++;
                }
                list.get(i).setNumber(a.toString());
            }else {
                list.get(i).setNumber(a.toString());
            }
        }

        List<String> alone = matterQuery.getAlone();
        if(alone != null && alone.indexOf("abstract") != -1){
            alone.add("matterAbstract");
        }
        if(alone.contains("contentClassify")){
            list = activityService.checkContentClassify(list);
            alone.add("contentClassify1");
            alone.add("contentClassify2");
            alone.add("contentClassify3");
            alone.add("contentClassify4");
            alone.add("contentClassify5");
            alone.remove("contentClassify");
        }

        checkActivityDTO(list);
        ExcelUtil.excludeOrIncludeWrite(response, list, ActivityDTO.class, merge, matterQuery.getAlone());
        return AjaxResult.success("total:"+list.size());
    }

    private void checkActivityDTO(List<ActivityDTO> list) {
        list.stream().forEach(p->{
            p.setMainPerson(p.getName());
            String valaue = "是";
            String valaue2 = "是";
            String valaueAccept = "是";
            if("1".equals(p.getIsAccept())){
                valaue = "否";
            }
            if("0".equals(p.getIsAnswer())){
                valaueAccept = "否";
            }
            p.setIsAnswer(valaueAccept);
            p.setIsAccept(valaue);

            if("1".equals(p.getIsAcceptPerson())){
                valaue2 = "否";
            }
            p.setIsAcceptPerson(valaue2);
        });
    }

    /**
     * 导出-领导代表查询
     * @param matterQuery
     * @return
     */
    @PostMapping("/excludeLeader")
    @ResponseBody
    public AjaxResult excludeExcelLeader(HttpServletResponse response, MatterQuery matterQuery){
        if(StringUtils.isEmpty(matterQuery.getXfSourceID())){
            matterQuery.setXfSourceID(Arrays.asList(LDDB));
        }
        List<ActivityDTO> list =  matterService.excludeExcelLeader(matterQuery);
        AhrdUitls.setNumber(list,matterQuery.getMerge());
        List<String> alone = matterQuery.getAlone();
        if(alone != null && alone.indexOf("abstract") != -1){
            alone.add("matterAbstract");
        }
        if(alone.contains("contentClassify")){
            list = activityService.checkContentClassify(list);
            alone.add("contentClassify1");
            alone.add("contentClassify2");
            alone.add("contentClassify3");
            alone.add("contentClassify4");
            alone.add("contentClassify5");
            alone.remove("contentClassify");
        }
        checkActivityDTO(list);
        ExcelUtil.excludeOrIncludeWrite(response, list, ActivityDTO.class, matterQuery.getMerge(), matterQuery.getAlone());
        return AjaxResult.success();
    }

    /**
     * 导出-联名反映查询
     */
    @PostMapping("/excludeLmfy")
    @ResponseBody
    public AjaxResult excludeExcelCollectiveResponse(HttpServletResponse response, MatterQuery matterQuery){
        if(StringUtils.isEmpty(matterQuery.getXfSourceID())){
            matterQuery.setXfTypeID(Arrays.asList(LMFY));
        }
        List<ActivityDTO> list =  matterService.excludeExcelLeader(matterQuery);
        AhrdUitls.setNumber(list,matterQuery.getMerge());
        List<String> alone = matterQuery.getAlone();
        if(alone != null && alone.indexOf("abstract") != -1){
            alone.add("matterAbstract");
        }
        if(alone.contains("contentClassify")){
            list = activityService.checkContentClassify(list);
            alone.add("contentClassify1");
            alone.add("contentClassify2");
            alone.add("contentClassify3");
            alone.add("contentClassify4");
            alone.add("contentClassify5");
            alone.remove("contentClassify");
        }

        checkActivityDTO(list);
        ExcelUtil.excludeOrIncludeWrite(response, list, ActivityDTO.class, matterQuery.getMerge(), matterQuery.getAlone());
        return AjaxResult.success();
    }

    /**
     * 导出-被控检人
     */
    @PostMapping("/excludeKongJian")
    @ResponseBody
    public AjaxResult excludeKongJian(HttpServletResponse response, MatterQuery matterQuery){
        matterQuery.setMajor("1");
        List<ActivityDTO> list =  matterService.excludeExcelLeader(matterQuery);
        AhrdUitls.setNumber(list,matterQuery.getMerge());
        List<String> alone = matterQuery.getAlone();
        if(alone != null && alone.indexOf("abstract") != -1){
            alone.add("matterAbstract");
        }
        if(alone.contains("contentClassify")){
            list = activityService.checkContentClassify(list);
            alone.add("contentClassify1");
            alone.add("contentClassify2");
            alone.add("contentClassify3");
            alone.add("contentClassify4");
            alone.add("contentClassify5");
            alone.remove("contentClassify");
        }
        checkActivityDTO(list);
        ExcelUtil.excludeOrIncludeWrite(response, list, ActivityDTO.class, matterQuery.getMerge(), matterQuery.getAlone());
        return AjaxResult.success();
    }

    /**
     * 异常信访查询
     */
    @PostMapping("/excludeAbnormal")
    @ResponseBody
    public AjaxResult excludeAbnormal(HttpServletResponse response , MatterQuery matterQuery){
        matterQuery.setSubmit("1");
        matterQuery.setIsAbnormal("1");
        List<ActivityDTO> list = matterService.excludeExcelLeader(matterQuery);
        AhrdUitls.setNumber(list,matterQuery.getMerge());
        List<String> alone = matterQuery.getAlone();
        if(alone != null && alone.indexOf("abstract") != -1){
            alone.add("matterAbstract");
        }
        if(alone.contains("contentClassify")){
            list = activityService.checkContentClassify(list);
            alone.add("contentClassify1");
            alone.add("contentClassify2");
            alone.add("contentClassify3");
            alone.add("contentClassify4");
            alone.add("contentClassify5");
            alone.remove("contentClassify");
        }
        checkActivityDTO(list);
        ExcelUtil.excludeOrIncludeWrite(response, list, ActivityDTO.class, matterQuery.getMerge(), matterQuery.getAlone());
        return AjaxResult.success();
    }

    /**
     * 导出-三跨三分离
     * @param matterQuery
     * @return
     */
    @PostMapping("/excludeSKSFL")
    @ResponseBody
    public AjaxResult excludeSKSFL(HttpServletResponse response, MatterQuery matterQuery){
        matterQuery.setMajor("1");
        List<ActivityDTO> list =  matterService.excludeExcelLeader(matterQuery);
        AhrdUitls.setNumber(list,matterQuery.getMerge());
        List<String> alone = matterQuery.getAlone();
        if(alone != null && alone.indexOf("abstract") != -1){
            alone.add("matterAbstract");
        }
        if(alone.contains("contentClassify")){
            list = activityService.checkContentClassify(list);
            alone.add("contentClassify1");
            alone.add("contentClassify2");
            alone.add("contentClassify3");
            alone.add("contentClassify4");
            alone.add("contentClassify5");
            alone.remove("contentClassify");
        }
        checkActivityDTO(list);
        ExcelUtil.excludeOrIncludeWrite(response, list, ActivityDTO.class, matterQuery.getMerge(), matterQuery.getAlone());
        return AjaxResult.success();
    }

    /**
     * 信访事项转交去向单位统计表
     * @param response
     * @param matterQuery
     * @return
     */
    @PostMapping("excludeSXZJQX")
    @ResponseBody
    public AjaxResult excludeSXZJQX(HttpServletResponse response, MatterQuery matterQuery){
        String fileName = "13.信访事项转交去向单位统计表(三级通用)";
        String orgName = matterQuery.getOrgName();
        LinkedList<Map> list = matterService.excludeSXZJQX(matterQuery);
        ExcelUtil.excludeTepm(response , fileName, list,orgName);
        return AjaxResult.success(list);
    }

    /**
     * 信访事项交办转送情况统计表
     */
    @PostMapping("excludeXSJBZSQK")
    @ResponseBody
    public AjaxResult excludeXSJBZSQK(HttpServletResponse response, MatterQuery matterQuery){
        String fileName = "14.信访事项交办转送情况统计表(三级通用)";
        LinkedList<XfzbDTO> list = null;
        try {
            list = matterService.excludeXSJBZSQK(matterQuery);
        } catch (ParseException e) {
            e.printStackTrace();
        }
        String orgName = matterQuery.getOrgName();
        ExcelUtil.excludeTepm(response , fileName, list,orgName);
        return AjaxResult.success(list);
    }
    /**
     * 15.上级交办转送件处理情况统计表
     */
    @PostMapping("excludeSJJBZSQK")
    @ResponseBody
    public AjaxResult excludeSJJBZSQK(HttpServletResponse response, MatterQuery matterQuery){
        String fileName = "15.上级交办转送件处理情况统计表(市县用)";
        LinkedList<XfzbDTO> list = null;
        try {
            list = matterService.excludeSJJBZSQK(matterQuery);
        } catch (ParseException e) {
            e.printStackTrace();
        }
        String orgName = matterQuery.getOrgName();
        ExcelUtil.excludeTepm(response , fileName, list,orgName);
        return AjaxResult.success(fileName);
    }

    /**
     *  集体访（联名信）问题属地统计表（三级通用）
     */
    @PostMapping("excludeWTSD")
    @ResponseBody
    public AjaxResult excludeWTSD(HttpServletResponse response, MatterQuery matterQuery){
        String fileName = "10.集体访问题属地统计表(三级通用)";
        if ("002002".equals(matterQuery.getXfTypeID())){
            fileName = "12.联名信问题属地统计表(三级通用)";
        }
        LinkedList<Map> list = matterService.excludeWTSD(matterQuery);
        String orgName = matterQuery.getOrgName();
        ExcelUtil.excludeTepm(response , fileName, list,orgName);
        return AjaxResult.success(list);
    }
}
