package com.dlsm.service.impl;


import com.dlsm.mapper.ActivityMapper;
import com.dlsm.mapper.DeptMapper;
import com.dlsm.mapper.DictionaryMapper;
import com.dlsm.model.Activity;
import com.dlsm.model.AffiliationMatter;
import com.dlsm.model.Dept;
import com.dlsm.model.Dictionary;
import com.dlsm.model.Matter;
import com.dlsm.model.dto.ActivityDto;
import com.dlsm.model.export.ActivityDTO;
import com.dlsm.model.export.XfzbDTO;
import com.dlsm.model.vo.*;
import com.dlsm.service.ActivityService;
import com.dlsm.service.DeptService;
import com.dlsm.service.MatterService;
import com.dlsm.utils.*;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.*;
import java.util.stream.Collectors;

/**
 * 活动管理Service业务层处理
 *
 * @author xunfeng
 * @date 2022-03-02
 */
@Service
public class ActivityServiceImpl implements ActivityService {

    @Autowired
    private ActivityMapper activityMapper;

    @Autowired
    private DeptService deptService;

    @Autowired
    private MatterService matterService;

    @Autowired
    private DeptMapper deptMapper;

    @Autowired
    private DictionaryMapper dictionaryMapper;

    // 查询信访总量分析表
    @Override
    public Map<String, Object> petitionLetterGrossAnalyse(String deptIdList,String userId, String sTime, String eTime) throws ParseException {
        Map<String, Object> map = new HashMap<>();
        Dept dept = deptService.selectDeptByUserId(userId);
        // 当前登录用户的单位id
        String deptId = "";
        if (deptIdList == null || deptIdList == "") {
            deptId = dept.getId().toString();
        }
        Date startTime = null;
        Date endTime = null;
        SimpleDateFormat  format = new SimpleDateFormat("yyyy-MM-dd");
        if (sTime != null && sTime != "") {
            startTime = format.parse(sTime);
            endTime = format.parse(eTime);
        }

        SimpleDateFormat  f = new SimpleDateFormat("yyyy", Locale.CHINA);

        // 同比开始时间与结束时间
        Date currYearHBTime;
        Date lastYearHBTime;

        // 环比开始时间与结束时间
        Date currYearTBTime;
        Date lastYearTBTime;

        if (startTime == null) {
            // 本年的第一天
            startTime = DateTimeUtils.getCurrYearFirst();
            // 当前时间
            endTime = new Date();

            // 同比时间
            currYearHBTime = DateTimeUtils.getStartHBTime(startTime);
            lastYearHBTime = DateTimeUtils.getEndHBTime(endTime);

            // 环比时间
            currYearTBTime = DateTimeUtils.getTBTime(startTime,endTime).get("startTBTime");
            lastYearTBTime = DateTimeUtils.getTBTime(startTime,endTime).get("endTBTime");
        } else {
            endTime = DateTimeUtils.getTodayTime(endTime);

            currYearHBTime = DateTimeUtils.getStartHBTime(startTime);
            lastYearHBTime = DateTimeUtils.getEndHBTime(endTime);

            currYearTBTime = DateTimeUtils.getTBTime(startTime,endTime).get("startTBTime");
            lastYearTBTime = DateTimeUtils.getTBTime(startTime,endTime).get("endTBTime");
        }

        // 今年群众信访数据
        List<Activity> activityList = activityMapper.selectActivityList(deptIdList,deptId,startTime,endTime);

        List<Matter> matters = new ArrayList();
        if (activityList.size()>0) {
            // 查询今年信访事项
            matters = matterService.selectMatterList(activityList);
        }

        // 初访
        List<Matter> firstXF = matters.stream().filter((n) -> "100".equals( n.getVisitID())).collect(Collectors.toList());
        // 重访
        List<Matter> repetitionXF = matters.stream().filter((n) -> "200".equals( n.getVisitID())).collect(Collectors.toList());

        // 今年群众来访
        List<Activity> activityVisitList = activityList.stream().filter((n) -> n.getRegisterTypeID().startsWith("001")).collect(Collectors.toList());
        // 群众来访人数
        Integer personSum = 0;
        for (Activity activity : activityVisitList) {
            personSum = personSum + activity.getXfNumber();
        }

        // 查询今年来访
        List<Matter> matterVisitList = new ArrayList<>();
        if (activityVisitList.size() > 0) {
            matterVisitList = matterService.selectMatterList(activityVisitList);
        }
        // 初次来访
        List<Matter> firstVisit = matterVisitList.stream().filter((n) -> "100".equals( n.getVisitID())).collect(Collectors.toList());
        // 重复来访
        List<Matter> repetitionVisit = matterVisitList.stream().filter((n) -> "200".equals( n.getVisitID())).collect(Collectors.toList());

        // 今年群众来信
        List<Activity> activityLetterList = activityList.stream().filter((n) -> n.getRegisterTypeID().startsWith("002")).collect(Collectors.toList());

        // 查询今年来信
        List<Matter> matterLetterList = new ArrayList<>();
        if (activityLetterList.size() > 0) {
            matterLetterList = matterService.selectMatterList(activityLetterList);
        }
        // 初次来信
        List<Matter> firstLetter = matterLetterList.stream().filter((n) -> "100".equals(n.getVisitID())).collect(Collectors.toList());
        // 重复来信
        List<Matter> repetitionLetter = matterLetterList.stream().filter((n) -> "200".equals( n.getVisitID())).collect(Collectors.toList());

        // 今年群众来电
        List<Activity> activityPhoneList = activityList.stream().filter((n) -> n.getRegisterTypeID().startsWith("003")).collect(Collectors.toList());
        // 查询今年信访来电
        List<Matter> matterPhoneList = new ArrayList<>();
        if (activityPhoneList.size() > 0) {
            matterPhoneList = matterService.selectMatterList(activityPhoneList);
        }
        // 初次来电
        List<Matter> firstPhone = matterPhoneList.stream().filter((n) -> "100".equals( n.getVisitID())).collect(Collectors.toList());
        // 重复来电
        List<Matter> repetitionPhone = matterPhoneList.stream().filter((n) -> "200".equals( n.getVisitID())).collect(Collectors.toList());

        // 今年群众网上信访
        List<Activity> activityInternetList = activityList.stream().filter((n) -> n.getRegisterTypeID().startsWith("004")).collect(Collectors.toList());
        // 查询今年网上信访
        List<Matter> matterInternetList = new ArrayList<>();
        if (activityInternetList.size() > 0) {
            matterInternetList = matterService.selectMatterList(activityInternetList);
        }
        // 初次网上信访
        List<Matter> firstInternet = matterInternetList.stream().filter((n) -> "100".equals( n.getVisitID())).collect(Collectors.toList());
        // 重复网上信访
        List<Matter> repetitionInternet = matterInternetList.stream().filter((n) -> "200".equals( n.getVisitID())).collect(Collectors.toList());


        // 同比群众信访数据
        List<Activity> lastYearActivityList = activityMapper.selectActivityList(deptIdList,deptId,currYearHBTime,lastYearHBTime);
        List<Matter> mattersHB = new ArrayList();
        // // 查询同比信访事
        if (lastYearActivityList.size()>0) {
            mattersHB = matterService.selectMatterList(lastYearActivityList);
        }
        // 初访
        List<Matter> firstVisitHB = mattersHB.stream().filter((n) -> "100".equals( n.getVisitID())).collect(Collectors.toList());
        // 重访
        List<Matter> repetitionVisitHB = mattersHB.stream().filter((n) -> "200".equals( n.getVisitID())).collect(Collectors.toList());

        // 同比群众来访
        List<Activity> lastYearActivityVisitList = lastYearActivityList.stream().filter((n) -> n.getRegisterTypeID().startsWith("001")).collect(Collectors.toList());
        // 群众来访人数同比
        Integer personSumHB = 0;
        for (Activity activity : lastYearActivityVisitList) {
            personSumHB = personSumHB + activity.getXfNumber();
        }
        // 同比群众来信
        List<Activity> lastYearActivityLetterList = lastYearActivityList.stream().filter((n) -> n.getRegisterTypeID().startsWith("002")).collect(Collectors.toList());
        // 同比群众来电
        List<Activity> lastYearActivityPhoneList = lastYearActivityList.stream().filter((n) -> n.getRegisterTypeID().startsWith("003")).collect(Collectors.toList());
        // 同比群众网上信访
        List<Activity> lastYearActivityInternetList = lastYearActivityList.stream().filter((n) -> n.getRegisterTypeID().startsWith("004")).collect(Collectors.toList());

        // 环比群众信访数据
        List<Activity> TBActivityList = activityMapper.selectActivityList(deptIdList,deptId,currYearTBTime,lastYearTBTime);
        List<Matter> mattersTB = new ArrayList();
        // 查询同比比信访事项
        if (TBActivityList.size()>0) {
            mattersTB = matterService.selectMatterList(TBActivityList);
        }
        // 初访
        List<Matter> firstVisitTB = mattersTB.stream().filter((n) -> "100".equals( n.getVisitID())).collect(Collectors.toList());
        // 重访
        List<Matter> repetitionVisitTB = mattersTB.stream().filter((n) -> "200".equals( n.getVisitID())).collect(Collectors.toList());

        // 环比群众来访
        List<Activity> TBActivityVisitList = TBActivityList.stream().filter((n) -> n.getRegisterTypeID().startsWith("001")).collect(Collectors.toList());
        // 群众来访人数环比
        Integer personSumTB = 0;
        for (Activity activity : TBActivityVisitList) {
            personSumTB = personSumTB + activity.getXfNumber();
        }
        // 环比群众来信
        List<Activity> TBActivityLetterList = TBActivityList.stream().filter((n) -> n.getRegisterTypeID().startsWith("002")).collect(Collectors.toList());
        // 环比群众来电
        List<Activity> TBActivityPhoneList = TBActivityList.stream().filter((n) -> n.getRegisterTypeID().startsWith("003")).collect(Collectors.toList());
        // 环比群众网上信访
        List<Activity> TBActivityInternetList = TBActivityList.stream().filter((n) -> n.getRegisterTypeID().startsWith("004")).collect(Collectors.toList());

        // 今年集体访
        List<Activity> activityCollectiveList = activityList.stream().filter((n) -> n.getXfTypeID().equals("001002")).collect(Collectors.toList());
        // 同比集体访
        List<Activity> lastYearActivityCollectiveList = lastYearActivityList.stream().filter((n) -> n.getXfTypeID().equals("001002")).collect(Collectors.toList());
        // 环比集体访
        List<Activity> TBActivityCollectiveList = TBActivityList.stream().filter((n) -> n.getXfTypeID().equals("001002")).collect(Collectors.toList());

        // 今年联名信
        List<Activity> activityJointlyList = activityList.stream().filter((n) -> n.getXfTypeID().equals("002002")).collect(Collectors.toList());
        // 同比联名信
        List<Activity> lastYearActivityJointlyList = lastYearActivityList.stream().filter((n) -> n.getXfTypeID().equals("002002")).collect(Collectors.toList());
        // 环比联名信
        List<Activity> TBActivityJointlyList = TBActivityList.stream().filter((n) -> n.getXfTypeID().equals("002002")).collect(Collectors.toList());

        // 数字表述
        String content;

        content = "&nbsp;"+ "&nbsp;" + "&nbsp;"+ "&nbsp;" + DateTimeUtils.getYear(startTime) + "年" + DateTimeUtils.getMonth(startTime) + "月" + DateTimeUtils.getDay(startTime) + "日至" + DateTimeUtils.getYear(endTime) + "年" + DateTimeUtils.getMonth(endTime) + "月" + DateTimeUtils.getDay(endTime) + "日，共处理群众信访"+
                activityList.size() + "件批次，环比" + CalculateUtils.IncreaseDecreaseMakeUp(activityList.size(),TBActivityList.size())
                + "%、同比" + CalculateUtils.IncreaseDecreaseMakeUp(activityList.size(),lastYearActivityList.size()) +
                "%。其中，来访" + activityVisitList.size() + "批" + personSum + "人次，批次占本期信访总量" +
                CalculateUtils.makeUp(activityVisitList.size(),activityList.size()) +
                "%,环比" + CalculateUtils.IncreaseDecreaseMakeUp(activityVisitList.size(),TBActivityVisitList.size()) +
                "%、同比" + CalculateUtils.IncreaseDecreaseMakeUp(activityVisitList.size(),lastYearActivityVisitList.size()) +
                "%,人次环比" + CalculateUtils.IncreaseDecreaseMakeUp(personSum,personSumTB) +
                "%、同比" + CalculateUtils.IncreaseDecreaseMakeUp(personSum,personSumHB) +
                "%；来信" + activityLetterList.size() + "件次，占本期信访总量" + CalculateUtils.makeUp(activityLetterList.size(),activityList.size())
                +  "%,环比" + CalculateUtils.IncreaseDecreaseMakeUp(activityLetterList.size(),TBActivityLetterList.size())  +
                "%、同比" + CalculateUtils.IncreaseDecreaseMakeUp(activityLetterList.size(),lastYearActivityLetterList.size()) +
                "%；网上反映" + activityInternetList.size() + "件次，占本期信访总量" + CalculateUtils.makeUp(activityInternetList.size(),activityList.size())
                + "%,环比" + CalculateUtils.IncreaseDecreaseMakeUp(activityInternetList.size(),TBActivityInternetList.size())  +
                "%、同比" + CalculateUtils.IncreaseDecreaseMakeUp(activityInternetList.size(),lastYearActivityInternetList.size()) +
                "%；电话反映" + activityPhoneList.size() + "件次，占本期信访总量" + CalculateUtils.makeUp(activityPhoneList.size(),activityList.size())
                + "%,环比" + CalculateUtils.IncreaseDecreaseMakeUp(activityPhoneList.size(),TBActivityPhoneList.size())  +
                "%、同比"+ CalculateUtils.IncreaseDecreaseMakeUp(activityPhoneList.size(),lastYearActivityPhoneList.size())  + "%。"+ System.getProperty("line.separator") + "&nbsp;"+ "&nbsp;" + "&nbsp;"+ "&nbsp;" +
                "处理的" + activityList.size() + "件批次群众信访，共涉及" + matters.size() +
                "件信访事项,环比" + CalculateUtils.IncreaseDecreaseMakeUp(matters.size(),mattersTB.size()) +
                "%、同比"+ CalculateUtils.IncreaseDecreaseMakeUp(matters.size(),mattersHB.size())  +
                 "%。其中：本系统初次登记" + firstXF.size() + "件，占本期信访事项总量" + CalculateUtils.makeUp(firstXF.size(),matters.size()) +
                "%,环比" +  CalculateUtils.IncreaseDecreaseMakeUp(firstXF.size(),firstVisitTB.size()) +
                "%、同比" + CalculateUtils.IncreaseDecreaseMakeUp(firstXF.size(),firstVisitHB.size()) +"%；重复反映" +
                repetitionXF.size() + "件，占本期信访事项总量" + CalculateUtils.makeUp(repetitionXF.size(),matters.size()) +
                "%,环比" + CalculateUtils.IncreaseDecreaseMakeUp(repetitionXF.size(),repetitionVisitTB.size())  +
                "%、同比" + CalculateUtils.IncreaseDecreaseMakeUp(repetitionXF.size(),repetitionVisitHB.size()) + "%；联名信" +
                + activityJointlyList.size() + "件次，占本期信访总量" + CalculateUtils.makeUp(activityJointlyList.size(),activityList.size())
                +  "%,环比" + CalculateUtils.IncreaseDecreaseMakeUp(activityJointlyList.size(),TBActivityJointlyList.size())  +
                "%、同比" + CalculateUtils.IncreaseDecreaseMakeUp(activityJointlyList.size(),lastYearActivityJointlyList.size()) +
                "%；集体访" + activityCollectiveList.size() + "件次，占本期信访总量" + CalculateUtils.makeUp(activityCollectiveList.size(),activityList.size())
                +  "%,环比" + CalculateUtils.IncreaseDecreaseMakeUp(activityCollectiveList.size(),TBActivityCollectiveList.size()) +
                "%、同比" + CalculateUtils.IncreaseDecreaseMakeUp(activityCollectiveList.size(),lastYearActivityCollectiveList.size()) +
                "%。";

        // 柱状统计图
        List<Object> histogram = new ArrayList();
        // 折线统计图
        HashMap<String, Object> brokenLineGraph = new HashMap<>();


        Integer[] gross = new Integer[]{matters.size(),matterVisitList.size(),matterLetterList.size(),matterInternetList.size(),matterPhoneList.size()};
        Integer[] first = new Integer[]{firstXF.size(),firstVisit.size(),firstLetter.size(),firstInternet.size(),firstPhone.size()};
        Integer[] revisit = new Integer[]{repetitionXF.size(),repetitionVisit.size(),repetitionLetter.size(),repetitionInternet.size(),repetitionPhone.size()};
        String[] firstZB = new String[]{CalculateUtils.makeUp(firstXF.size(),matters.size())+ "%",CalculateUtils.makeUp(firstVisit.size(),matterVisitList.size())+ "%",CalculateUtils.makeUp(firstLetter.size(),matterLetterList.size())+ "%",
                                        CalculateUtils.makeUp(firstInternet.size(),matterInternetList.size())+ "%",CalculateUtils.makeUp(firstPhone.size(),matterPhoneList.size())+ "%",};
        String[] revisitZB = new String[]{CalculateUtils.makeUp(repetitionXF.size(),matters.size())+ "%",CalculateUtils.makeUp(repetitionVisit.size(),matterVisitList.size())+ "%",CalculateUtils.makeUp(repetitionLetter.size(),matterLetterList.size())+ "%",
                CalculateUtils.makeUp(repetitionInternet.size(),matterInternetList.size())+ "%",CalculateUtils.makeUp(repetitionPhone.size(),matterPhoneList.size())+ "%",};

        histogram.add(gross);
        histogram.add(first);
        histogram.add(revisit);
        histogram.add(firstZB);
        histogram.add(revisitZB);

        map.put("histogram",histogram);

        List<Map<String,Object>> pieChart = new ArrayList<>();

        HashMap<String, Object> map1 = new HashMap<>();
        HashMap<String, Object> map2 = new HashMap<>();
        HashMap<String, Object> map3 = new HashMap<>();
        HashMap<String, Object> map4 = new HashMap<>();
        HashMap<String, Object> map5 = new HashMap<>();
        map1.put("name","总量");
        map1.put("count",activityList.size());
        map2.put("name","来访");
        map2.put("count",activityVisitList.size());
        map3.put("name","来电");
        map3.put("count",activityPhoneList.size());
        map4.put("name","来信");
        map4.put("count",activityLetterList.size());
        map5.put("name","网上信访");
        map5.put("count",activityInternetList.size());
        pieChart.add(map1);
        pieChart.add(map2);
        pieChart.add(map3);
        pieChart.add(map4);
        pieChart.add(map5);

        map.put("pieChart",pieChart);

        Integer year = Integer.valueOf(DateTimeUtils.getYear(new Date()));
        Integer lastYear = Integer.valueOf(DateTimeUtils.getYear(new Date())) - 1;
        // 获取今年来访的数量
        List<Activity> thisYearActivityList = activityMapper.selectActivityList(deptIdList,deptId,DateTimeUtils.getCurrYearFirst(),DateTimeUtils.getCurrYearLast());
        // 获取去年来访的数量
        List<Activity> lYearActivityList = activityMapper.selectActivityList(deptIdList,deptId,DateTimeUtils.getYearFirst(lastYear),DateTimeUtils.getYearLast(lastYear));

        List<List<Integer>> grossBrokenLineGraph = new ArrayList();
        List<List<Integer>> visitBrokenLineGraph = new ArrayList();
        List<List<Integer>> letterBrokenLineGraph = new ArrayList();
        List<List<Integer>> phoneBrokenLineGraph = new ArrayList();
        List<List<Integer>> internetBrokenLineGraph = new ArrayList();

        List<Integer> lastYearBrokenLineGraph = new ArrayList();
        List<Integer> thisYearBrokenLineGraph = new ArrayList();

        List<Integer> lastYearVisitBrokenLineGraph = new ArrayList();
        List<Integer> thisYearVisitBrokenLineGraph = new ArrayList();

        List<Integer> lastYearLetterBrokenLineGraph = new ArrayList();
        List<Integer> thisYearLetterBrokenLineGraph = new ArrayList();

        List<Integer> lastYearPhoneBrokenLineGraph = new ArrayList();
        List<Integer> thisYearPhoneBrokenLineGraph = new ArrayList();

        List<Integer> lastYearInternetBrokenLineGraph = new ArrayList();
        List<Integer> thisYearInternetBrokenLineGraph = new ArrayList();


        thisYearBrokenLineGraph.add(thisYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(year,1)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(year,2))).collect(Collectors.toList()).size());
        thisYearBrokenLineGraph.add(thisYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(year,2)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(year,3))).collect(Collectors.toList()).size());
        thisYearBrokenLineGraph.add(thisYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(year,3)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(year,4))).collect(Collectors.toList()).size());
        thisYearBrokenLineGraph.add(thisYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(year,4)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(year,5))).collect(Collectors.toList()).size());
        thisYearBrokenLineGraph.add(thisYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(year,5)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(year,6))).collect(Collectors.toList()).size());
        thisYearBrokenLineGraph.add(thisYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(year,6)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(year,7))).collect(Collectors.toList()).size());
        thisYearBrokenLineGraph.add(thisYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(year,7)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(year,8))).collect(Collectors.toList()).size());
        thisYearBrokenLineGraph.add(thisYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(year,8)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(year,9))).collect(Collectors.toList()).size());
        thisYearBrokenLineGraph.add(thisYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(year,9)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(year,10))).collect(Collectors.toList()).size());
        thisYearBrokenLineGraph.add(thisYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(year,10)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(year,11))).collect(Collectors.toList()).size());
        thisYearBrokenLineGraph.add(thisYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(year,11)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(year,10))).collect(Collectors.toList()).size());
        thisYearBrokenLineGraph.add(thisYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(year,12)) && n.getCreateTime().before(DateTimeUtils.getYearLast(year))).collect(Collectors.toList()).size());

        lastYearBrokenLineGraph.add(lYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(lastYear,1)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(lastYear,2))).collect(Collectors.toList()).size());
        lastYearBrokenLineGraph.add(lYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(lastYear,2)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(lastYear,3))).collect(Collectors.toList()).size());
        lastYearBrokenLineGraph.add(lYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(lastYear,3)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(lastYear,4))).collect(Collectors.toList()).size());
        lastYearBrokenLineGraph.add(lYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(lastYear,4)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(lastYear,5))).collect(Collectors.toList()).size());
        lastYearBrokenLineGraph.add(lYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(lastYear,5)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(lastYear,6))).collect(Collectors.toList()).size());
        lastYearBrokenLineGraph.add(lYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(lastYear,6)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(lastYear,7))).collect(Collectors.toList()).size());
        lastYearBrokenLineGraph.add(lYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(lastYear,7)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(lastYear,8))).collect(Collectors.toList()).size());
        lastYearBrokenLineGraph.add(lYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(lastYear,8)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(lastYear,9))).collect(Collectors.toList()).size());
        lastYearBrokenLineGraph.add(lYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(lastYear,9)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(lastYear,10))).collect(Collectors.toList()).size());
        lastYearBrokenLineGraph.add(lYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(lastYear,10)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(lastYear,11))).collect(Collectors.toList()).size());
        lastYearBrokenLineGraph.add(lYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(lastYear,11)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(lastYear,10))).collect(Collectors.toList()).size());
        lastYearBrokenLineGraph.add(lYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(lastYear,12)) && n.getCreateTime().before(DateTimeUtils.getYearLast(lastYear))).collect(Collectors.toList()).size());

        grossBrokenLineGraph.add(thisYearBrokenLineGraph);
        grossBrokenLineGraph.add(lastYearBrokenLineGraph);

        thisYearVisitBrokenLineGraph.add(thisYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(year,1)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(year,2)) && n.getRegisterTypeID().startsWith("001")).collect(Collectors.toList()).size());
        thisYearVisitBrokenLineGraph.add(thisYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(year,2)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(year,3)) && n.getRegisterTypeID().startsWith("001")).collect(Collectors.toList()).size());
        thisYearVisitBrokenLineGraph.add(thisYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(year,3)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(year,4)) && n.getRegisterTypeID().startsWith("001")).collect(Collectors.toList()).size());
        thisYearVisitBrokenLineGraph.add(thisYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(year,4)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(year,5)) && n.getRegisterTypeID().startsWith("001")).collect(Collectors.toList()).size());
        thisYearVisitBrokenLineGraph.add(thisYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(year,5)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(year,6)) && n.getRegisterTypeID().startsWith("001")).collect(Collectors.toList()).size());
        thisYearVisitBrokenLineGraph.add(thisYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(year,6)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(year,7)) && n.getRegisterTypeID().startsWith("001")).collect(Collectors.toList()).size());
        thisYearVisitBrokenLineGraph.add(thisYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(year,7)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(year,8)) && n.getRegisterTypeID().startsWith("001")).collect(Collectors.toList()).size());
        thisYearVisitBrokenLineGraph.add(thisYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(year,8)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(year,9)) && n.getRegisterTypeID().startsWith("001")).collect(Collectors.toList()).size());
        thisYearVisitBrokenLineGraph.add(thisYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(year,9)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(year,10)) && n.getRegisterTypeID().startsWith("001")).collect(Collectors.toList()).size());
        thisYearVisitBrokenLineGraph.add(thisYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(year,10)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(year,11)) && n.getRegisterTypeID().startsWith("001")).collect(Collectors.toList()).size());
        thisYearVisitBrokenLineGraph.add(thisYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(year,11)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(year,10)) && n.getRegisterTypeID().startsWith("001")).collect(Collectors.toList()).size());
        thisYearVisitBrokenLineGraph.add(thisYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(year,12)) && n.getCreateTime().before(DateTimeUtils.getYearLast(year)) && n.getRegisterTypeID().startsWith("001")).collect(Collectors.toList()).size());

        lastYearVisitBrokenLineGraph.add(lYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(lastYear,1)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(lastYear,2)) && n.getRegisterTypeID().startsWith("001")).collect(Collectors.toList()).size());
        lastYearVisitBrokenLineGraph.add(lYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(lastYear,2)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(lastYear,3)) && n.getRegisterTypeID().startsWith("001")).collect(Collectors.toList()).size());
        lastYearVisitBrokenLineGraph.add(lYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(lastYear,3)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(lastYear,4)) && n.getRegisterTypeID().startsWith("001")).collect(Collectors.toList()).size());
        lastYearVisitBrokenLineGraph.add(lYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(lastYear,4)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(lastYear,5)) && n.getRegisterTypeID().startsWith("001")).collect(Collectors.toList()).size());
        lastYearVisitBrokenLineGraph.add(lYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(lastYear,5)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(lastYear,6)) && n.getRegisterTypeID().startsWith("001")).collect(Collectors.toList()).size());
        lastYearVisitBrokenLineGraph.add(lYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(lastYear,6)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(lastYear,7)) && n.getRegisterTypeID().startsWith("001")).collect(Collectors.toList()).size());
        lastYearVisitBrokenLineGraph.add(lYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(lastYear,7)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(lastYear,8)) && n.getRegisterTypeID().startsWith("001")).collect(Collectors.toList()).size());
        lastYearVisitBrokenLineGraph.add(lYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(lastYear,8)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(lastYear,9)) && n.getRegisterTypeID().startsWith("001")).collect(Collectors.toList()).size());
        lastYearVisitBrokenLineGraph.add(lYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(lastYear,9)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(lastYear,10)) && n.getRegisterTypeID().startsWith("001")).collect(Collectors.toList()).size());
        lastYearVisitBrokenLineGraph.add(lYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(lastYear,10)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(lastYear,11)) && n.getRegisterTypeID().startsWith("001")).collect(Collectors.toList()).size());
        lastYearVisitBrokenLineGraph.add(lYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(lastYear,11)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(lastYear,10)) && n.getRegisterTypeID().startsWith("001")).collect(Collectors.toList()).size());
        lastYearVisitBrokenLineGraph.add(lYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(lastYear,12)) && n.getCreateTime().before(DateTimeUtils.getYearLast(lastYear)) && n.getRegisterTypeID().startsWith("001")).collect(Collectors.toList()).size());

        visitBrokenLineGraph.add(thisYearVisitBrokenLineGraph);
        visitBrokenLineGraph.add(lastYearVisitBrokenLineGraph);

        thisYearLetterBrokenLineGraph.add(thisYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(year,1)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(year,2)) && n.getRegisterTypeID().startsWith("002")).collect(Collectors.toList()).size());
        thisYearLetterBrokenLineGraph.add(thisYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(year,2)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(year,3)) && n.getRegisterTypeID().startsWith("002")).collect(Collectors.toList()).size());
        thisYearLetterBrokenLineGraph.add(thisYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(year,3)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(year,4)) && n.getRegisterTypeID().startsWith("002")).collect(Collectors.toList()).size());
        thisYearLetterBrokenLineGraph.add(thisYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(year,4)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(year,5)) && n.getRegisterTypeID().startsWith("002")).collect(Collectors.toList()).size());
        thisYearLetterBrokenLineGraph.add(thisYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(year,5)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(year,6)) && n.getRegisterTypeID().startsWith("002")).collect(Collectors.toList()).size());
        thisYearLetterBrokenLineGraph.add(thisYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(year,6)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(year,7)) && n.getRegisterTypeID().startsWith("002")).collect(Collectors.toList()).size());
        thisYearLetterBrokenLineGraph.add(thisYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(year,7)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(year,8)) && n.getRegisterTypeID().startsWith("002")).collect(Collectors.toList()).size());
        thisYearLetterBrokenLineGraph.add(thisYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(year,8)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(year,9)) && n.getRegisterTypeID().startsWith("002")).collect(Collectors.toList()).size());
        thisYearLetterBrokenLineGraph.add(thisYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(year,9)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(year,10)) && n.getRegisterTypeID().startsWith("002")).collect(Collectors.toList()).size());
        thisYearLetterBrokenLineGraph.add(thisYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(year,10)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(year,11)) && n.getRegisterTypeID().startsWith("002")).collect(Collectors.toList()).size());
        thisYearLetterBrokenLineGraph.add(thisYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(year,11)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(year,10)) && n.getRegisterTypeID().startsWith("002")).collect(Collectors.toList()).size());
        thisYearLetterBrokenLineGraph.add(thisYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(year,12)) && n.getCreateTime().before(DateTimeUtils.getYearLast(year)) && n.getRegisterTypeID().startsWith("002")).collect(Collectors.toList()).size());

        lastYearLetterBrokenLineGraph.add(lYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(lastYear,1)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(lastYear,2)) && n.getRegisterTypeID().startsWith("002")).collect(Collectors.toList()).size());
        lastYearLetterBrokenLineGraph.add(lYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(lastYear,2)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(lastYear,3)) && n.getRegisterTypeID().startsWith("002")).collect(Collectors.toList()).size());
        lastYearLetterBrokenLineGraph.add(lYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(lastYear,3)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(lastYear,4)) && n.getRegisterTypeID().startsWith("002")).collect(Collectors.toList()).size());
        lastYearLetterBrokenLineGraph.add(lYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(lastYear,4)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(lastYear,5)) && n.getRegisterTypeID().startsWith("002")).collect(Collectors.toList()).size());
        lastYearLetterBrokenLineGraph.add(lYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(lastYear,5)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(lastYear,6)) && n.getRegisterTypeID().startsWith("002")).collect(Collectors.toList()).size());
        lastYearLetterBrokenLineGraph.add(lYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(lastYear,6)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(lastYear,7)) && n.getRegisterTypeID().startsWith("002")).collect(Collectors.toList()).size());
        lastYearLetterBrokenLineGraph.add(lYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(lastYear,7)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(lastYear,8)) && n.getRegisterTypeID().startsWith("002")).collect(Collectors.toList()).size());
        lastYearLetterBrokenLineGraph.add(lYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(lastYear,8)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(lastYear,9)) && n.getRegisterTypeID().startsWith("002")).collect(Collectors.toList()).size());
        lastYearLetterBrokenLineGraph.add(lYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(lastYear,9)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(lastYear,10)) && n.getRegisterTypeID().startsWith("002")).collect(Collectors.toList()).size());
        lastYearLetterBrokenLineGraph.add(lYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(lastYear,10)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(lastYear,11)) && n.getRegisterTypeID().startsWith("002")).collect(Collectors.toList()).size());
        lastYearLetterBrokenLineGraph.add(lYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(lastYear,11)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(lastYear,10)) && n.getRegisterTypeID().startsWith("002")).collect(Collectors.toList()).size());
        lastYearLetterBrokenLineGraph.add(lYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(lastYear,12)) && n.getCreateTime().before(DateTimeUtils.getYearLast(lastYear)) && n.getRegisterTypeID().startsWith("002")).collect(Collectors.toList()).size());

        letterBrokenLineGraph.add(thisYearLetterBrokenLineGraph);
        letterBrokenLineGraph.add(lastYearLetterBrokenLineGraph);

        thisYearPhoneBrokenLineGraph.add(thisYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(year,1)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(year,2)) && n.getRegisterTypeID().startsWith("003")).collect(Collectors.toList()).size());
        thisYearPhoneBrokenLineGraph.add(thisYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(year,2)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(year,3)) && n.getRegisterTypeID().startsWith("003")).collect(Collectors.toList()).size());
        thisYearPhoneBrokenLineGraph.add(thisYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(year,3)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(year,4)) && n.getRegisterTypeID().startsWith("003")).collect(Collectors.toList()).size());
        thisYearPhoneBrokenLineGraph.add(thisYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(year,4)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(year,5)) && n.getRegisterTypeID().startsWith("003")).collect(Collectors.toList()).size());
        thisYearPhoneBrokenLineGraph.add(thisYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(year,5)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(year,6)) && n.getRegisterTypeID().startsWith("003")).collect(Collectors.toList()).size());
        thisYearPhoneBrokenLineGraph.add(thisYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(year,6)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(year,7)) && n.getRegisterTypeID().startsWith("003")).collect(Collectors.toList()).size());
        thisYearPhoneBrokenLineGraph.add(thisYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(year,7)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(year,8)) && n.getRegisterTypeID().startsWith("003")).collect(Collectors.toList()).size());
        thisYearPhoneBrokenLineGraph.add(thisYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(year,8)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(year,9)) && n.getRegisterTypeID().startsWith("003")).collect(Collectors.toList()).size());
        thisYearPhoneBrokenLineGraph.add(thisYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(year,9)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(year,10)) && n.getRegisterTypeID().startsWith("003")).collect(Collectors.toList()).size());
        thisYearPhoneBrokenLineGraph.add(thisYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(year,10)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(year,11)) && n.getRegisterTypeID().startsWith("003")).collect(Collectors.toList()).size());
        thisYearPhoneBrokenLineGraph.add(thisYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(year,11)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(year,10)) && n.getRegisterTypeID().startsWith("003")).collect(Collectors.toList()).size());
        thisYearPhoneBrokenLineGraph.add(thisYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(year,12)) && n.getCreateTime().before(DateTimeUtils.getYearLast(year)) && n.getRegisterTypeID().startsWith("003")).collect(Collectors.toList()).size());

        lastYearPhoneBrokenLineGraph.add(lYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(lastYear,1)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(lastYear,2)) && n.getRegisterTypeID().startsWith("003")).collect(Collectors.toList()).size());
        lastYearPhoneBrokenLineGraph.add(lYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(lastYear,2)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(lastYear,3)) && n.getRegisterTypeID().startsWith("003")).collect(Collectors.toList()).size());
        lastYearPhoneBrokenLineGraph.add(lYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(lastYear,3)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(lastYear,4)) && n.getRegisterTypeID().startsWith("003")).collect(Collectors.toList()).size());
        lastYearPhoneBrokenLineGraph.add(lYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(lastYear,4)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(lastYear,5)) && n.getRegisterTypeID().startsWith("003")).collect(Collectors.toList()).size());
        lastYearPhoneBrokenLineGraph.add(lYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(lastYear,5)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(lastYear,6)) && n.getRegisterTypeID().startsWith("003")).collect(Collectors.toList()).size());
        lastYearPhoneBrokenLineGraph.add(lYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(lastYear,6)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(lastYear,7)) && n.getRegisterTypeID().startsWith("003")).collect(Collectors.toList()).size());
        lastYearPhoneBrokenLineGraph.add(lYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(lastYear,7)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(lastYear,8)) && n.getRegisterTypeID().startsWith("003")).collect(Collectors.toList()).size());
        lastYearPhoneBrokenLineGraph.add(lYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(lastYear,8)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(lastYear,9)) && n.getRegisterTypeID().startsWith("003")).collect(Collectors.toList()).size());
        lastYearPhoneBrokenLineGraph.add(lYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(lastYear,9)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(lastYear,10)) && n.getRegisterTypeID().startsWith("003")).collect(Collectors.toList()).size());
        lastYearPhoneBrokenLineGraph.add(lYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(lastYear,10)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(lastYear,11)) && n.getRegisterTypeID().startsWith("003")).collect(Collectors.toList()).size());
        lastYearPhoneBrokenLineGraph.add(lYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(lastYear,11)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(lastYear,10)) && n.getRegisterTypeID().startsWith("003")).collect(Collectors.toList()).size());
        lastYearPhoneBrokenLineGraph.add(lYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(lastYear,12)) && n.getCreateTime().before(DateTimeUtils.getYearLast(lastYear)) && n.getRegisterTypeID().startsWith("003")).collect(Collectors.toList()).size());

        phoneBrokenLineGraph.add(thisYearPhoneBrokenLineGraph);
        phoneBrokenLineGraph.add(lastYearPhoneBrokenLineGraph);

        thisYearInternetBrokenLineGraph.add(thisYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(year,1)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(year,2)) && n.getRegisterTypeID().startsWith("004")).collect(Collectors.toList()).size());
        thisYearInternetBrokenLineGraph.add(thisYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(year,2)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(year,3)) && n.getRegisterTypeID().startsWith("004")).collect(Collectors.toList()).size());
        thisYearInternetBrokenLineGraph.add(thisYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(year,3)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(year,4)) && n.getRegisterTypeID().startsWith("004")).collect(Collectors.toList()).size());
        thisYearInternetBrokenLineGraph.add(thisYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(year,4)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(year,5)) && n.getRegisterTypeID().startsWith("004")).collect(Collectors.toList()).size());
        thisYearInternetBrokenLineGraph.add(thisYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(year,5)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(year,6)) && n.getRegisterTypeID().startsWith("004")).collect(Collectors.toList()).size());
        thisYearInternetBrokenLineGraph.add(thisYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(year,6)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(year,7)) && n.getRegisterTypeID().startsWith("004")).collect(Collectors.toList()).size());
        thisYearInternetBrokenLineGraph.add(thisYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(year,7)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(year,8)) && n.getRegisterTypeID().startsWith("004")).collect(Collectors.toList()).size());
        thisYearInternetBrokenLineGraph.add(thisYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(year,8)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(year,9)) && n.getRegisterTypeID().startsWith("004")).collect(Collectors.toList()).size());
        thisYearInternetBrokenLineGraph.add(thisYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(year,9)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(year,10)) && n.getRegisterTypeID().startsWith("004")).collect(Collectors.toList()).size());
        thisYearInternetBrokenLineGraph.add(thisYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(year,10)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(year,11)) && n.getRegisterTypeID().startsWith("004")).collect(Collectors.toList()).size());
        thisYearInternetBrokenLineGraph.add(thisYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(year,11)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(year,10)) && n.getRegisterTypeID().startsWith("004")).collect(Collectors.toList()).size());
        thisYearInternetBrokenLineGraph.add(thisYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(year,12)) && n.getCreateTime().before(DateTimeUtils.getYearLast(year)) && n.getRegisterTypeID().startsWith("004")).collect(Collectors.toList()).size());

        lastYearInternetBrokenLineGraph.add(lYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(lastYear,1)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(lastYear,2)) && n.getRegisterTypeID().startsWith("004")).collect(Collectors.toList()).size());
        lastYearInternetBrokenLineGraph.add(lYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(lastYear,2)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(lastYear,3)) && n.getRegisterTypeID().startsWith("004")).collect(Collectors.toList()).size());
        lastYearInternetBrokenLineGraph.add(lYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(lastYear,3)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(lastYear,4)) && n.getRegisterTypeID().startsWith("004")).collect(Collectors.toList()).size());
        lastYearInternetBrokenLineGraph.add(lYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(lastYear,4)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(lastYear,5)) && n.getRegisterTypeID().startsWith("004")).collect(Collectors.toList()).size());
        lastYearInternetBrokenLineGraph.add(lYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(lastYear,5)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(lastYear,6)) && n.getRegisterTypeID().startsWith("004")).collect(Collectors.toList()).size());
        lastYearInternetBrokenLineGraph.add(lYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(lastYear,6)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(lastYear,7)) && n.getRegisterTypeID().startsWith("004")).collect(Collectors.toList()).size());
        lastYearInternetBrokenLineGraph.add(lYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(lastYear,7)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(lastYear,8)) && n.getRegisterTypeID().startsWith("004")).collect(Collectors.toList()).size());
        lastYearInternetBrokenLineGraph.add(lYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(lastYear,8)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(lastYear,9)) && n.getRegisterTypeID().startsWith("004")).collect(Collectors.toList()).size());
        lastYearInternetBrokenLineGraph.add(lYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(lastYear,9)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(lastYear,10)) && n.getRegisterTypeID().startsWith("004")).collect(Collectors.toList()).size());
        lastYearInternetBrokenLineGraph.add(lYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(lastYear,10)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(lastYear,11)) && n.getRegisterTypeID().startsWith("004")).collect(Collectors.toList()).size());
        lastYearInternetBrokenLineGraph.add(lYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(lastYear,11)) && n.getCreateTime().before(DateTimeUtils.getMonthDay(lastYear,10)) && n.getRegisterTypeID().startsWith("004")).collect(Collectors.toList()).size());
        lastYearInternetBrokenLineGraph.add(lYearActivityList.stream().filter(n -> n.getCreateTime().after(DateTimeUtils.getMonthDay(lastYear,12)) && n.getCreateTime().before(DateTimeUtils.getYearLast(lastYear)) && n.getRegisterTypeID().startsWith("004")).collect(Collectors.toList()).size());

        internetBrokenLineGraph.add(thisYearInternetBrokenLineGraph);
        internetBrokenLineGraph.add(lastYearInternetBrokenLineGraph);

        brokenLineGraph.put("grossBrokenLineGraph",grossBrokenLineGraph);
        brokenLineGraph.put("visitBrokenLineGraph",visitBrokenLineGraph);
        brokenLineGraph.put("letterBrokenLineGraph",letterBrokenLineGraph);
        brokenLineGraph.put("phoneBrokenLineGraph",phoneBrokenLineGraph);
        brokenLineGraph.put("internetBrokenLineGraph",internetBrokenLineGraph);

        map.put("brokenLineGraph",brokenLineGraph);
        map.put("content",content);

        return map;
    }

    @Override
    public LinkedList<ActivityDTO> selectByActivityDtoToExport(ActivityVO activityVO) {
        return activityMapper.selectByActivityDtoToExport(activityVO);
    }

    @Override
    public List<ActivityVO> selectByXFZBToExport(ActivityVO activityVO) {
        return activityMapper.selectByXFZBToExport(activityVO);
    }

    @Override
    public List<XfzbDTO> excludeExcelXfzb(ActivityVO activityVO) throws ParseException {


        List<ActivityVO> list =  activityMapper.selectByXFZBToExport(activityVO);
        //去重
        List<ActivityVO> aList = list.stream().collect(
                Collectors.collectingAndThen(
                        Collectors.toCollection(() -> new TreeSet<>(Comparator.comparing(ActivityVO::getId))), ArrayList::new)
        );

        //设置同比时间
        activityVO.setStartTime(activityVO.getOrgStartTime());
        activityVO.setEndTime(activityVO.getOrgEndTime());

        List<ActivityVO> orgList =  activityMapper.selectByXFZBToExport(activityVO);
        List<ActivityVO> aOrgList = orgList.stream().collect(
                Collectors.collectingAndThen(
                        Collectors.toCollection(() -> new TreeSet<>(Comparator.comparing(ActivityVO::getId))), ArrayList::new)
        );

        //当年总数
        activityVO.setStartTime(DateTimeUtils.formatDate(DateTimeUtils.getCurrYearFirst()));
        activityVO.setEndTime(DateTimeUtils.formatDate(new Date()));
        List<ActivityVO> curYearList =  activityMapper.selectByXFZBToExport(activityVO);
        List<ActivityVO> aCurYearList = curYearList.stream().collect(
                Collectors.collectingAndThen(
                        Collectors.toCollection(() -> new TreeSet<>(Comparator.comparing(ActivityVO::getId))), ArrayList::new)
        );


        //去年总数
        activityVO.setStartTime(DateTimeUtils.getOrgStartTime());
        activityVO.setEndTime(DateTimeUtils.getOrgEndTime());
        List<ActivityVO> orgYearList =  activityMapper.selectByXFZBToExport(activityVO);
        List<ActivityVO> aOrgYearList = orgYearList.stream().collect(
                Collectors.collectingAndThen(
                        Collectors.toCollection(() -> new TreeSet<>(Comparator.comparing(ActivityVO::getId))), ArrayList::new)
        );

        Integer curSum;
        Integer curYear;
        Integer orgSum;
        Integer orgYear;
        List<XfzbDTO> xfzbDTOS = new LinkedList<>();

        //去重活动总数
        Integer size = aList.size();
        Integer orgSize = aOrgList.size();

        //去重A 信访人员集合
        Integer a1 = aList.stream().collect(Collectors.summingInt(ActivityVO::getXfNumber));
        curYear = aCurYearList.stream().collect(Collectors.summingInt(ActivityVO::getXfNumber));
        Integer orgA1 = aOrgList.stream().collect(Collectors.summingInt(ActivityVO::getXfNumber));
        orgYear = aOrgYearList.stream().collect(Collectors.summingInt(ActivityVO::getXfNumber));
        //xfzbDTOS.add(addXfzbDto("信访总量件人次", curSum, curYear, orgSum, orgYear));

        xfzbDTOS.add(addXfzbDto("信访总量件批次", list.size(), curYearList.size(), orgList.size(), orgYearList.size(),0,0));

        //初次信访件批次
        curSum = list.stream().filter(p -> "100".equals(p.getVisitID())).collect(Collectors.toList()).size();
        curYear = curYearList.stream().filter(p -> "100".equals(p.getVisitID())).collect(Collectors.toList()).size();
        orgSum = orgList.stream().filter(p -> "100".equals(p.getVisitID())).collect(Collectors.toList()).size();
        orgYear = orgYearList.stream().filter(p -> "100".equals(p.getVisitID())).collect(Collectors.toList()).size();
        xfzbDTOS.add(addXfzbDto("初次信访件批次", curSum, curYear, orgSum, orgYear, list.size(), orgList.size()));
        //重复信访件批次
        curSum = list.stream().filter(p -> "200".equals(p.getVisitID())).collect(Collectors.toList()).size();
        curYear = curYearList.stream().filter(p -> "200".equals(p.getVisitID())).collect(Collectors.toList()).size();
        orgSum = orgList.stream().filter(p -> "200".equals(p.getVisitID())).collect(Collectors.toList()).size();
        orgYear = orgYearList.stream().filter(p -> "200".equals(p.getVisitID())).collect(Collectors.toList()).size();
        xfzbDTOS.add(addXfzbDto("重复信访件批次", curSum, curYear, orgSum, orgYear,  list.size(), orgList.size()));
        //来信件次
        curSum = aList.stream().filter(p -> "002".equals(p.getRegisterTypeID())).collect(Collectors.toList()).size();
        curYear = aCurYearList.stream().filter(p -> "002".equals(p.getRegisterTypeID())).collect(Collectors.toList()).size();
        orgSum = aOrgList.stream().filter(p -> "002".equals(p.getRegisterTypeID())).collect(Collectors.toList()).size();
        orgYear = aOrgYearList.stream().filter(p -> "002".equals(p.getRegisterTypeID())).collect(Collectors.toList()).size();
        xfzbDTOS.add(addXfzbDto("来信件次", curSum, curYear, orgSum, orgYear, size, orgSize));
        //联名信件次  xfTypeID=002002
        curSum = aList.stream().filter(p -> "002002".equals(p.getXfTypeID())).collect(Collectors.toList()).size();
        curYear = aCurYearList.stream().filter(p -> "002002".equals(p.getXfTypeID())).collect(Collectors.toList()).size();
        orgSum = aOrgList.stream().filter(p -> "002002".equals(p.getXfTypeID())).collect(Collectors.toList()).size();
        orgYear = aOrgYearList.stream().filter(p -> "002002".equals(p.getXfTypeID())).collect(Collectors.toList()).size();
        xfzbDTOS.add(addXfzbDto("联名信件次", curSum, curYear, orgSum, orgYear,size, orgSize));
        //扬言信件次
        curSum = getSum(aList.stream().filter(p -> StringUtils.isNotEmpty(p.getAbnormalID())).collect(Collectors.toList()), "002001");
        curYear = getSum(aCurYearList.stream().filter(p -> StringUtils.isNotEmpty(p.getAbnormalID())).collect(Collectors.toList()), "002001");
        orgSum =  getSum(aOrgList.stream().filter(p -> StringUtils.isNotEmpty(p.getAbnormalID())).collect(Collectors.toList()),"002001");
        orgYear =  getSum(aOrgYearList.stream().filter(p -> StringUtils.isNotEmpty(p.getAbnormalID())).collect(Collectors.toList()),"002001");
        xfzbDTOS.add(addXfzbDto("扬言信件次", curSum, curYear, orgSum, orgYear,size, orgSize));
        //来访批次  activity.registerTypeID=001
        curSum = aList.stream().filter(p -> "001".equals(p.getRegisterTypeID())).collect(Collectors.toList()).size();
        curYear = aCurYearList.stream().filter(p -> "001".equals(p.getRegisterTypeID())).collect(Collectors.toList()).size();
        orgSum = aOrgList.stream().filter(p -> "001".equals(p.getRegisterTypeID())).collect(Collectors.toList()).size();
        orgYear = aOrgYearList.stream().filter(p -> "001".equals(p.getRegisterTypeID())).collect(Collectors.toList()).size();
        xfzbDTOS.add(addXfzbDto("来访批次", curSum, curYear, orgSum, orgYear, size, orgSize));
        //来访人次 activity.registerTypeID=001  activity.xfNumber
        curSum = aList.stream().filter(p-> "001".equals(p.getRegisterTypeID())).collect(Collectors.summingInt(ActivityVO::getXfNumber));
        curYear = aCurYearList.stream().filter(p-> "001".equals(p.getRegisterTypeID())).collect(Collectors.summingInt(ActivityVO::getXfNumber));
        orgSum = aOrgList.stream().filter(p-> "001".equals(p.getRegisterTypeID())).collect(Collectors.summingInt(ActivityVO::getXfNumber));
        orgYear = aOrgYearList.stream().filter(p-> "001".equals(p.getRegisterTypeID())).collect(Collectors.summingInt(ActivityVO::getXfNumber));
        xfzbDTOS.add(addXfzbDto("来访人次", curSum, curYear, orgSum, orgYear, a1 ,orgA1));
        //集体访批次 xfTypeID=001002
        curSum = aList.stream().filter(p -> "001002".equals(p.getXfTypeID())).collect(Collectors.toList()).size();
        curYear = aCurYearList.stream().filter(p -> "001002".equals(p.getXfTypeID())).collect(Collectors.toList()).size();
        orgSum = aOrgList.stream().filter(p -> "001002".equals(p.getXfTypeID())).collect(Collectors.toList()).size();
        orgYear = aOrgYearList.stream().filter(p -> "001002".equals(p.getXfTypeID())).collect(Collectors.toList()).size();
        xfzbDTOS.add(addXfzbDto("集体访批次", curSum, curYear, orgSum, orgYear, size, orgSize));
        //集体访人次 xfTypeID=001002 activity.xfNumber
        curSum = aList.stream().filter(p-> "001002".equals(p.getXfTypeID())).collect(Collectors.summingInt(ActivityVO::getXfNumber));
        curYear = aCurYearList.stream().filter(p-> "001002".equals(p.getXfTypeID())).collect(Collectors.summingInt(ActivityVO::getXfNumber));
        orgSum = aOrgList.stream().filter(p-> "001002".equals(p.getXfTypeID())).collect(Collectors.summingInt(ActivityVO::getXfNumber));
        orgYear = aOrgYearList.stream().filter(p-> "001002".equals(p.getXfTypeID())).collect(Collectors.summingInt(ActivityVO::getXfNumber));
        xfzbDTOS.add(addXfzbDto("集体访人次", curSum, curYear, orgSum, orgYear, a1 ,orgA1));
        //异常访批次  activity.registerTypeID=001  activity.isAbnormal=1
        curSum = aList.stream().filter(p -> "001".equals(p.getRegisterTypeID()) && "1".equals(p.getIsAbnormal())).collect(Collectors.toList()).size();
        curYear = aCurYearList.stream().filter(p -> "001".equals(p.getRegisterTypeID()) && "1".equals(p.getIsAbnormal())).collect(Collectors.toList()).size();
        orgSum = aOrgList.stream().filter(p -> "001".equals(p.getRegisterTypeID()) && "1".equals(p.getIsAbnormal())).collect(Collectors.toList()).size();
        orgYear = aOrgYearList.stream().filter(p -> "001".equals(p.getRegisterTypeID()) && "1".equals(p.getIsAbnormal())).collect(Collectors.toList()).size();
        xfzbDTOS.add(addXfzbDto("异常访批次", curSum, curYear, orgSum, orgYear, size, orgSize));
        //异常访人次  activity.registerTypeID=001  activity.isAbnormal=1  activity.xfNumber
        curSum = aList.stream().filter(p -> "001".equals(p.getRegisterTypeID()) && "1".equals(p.getIsAbnormal())).collect(Collectors.summingInt(ActivityVO::getXfNumber));
        curYear = aCurYearList.stream().filter(p -> "001".equals(p.getRegisterTypeID()) && "1".equals(p.getIsAbnormal())).collect(Collectors.summingInt(ActivityVO::getXfNumber));
        orgSum = aOrgList.stream().filter(p -> "001".equals(p.getRegisterTypeID()) && "1".equals(p.getIsAbnormal())).collect(Collectors.summingInt(ActivityVO::getXfNumber));
        orgYear = aOrgYearList.stream().filter(p -> "001".equals(p.getRegisterTypeID()) && "1".equals(p.getIsAbnormal())).collect(Collectors.summingInt(ActivityVO::getXfNumber));
        xfzbDTOS.add(addXfzbDto("异常访人次", curSum, curYear, orgSum, orgYear , a1 ,orgA1));
        //网上反映件次  activity.registerTypeID=004
        curSum = aList.stream().filter(p -> "004".equals(p.getRegisterTypeID())).collect(Collectors.toList()).size();
        curYear = aCurYearList.stream().filter(p -> "004".equals(p.getRegisterTypeID())).collect(Collectors.toList()).size();
        orgSum = aOrgList.stream().filter(p -> "004".equals(p.getRegisterTypeID())).collect(Collectors.toList()).size();
        orgYear = aOrgYearList.stream().filter(p -> "004".equals(p.getRegisterTypeID())).collect(Collectors.toList()).size();
        xfzbDTOS.add(addXfzbDto("网上反映件次", curSum, curYear, orgSum, orgYear , size, orgSize));
        //网上反映扬言件次activity.abnormalID=004001%  字符串转数组
        curSum =getSum(aList.stream().filter(p -> StringUtils.isNotEmpty(p.getAbnormalID())).collect(Collectors.toList()),"004001");
        curYear = getSum(aCurYearList.stream().filter(p -> StringUtils.isNotEmpty(p.getAbnormalID())).collect(Collectors.toList()),"004001");
        orgSum =  getSum(aOrgList.stream().filter(p -> StringUtils.isNotEmpty(p.getAbnormalID())).collect(Collectors.toList()),"004001");
        orgYear =  getSum(aOrgYearList.stream().filter(p -> StringUtils.isNotEmpty(p.getAbnormalID())).collect(Collectors.toList()),"004001");
        xfzbDTOS.add(addXfzbDto("网上反映扬言件次", curSum, curYear, orgSum, orgYear, size, orgSize));
        //来电件次  activity.registerTypeID=003
        curSum = aList.stream().filter(p -> "003".equals(p.getRegisterTypeID())).collect(Collectors.toList()).size();
        curYear = aCurYearList.stream().filter(p -> "003".equals(p.getRegisterTypeID())).collect(Collectors.toList()).size();
        orgSum = aOrgList.stream().filter(p -> "003".equals(p.getRegisterTypeID())).collect(Collectors.toList()).size();
        orgYear = aOrgYearList.stream().filter(p -> "003".equals(p.getRegisterTypeID())).collect(Collectors.toList()).size();
        xfzbDTOS.add(addXfzbDto("来电件次", curSum, curYear, orgSum, orgYear, size, orgSize));
        //来电扬言件次 activity.abnormalID=003001%  字符串转数组
        curSum = getSum(aList.stream().filter(p -> StringUtils.isNotEmpty(p.getAbnormalID())).collect(Collectors.toList()),"003001");
        curYear = getSum(aCurYearList.stream().filter(p -> StringUtils.isNotEmpty(p.getAbnormalID())).collect(Collectors.toList()),"003001");
        orgSum =  getSum(aOrgList.stream().filter(p -> StringUtils.isNotEmpty(p.getAbnormalID())).collect(Collectors.toList()),"003001");
        orgYear =  getSum(aOrgYearList.stream().filter(p -> StringUtils.isNotEmpty(p.getAbnormalID())).collect(Collectors.toList()),"003001");
        xfzbDTOS.add(addXfzbDto("来电扬言件次", curSum, curYear, orgSum, orgYear, size, orgSize));

        return xfzbDTOS;
    }

    @Override
    public LinkedList<Map> excludeExcelXfdj(ActivityVO activityVO, int type) {
        LinkedList<Map> res =new LinkedList<>();

        List<ActivityVO> list = activityMapper.selectByXfdj(activityVO);
        Map<String, List<ActivityVO>> collect = list.stream().collect(Collectors.groupingBy(ActivityVO::getType));

        activityVO.setStartTime(activityVO.getOrgStartTime());
        activityVO.setEndTime(activityVO.getOrgEndTime());
        List<ActivityVO> orgList = activityMapper.selectByXfdj(activityVO);
        Map<String, List<ActivityVO>> orgCollect = orgList.stream().collect(Collectors.groupingBy(ActivityVO::getType));

        for (int i = type; i <= 5; i++) {
            Map map = new HashMap();
            List<ActivityVO> a = collect.get(i+"");
            List<ActivityVO> b = orgCollect.get(i+"");
            a = a == null ? new ArrayList<ActivityVO>() : a;
            b = b == null ? new ArrayList<ActivityVO>() : b;
            if(i == 5){
                //最后计算合计
                a = list;
                b = orgList;
                if(type == 3){
                    a = list.stream().filter(p-> !"2".equals(p.getType())).collect(Collectors.toList());
                    b = orgList.stream().filter(p-> !"2".equals(p.getType())).collect(Collectors.toList());
                }
            }
            map.put("xfjc", a.size());
            map.put("xftb", getPercent(a.size(), b.size()));
            map.put("lxjc", a.stream().filter(p -> "002".equals(p.getRegisterTypeID())).count());
            map.put("lxtb", getPercent(getRegisterTypeSum("002", a, false), getRegisterTypeSum("002", b, false)));
            //来访批次  activity.registerTypeID=001
            map.put("lfpc", getRegisterTypeSum("001", a, false));
            map.put("lfpctb", getPercent(getRegisterTypeSum("001", a, false), getRegisterTypeSum("001", b, false)));
            map.put("lfrc", getRegisterTypeSum("001", a, true));
            map.put("lfrctb", getPercent(getRegisterTypeSum("001", a, true), getRegisterTypeSum("001", b, true)));
            //集体访
            map.put("lfjtpc", a.stream().filter(p -> "001002".equals(p.getXfTypeID())).count());
            map.put("lfjtpctb", getPercent(a.stream().filter(p -> "001002".equals(p.getXfTypeID())).collect(Collectors.toList()).size(),
                    b.stream().filter(p -> "001002".equals(p.getXfTypeID())).collect(Collectors.toList()).size()));
            map.put("lfjtrc", a.stream().filter(p -> "001002".equals(p.getXfTypeID())).collect(Collectors.summingInt(ActivityVO::getXfNumber)));
            map.put("lfjtrctb", getPercent(a.stream().filter(p -> "001002".equals(p.getXfTypeID())).collect(Collectors.summingInt(ActivityVO::getXfNumber)),
                    b.stream().filter(p -> "001002".equals(p.getXfTypeID())).collect(Collectors.summingInt(ActivityVO::getXfNumber))));
            //网上反映件次  activity.registerTypeID=004
            map.put("wsjc",getRegisterTypeSum("004" , a, false));
            map.put("wsjctb",getPercent(getRegisterTypeSum("004" , a, false),getRegisterTypeSum("004" , b, false)));
            //来电件次  activity.registerTypeID=003
            map.put("ldjc",getRegisterTypeSum("003" , a, false));
            map.put("ldtb",getPercent(getRegisterTypeSum("003" , a, false),getRegisterTypeSum("003" , b, false)));
            res.add(map);
        }
        return res;
    }

    //添加信访指标记录
    private XfzbDTO addXfzbDto(String title , Integer curSum, Integer curYear, Integer orgSum, Integer orgYear ,Integer zb ,Integer orgZb) {
        return new XfzbDTO(title, curSum.toString(), getPercent(curSum, orgSum) ,getZb(curSum,zb), curYear.toString(), getPercent(curYear, orgYear),getZb(orgSum,orgZb));
    }


    /**
     *
     * @param type 统计类型
     * @param list 统计列表
     * @param rc  是否统计人次
     * @return
     */
    private int getRegisterTypeSum(String type, List<ActivityVO> list,Boolean rc) {
        if(rc){
            return list.stream().filter(p -> type.equals(p.getRegisterTypeID())).collect(Collectors.summingInt(ActivityVO::getXfNumber));
        }else {
            return (int) list.stream().filter(p -> type.equals(p.getRegisterTypeID())).count();
        }

    }

    //根据逗号分割匹配统计数量
    private Integer getSum(List<ActivityVO> collect,String value) {
        Integer sum = 0;
        for (ActivityVO activityVO : collect) {
            String[] split = activityVO.getAbnormalID().split(",");
            for (String s : split) {
                if(s.indexOf(value) != -1){
                    sum++;
                }
            }
        }
        return sum;
    }
    //获取占比
    public String getZb(int x , int total){
        if(total == 0){
            return "100.00%";
        }
        double f = (Double.valueOf(x) / Double.valueOf(total)) * 100;
        BigDecimal bg = new BigDecimal(f);
        double f1 = bg.setScale(2, BigDecimal.ROUND_HALF_UP).doubleValue();
        return (f1+"%");
    }

     // 获取同比数值
    public String  getPercent(int x, int total){
        if(total == 0 && x == 0 ){
            return "0.00%";
        }else if(total == 0) {
            return "100.00%";
        }
        double f = (Double.valueOf(x) - Double.valueOf(total)) / Double.valueOf(total) * 100;
        //double f = x*100/ total;

        BigDecimal bg = new BigDecimal(f);

        double f1 = bg.setScale(2, BigDecimal.ROUND_HALF_UP).doubleValue();

        return (f1+"%");
    }


    /**
     * 本级代表反应信访事项统计表
     * @param affiliationMatter
     * @return
     * @throws ParseException
     */
    @Override
    public Map<String, List<ActivityDto>> behalfList(AffiliationMatter affiliationMatter) throws ParseException {
        Map<String, List<ActivityDto>> map =new HashMap<>();

        //传入的时间
        Date currTime=affiliationMatter.getStartTime();
        Date lastTime=DateTimeUtils.getTodayTime(affiliationMatter.getEndTime());
        // 同比开始时间与结束时间
        Date currTBTime=DateTimeUtils.getStartHBTime(affiliationMatter.getStartTime());
        Date lastTBTime=DateTimeUtils.getEndHBTime(affiliationMatter.getEndTime());
        //当年累计时间
        Date currYearTime =DateTimeUtils.getCurrYearFirst();
        Date lastYearTime =new Date();

        // //当年累计时间 同比开始时间与结束时间
        Date currYearTBTime=DateTimeUtils.getStartHBTime(currYearTime);
        Date lastYearTBTime=DateTimeUtils.getEndHBTime(lastYearTime);

        affiliationMatter.setStartTime(currTime);
        affiliationMatter.setEndTime(lastTime);
        List<ActivityVO2> total = activityMapper.behalfList(affiliationMatter);
        //代表来信 001004 002006 002003 001003
        List<ActivityVO2> collect = total.stream().filter((n) -> n.getXfSourceID().equals("001003") || n.getXfSourceID().equals("001004") || n.getXfSourceID().equals("002003") || n.getXfSourceID().equals("002006")).collect(Collectors.toList());

        //获取同比开始时间
        affiliationMatter.setStartTime(currTBTime);
        affiliationMatter.setEndTime(lastTBTime);
        List<ActivityVO2> totalTB = activityMapper.behalfList(affiliationMatter);
        List<ActivityVO2> collectTB = totalTB.stream().filter((n) -> n.getXfSourceID().equals("001003") || n.getXfSourceID().equals("001004") || n.getXfSourceID().equals("002003") || n.getXfSourceID().equals("002006")).collect(Collectors.toList());

        //当年累计
        affiliationMatter.setStartTime(currYearTime);
        affiliationMatter.setEndTime(lastYearTime);
        List<ActivityVO2> totleDN = activityMapper.behalfList(affiliationMatter);
        List<ActivityVO2> collectDN = totleDN.stream().filter((n) -> n.getXfSourceID().equals("001003") || n.getXfSourceID().equals("001004") || n.getXfSourceID().equals("002003") || n.getXfSourceID().equals("002006")).collect(Collectors.toList());

        //当年累计同比总数
        affiliationMatter.setStartTime(currYearTBTime);
        affiliationMatter.setEndTime(lastYearTBTime);
        List<ActivityVO2> totleDNTB = activityMapper.behalfList(affiliationMatter);
        List<ActivityVO2> collectDNTB = totleDNTB.stream().filter((n) -> n.getXfSourceID().equals("001003") || n.getXfSourceID().equals("001004") || n.getXfSourceID().equals("002003") || n.getXfSourceID().equals("002006")).collect(Collectors.toList());
//代表信访活动
        //批次
        ActivityDto activity =new ActivityDto();
        activity.setNum(collect.size());
        //同比
        activity.setWithRatio(getPercent(collect.size(),collectTB.size()));
        //站总量比
        activity.setPropoRtion(CalculateUtils.makeUp(collect.size(),total.size()));
        //当年累计
        activity.setYearTotal(collectDN.size());
        //当年累计同比
        activity.setYearRtion(getPercent(collectDN.size(),collectDNTB.size()));
        //当年累计占总量
        activity.setYearpropoRtion(CalculateUtils.makeUp(collectDN.size(),totleDN.size()));
        List<ActivityDto> list =new ArrayList<>();
        list.add(activity);
        map.put("list1zpc",list);
        //统计总的人数
        // 时间区域总人数
        Integer totaliper = getpersonNum(total);
        //当年累计总人数
        Integer totaliperDN = getpersonNum(totleDN);
        // 人数
        ActivityDto activityRer =new ActivityDto();
        activityRer.setNum(getpersonNum(collect));
        //同比
        activityRer.setWithRatio(getPercent(getpersonNum(collect),getpersonNum(collectTB)));
        //站总量比
        activityRer.setPropoRtion(CalculateUtils.makeUp(getpersonNum(collect),totaliper));
        //当年累计
        activityRer.setYearTotal(getpersonNum(collectDN));
        //当年累计同比
        activityRer.setYearRtion(getPercent(getpersonNum(collectDN),getpersonNum(collectDNTB)));
        //当年累计占总量
        activityRer.setYearpropoRtion(CalculateUtils.makeUp(getpersonNum(collectDN),totaliperDN));

        List<ActivityDto> list2 =new ArrayList<>();
        list2.add(activityRer);
        map.put("list2zrs",list2);
        Map<String, List<ActivityVO2>> stacollect = getstatistics(collect);
        List<ActivityVO2> dblf = stacollect.get("Dblf");
        List<ActivityVO2> Dbydlf = stacollect.get("Dbydlf");
        List<ActivityVO2> Dblx = stacollect.get("Dblx");
        List<ActivityVO2> Dbzx = stacollect.get("Dbzx");
        Map<String, List<ActivityVO2>> stacollectTB = getstatistics(collectTB);
        List<ActivityVO2> dblfTB = stacollectTB.get("Dblf");
        List<ActivityVO2> DbydlfTB = stacollectTB.get("Dbydlf");
        List<ActivityVO2> DblxTB = stacollectTB.get("Dblx");
        List<ActivityVO2> DbzxTB = stacollectTB.get("Dbzx");
        Map<String, List<ActivityVO2>> stacollectDN = getstatistics(collectDN);
        List<ActivityVO2> dblfDN = stacollectDN.get("Dblf");
        List<ActivityVO2> DbydlfDN = stacollectDN.get("Dbydlf");
        List<ActivityVO2> DblxDN = stacollectDN.get("Dblx");
        List<ActivityVO2> DbzxDN = stacollectDN.get("Dbzx");
        Map<String, List<ActivityVO2>> stacollectDNTB = getstatistics(collectDNTB);
        List<ActivityVO2> dblfDNTB = stacollectDNTB.get("Dblf");
        List<ActivityVO2> DbydlfDNTB = stacollectDNTB.get("Dbydlf");
        List<ActivityVO2> DblxDNTB = stacollectDNTB.get("Dblx");
        List<ActivityVO2> DbzxDNTB = stacollectDNTB.get("Dbzx");

//代表来访
        ActivityDto activityLf =new ActivityDto();
        activityLf.setNum(dblf.size());
        //同比
        activityLf.setWithRatio(getPercent(dblf.size(),dblfTB.size()));
        //站总量比
        activityLf.setPropoRtion(CalculateUtils.makeUp(dblf.size(),total.size()));
        //当年累计
        activityLf.setYearTotal(dblfDN.size());
        //当年累计同比
        activityLf.setYearRtion(getPercent(dblfDN.size(),dblfDNTB.size()));
        //当年累计占总量
        activityLf.setYearpropoRtion(CalculateUtils.makeUp(dblfDN.size(),totleDN.size()));
        List<ActivityDto> list3 =new ArrayList<>();
        list3.add(activityLf);
        map.put("list3dblfpc",list3);
        //代表来访人数
        ActivityDto activityLfper =new ActivityDto();
        //同比
        Integer dblfperNum = getpersonNum(dblf);
        activityLfper.setNum(dblfperNum);
        activityLfper.setWithRatio(getPercent(dblfperNum,getpersonNum(dblfTB)));
        //站总量比
        activityLfper.setPropoRtion(CalculateUtils.makeUp(dblfperNum,totaliper));
        //当年累计
        Integer dblfDNperNum = getpersonNum(dblfDN);
        activityLfper.setYearTotal(dblfDNperNum);
        //当年累计同比
        activityLfper.setYearRtion(getPercent(dblfDNperNum,getpersonNum(dblfDNTB)));
        //当年累计占总量
        activityLfper.setYearpropoRtion(CalculateUtils.makeUp(dblfDNperNum,totaliperDN));
        List<ActivityDto> list4 =new ArrayList<>();
        list4.add(activityLfper);
        map.put("list4dblfrs",list4);

//代表引导来访
        ActivityDto activityYD =new ActivityDto();
        activityYD.setNum(Dbydlf.size());
        //同比
        activityYD.setWithRatio(getPercent(Dbydlf.size(),DbydlfTB.size()));
        //站总量比
        activityYD.setPropoRtion(CalculateUtils.makeUp(Dbydlf.size(),total.size()));
        //当年累计
        activityYD.setYearTotal(DbydlfDN.size());
        //当年累计同比
        activityYD.setYearRtion(getPercent(DbydlfDN.size(),DbydlfDNTB.size()));
        //当年累计占总量
        activityYD.setYearpropoRtion(CalculateUtils.makeUp(DbydlfDN.size(),totleDN.size()));
        List<ActivityDto> list5 =new ArrayList<>();
        list5.add(activityYD);
        map.put("list5dbydpc",list5);

        ////代表引导来访人数
        ActivityDto activityYDper =new ActivityDto();
        Integer DbydlfperNum = getpersonNum(Dbydlf);
        activityYDper.setNum(DbydlfperNum);
        //同比
        activityYDper.setWithRatio(getPercent(DbydlfperNum,getpersonNum(DbydlfTB)));
        //站总量比
        activityYDper.setPropoRtion(CalculateUtils.makeUp(DbydlfperNum,totaliper));
        //当年累计
        Integer DbydlfDNperNum = getpersonNum(DbydlfDN);
        activityYDper.setYearTotal(DbydlfDNperNum);
        //当年累计同比
        activityYDper.setYearRtion(getPercent(DbydlfDNperNum,getpersonNum(DbydlfDNTB)));
        //当年累计占总量
        activityYDper.setYearpropoRtion(CalculateUtils.makeUp(DbydlfDNperNum,totaliperDN));
        List<ActivityDto> list6 =new ArrayList<>();
        list6.add(activityYDper);
        map.put("list6dbydrs",list6);
        //代表来访 ，引导来访
        ActivityDto activityLFYD =new ActivityDto();
        activityLFYD.setNum(Dbydlf.size()+dblf.size());
        //同比
        activityLFYD.setWithRatio(getPercent(Dbydlf.size()+dblf.size(),DbydlfTB.size()+dblfTB.size()));
        //站总量比
        activityLFYD.setPropoRtion(CalculateUtils.makeUp(Dbydlf.size()+dblf.size(),total.size()));
        //当年累计
        activityLFYD.setYearTotal(DbydlfDN.size()+dblfDN.size());
        //当年累计同比
        activityLFYD.setYearRtion(getPercent(DbydlfDN.size()+dblfDN.size(),DbydlfDNTB.size()+dblfDNTB.size()));
        //当年累计占总量
        activityLFYD.setYearpropoRtion(CalculateUtils.makeUp(DbydlfDN.size()+dblfDN.size(),totleDN.size()));

        List<ActivityDto> list7 =new ArrayList<>();
        list7.add(activityLFYD);
        map.put("list7lfydpc",list7);
        ////代表引导来访人数
        ActivityDto activityLFYDper =new ActivityDto();
        activityLFYDper.setNum(dblfperNum+DbydlfperNum);
        //同比
        activityLFYDper.setWithRatio(getPercent(dblfperNum+DbydlfperNum,getpersonNum(DbydlfTB)+getpersonNum(dblfTB)));
        //站总量比
        activityLFYDper.setPropoRtion(CalculateUtils.makeUp(dblfperNum+DbydlfperNum,totaliper));
        //当年累计
        activityLFYDper.setYearTotal(DbydlfDNperNum+dblfDNperNum);
        //当年累计同比
        activityLFYDper.setYearRtion(getPercent(DbydlfDNperNum+dblfDNperNum,getpersonNum(DbydlfDNTB)+getpersonNum(dblfDNTB)));
        //当年累计占总量
        activityLFYDper.setYearpropoRtion(CalculateUtils.makeUp(DbydlfDNperNum+dblfDNperNum,totaliperDN));
        List<ActivityDto> list8 =new ArrayList<>();
        list8.add(activityLFYDper);
        map.put("list8lfydrs",list8);
//代表来信
        ActivityDto activityLX =new ActivityDto();
        activityLX.setNum(Dblx.size());
        //同比
        activityLX.setWithRatio(getPercent(Dblx.size(),DblxTB.size()));
        //站总量比
        activityLX.setPropoRtion(CalculateUtils.makeUp(Dblx.size(),total.size()));
        //当年累计
        activityLX.setYearTotal(DblxDN.size());
        //当年累计同比
        activityLX.setYearRtion(getPercent(DblxDN.size(),DblxDNTB.size()));
        //当年累计占总量
        activityLX.setYearpropoRtion(CalculateUtils.makeUp(DblxDN.size(),totleDN.size()));
        List<ActivityDto> list9 =new ArrayList<>();
        list9.add(activityLX);
        map.put("list9lx",list9);


        //代表转信
        ActivityDto activityZX =new ActivityDto();
        activityZX.setNum(Dbzx.size());
        //同比
        activityZX.setWithRatio(getPercent(Dbzx.size(),DbzxTB.size()));
        //站总量比
        activityZX.setPropoRtion(CalculateUtils.makeUp(Dbzx.size(),total.size()));
        //当年累计
        activityZX.setYearTotal(DbzxDN.size());
        //当年累计同比
        activityZX.setYearRtion(getPercent(DbzxDN.size(),DbzxDNTB.size()));
        //当年累计占总量
        activityZX.setYearpropoRtion(CalculateUtils.makeUp(DbzxDN.size(),totleDN.size()));

        List<ActivityDto> list10 =new ArrayList<>();
        list10.add(activityZX);
        map.put("list10zx",list10);
        //代表来信你转信
        ActivityDto activityLXZX =new ActivityDto();
        activityLXZX.setNum(Dbzx.size()+Dblx.size());
        //同比
        activityLXZX.setWithRatio(getPercent(Dbzx.size()+Dblx.size(),DbzxTB.size()+DblxTB.size()));
        //站总量比
        activityLXZX.setPropoRtion(CalculateUtils.makeUp(Dbzx.size()+Dblx.size(),total.size()));
        //当年累计
        activityLXZX.setYearTotal(DbzxDN.size()+DblxDN.size());
        //当年累计同比
        activityLXZX.setYearRtion(getPercent(DbzxDN.size()+DblxDN.size(),DbzxDNTB.size()+DblxDNTB.size()));
        //当年累计占总量
        activityLXZX.setYearpropoRtion(CalculateUtils.makeUp(DbzxDN.size()+DblxDN.size(),totleDN.size()));
        List<ActivityDto> list11 =new ArrayList<>();
        list11.add(activityLXZX);
        map.put("list11lxzx",list11);
        return map;
    }

    private  Map<String, List<ActivityVO2>> getstatistics(List<ActivityVO2> collect) {
        Map<String, List<ActivityVO2>> map= new HashMap<>();
        //代表来访
        List<ActivityVO2> Dblf = new ArrayList<>();
        //代表引导来访
        List<ActivityVO2> Dbydlf = new ArrayList<>();
        //代表来信
        List<ActivityVO2> Dblx = new ArrayList<>();
        //代表转信
        List<ActivityVO2> Dbzx = new ArrayList<>();
        for (ActivityVO2 activity : collect) {
            String xfSourceID = activity.getXfSourceID();
            if (xfSourceID.equals("001004")){
                Dblf.add(activity);
            }else if (xfSourceID.equals("001003")){
                Dbydlf.add(activity);
            }else if (xfSourceID.equals("002006")){
                Dblx.add(activity);
            }else if (xfSourceID.equals("002003")){
                Dbzx.add(activity);
            }
        }
        map.put("Dblf",Dblf);
        map.put("Dbydlf",Dbydlf);
        map.put("Dblx",Dblx);
        map.put("Dbzx",Dbzx);
        return map;
    }

    private  Integer getpersonNum(List<ActivityVO2> ActivityVO2List) {
        Integer numberPer =0 ;
        for (ActivityVO2 activityPerson : ActivityVO2List) {
            numberPer = numberPer+activityPerson.getXfNumber();
        }
        return numberPer;
    }
    /**
     * 人大常委会及机关、工委领导接访阅信情况统计表
     * @param affiliationMatter
     * @return
     * @throws ParseException
     */
    @Override
    public Map<String, List<ActivityDto>> leadList(AffiliationMatter affiliationMatter) throws ParseException {
        Map<String, List<ActivityDto>> map = new HashMap<>();

        //传入的时间
        Date currTime = affiliationMatter.getStartTime();
        Date lastTime = DateTimeUtils.getTodayTime(affiliationMatter.getEndTime());
        // 同比开始时间与结束时间
        Date currTBTime = DateTimeUtils.getStartHBTime(affiliationMatter.getStartTime());
        Date lastTBTime = DateTimeUtils.getEndHBTime(affiliationMatter.getEndTime());
        //当年累计时间
        Date currYearTime = DateTimeUtils.getCurrYearFirst();
        Date lastYearTime = new Date();

        // //当年累计时间 同比开始时间与结束时间
        Date currYearTBTime = DateTimeUtils.getStartHBTime(currYearTime);
        Date lastYearTBTime = DateTimeUtils.getEndHBTime(lastYearTime);

        affiliationMatter.setStartTime(currTime);
        affiliationMatter.setEndTime(lastTime);
        List<ActivityVO2> total = activityMapper.behalfList(affiliationMatter);
        //接访 阅信 001004 002006 002003 001003
        List<ActivityVO2> collect = total.stream().filter((n) -> n.getXfSourceID().equals("001002001") || n.getXfSourceID().equals("001002002") || n.getXfSourceID().equals("002002001") || n.getXfSourceID().equals("002002002")).collect(Collectors.toList());

        //获取同比开始时间
        affiliationMatter.setStartTime(currTBTime);
        affiliationMatter.setEndTime(lastTBTime);
        List<ActivityVO2> totalTB = activityMapper.behalfList(affiliationMatter);
        List<ActivityVO2> collectTB = totalTB.stream().filter((n) -> n.getXfSourceID().equals("001002001") || n.getXfSourceID().equals("001002002") || n.getXfSourceID().equals("002002001") || n.getXfSourceID().equals("002002002")).collect(Collectors.toList());

        //当年累计
        affiliationMatter.setStartTime(currYearTime);
        affiliationMatter.setEndTime(lastYearTime);
        List<ActivityVO2> totleDN = activityMapper.behalfList(affiliationMatter);
        List<ActivityVO2> collectDN = totleDN.stream().filter((n) -> n.getXfSourceID().equals("001002001") || n.getXfSourceID().equals("001002002") || n.getXfSourceID().equals("002002001") || n.getXfSourceID().equals("002002002")).collect(Collectors.toList());

        //当年累计同比总数
        affiliationMatter.setStartTime(currYearTBTime);
        affiliationMatter.setEndTime(lastYearTBTime);
        List<ActivityVO2> totleDNTB = activityMapper.behalfList(affiliationMatter);
        List<ActivityVO2> collectDNTB = totleDNTB.stream().filter((n) -> n.getXfSourceID().equals("001002001") || n.getXfSourceID().equals("001002002") || n.getXfSourceID().equals("002002001") || n.getXfSourceID().equals("002002002")).collect(Collectors.toList());
//领导接访及阅信总计
        //批次
        ActivityDto activity =new ActivityDto();
        activity.setNum(collect.size());
        //同比
        activity.setWithRatio(getPercent(collect.size(),collectTB.size()));
        //站总量比
        activity.setPropoRtion(CalculateUtils.makeUp(collect.size(),total.size()));
        //当年累计
        activity.setYearTotal(collectDN.size());
        //当年累计同比
        activity.setYearRtion(getPercent(collectDN.size(),collectDNTB.size()));
        //当年累计占总量
        activity.setYearpropoRtion(CalculateUtils.makeUp(collectDN.size(),totleDN.size()));
        List<ActivityDto> list =new ArrayList<>();
        list.add(activity);
        map.put("list1jfyxpc",list);
        //统计总的人数
        // 时间区域总人数
        Integer totaliper = getpersonNum(total);
        //当年累计总人数
        Integer totaliperDN = getpersonNum(totleDN);
        // 人数
        ActivityDto activityRer =new ActivityDto();
        activityRer.setNum(getpersonNum(collect));
        //同比
        activityRer.setWithRatio(getPercent(getpersonNum(collect),getpersonNum(collectTB)));
        //站总量比
        activityRer.setPropoRtion(CalculateUtils.makeUp(getpersonNum(collect),totaliper));
        //当年累计
        activityRer.setYearTotal(getpersonNum(collectDN));
        //当年累计同比
        activityRer.setYearRtion(getPercent(getpersonNum(collectDN),getpersonNum(collectDNTB)));
        //当年累计占总量
        activityRer.setYearpropoRtion(CalculateUtils.makeUp(getpersonNum(collectDN),totaliperDN));

        List<ActivityDto> list2 =new ArrayList<>();
        list2.add(activityRer);
        map.put("list2jfyxrs",list2);

        Map<String, List<ActivityVO2>> stacollect = getlead(collect);
        List<ActivityVO2> jfcw = stacollect.get("jfcw");
        List<ActivityVO2> jfjg = stacollect.get("jfjg");
        List<ActivityVO2> yxcw = stacollect.get("yxcw");
        List<ActivityVO2> yxjg = stacollect.get("yxjg");
        Map<String, List<ActivityVO2>> stacollectTB = getlead(collectTB);
        List<ActivityVO2> jfcwTB = stacollectTB.get("jfcw");
        List<ActivityVO2> jfjgTB = stacollectTB.get("jfjg");
        List<ActivityVO2> yxcwTB = stacollectTB.get("yxcw");
        List<ActivityVO2> yxjgTB = stacollectTB.get("yxjg");
        Map<String, List<ActivityVO2>> stacollectDN = getlead(collectDN);
        List<ActivityVO2> jfcwDN = stacollectDN.get("jfcw");
        List<ActivityVO2> jfjgDN = stacollectDN.get("jfjg");
        List<ActivityVO2> yxcwDN = stacollectDN.get("yxcw");
        List<ActivityVO2> yxjgDN = stacollectDN.get("yxjg");
        Map<String, List<ActivityVO2>> stacollectDNTB = getlead(collectDNTB);
        List<ActivityVO2> jfcwDNTB = stacollectDNTB.get("jfcw");
        List<ActivityVO2> jfjgDNTB = stacollectDNTB.get("jfjg");
        List<ActivityVO2> yxcwDNTB = stacollectDNTB.get("yxcw");
        List<ActivityVO2> yxjgDNTB = stacollectDNTB.get("yxjg");


        //常委会领导接访
        ActivityDto activityCwjf =new ActivityDto();
        activityCwjf.setNum(jfcw.size());
        //同比
        activityCwjf.setWithRatio(getPercent(jfcw.size(),jfcwTB.size()));
        //站总量比
        activityCwjf.setPropoRtion(CalculateUtils.makeUp(jfcw.size(),total.size()));
        //当年累计
        activityCwjf.setYearTotal(jfcwDN.size());
        //当年累计同比
        activityCwjf.setYearRtion(getPercent(jfcwDN.size(),jfcwDNTB.size()));
        //当年累计占总量
        activityCwjf.setYearpropoRtion(CalculateUtils.makeUp(jfcwDN.size(),totleDN.size()));
        List<ActivityDto> list3 =new ArrayList<>();
        list3.add(activityCwjf);
        map.put("list3CwjfPc",list3);
        //常委会领导接访 人数
        ActivityDto activitcwjfPer =new ActivityDto();
        //同比
        Integer jfcwperNum = getpersonNum(jfcw);
        activitcwjfPer.setNum(jfcwperNum);
        activitcwjfPer.setWithRatio(getPercent(jfcwperNum,getpersonNum(jfcwTB)));
        //站总量比
        activitcwjfPer.setPropoRtion(CalculateUtils.makeUp(jfcwperNum,totaliper));
        //当年累计
        Integer jfcwDNperNum = getpersonNum(jfcwDN);
        activitcwjfPer.setYearTotal(jfcwDNperNum);
        //当年累计同比
        activitcwjfPer.setYearRtion(getPercent(jfcwDNperNum,getpersonNum(jfcwDNTB)));
        //当年累计占总量
        activitcwjfPer.setYearpropoRtion(CalculateUtils.makeUp(jfcwDNperNum,totaliperDN));
        List<ActivityDto> list4 =new ArrayList<>();
        list4.add(activitcwjfPer);
        map.put("list4CwjfRs",list4);

        //机关或工委接访
        ActivityDto activityJgjf =new ActivityDto();
        activityJgjf.setNum(jfjg.size());
        //同比
        activityJgjf.setWithRatio(getPercent(jfjg.size(),jfjgTB.size()));
        //站总量比
        activityJgjf.setPropoRtion(CalculateUtils.makeUp(jfjg.size(),total.size()));
        //当年累计
        activityJgjf.setYearTotal(jfjgDN.size());
        //当年累计同比
        activityJgjf.setYearRtion(getPercent(jfjgDN.size(),jfjgDNTB.size()));
        //当年累计占总量
        activityJgjf.setYearpropoRtion(CalculateUtils.makeUp(jfjgDN.size(),totleDN.size()));
        List<ActivityDto> list5 =new ArrayList<>();
        list5.add(activityJgjf);
        map.put("list5Jgjfpc",list5);

        //机关或工委接访人数
        ActivityDto activityYDper =new ActivityDto();
        Integer jfjgperNum = getpersonNum(jfjg);
        activityYDper.setNum(jfjgperNum);
        //同比
        activityYDper.setWithRatio(getPercent(jfjgperNum,getpersonNum(jfjgTB)));
        //站总量比
        activityYDper.setPropoRtion(CalculateUtils.makeUp(jfjgperNum,totaliper));
        //当年累计
        Integer jfjgDNperNum = getpersonNum(jfjgDN);
        activityYDper.setYearTotal(jfjgDNperNum);
        //当年累计同比
        activityYDper.setYearRtion(getPercent(jfjgDNperNum,getpersonNum(jfjgDNTB)));
        //当年累计占总量
        activityYDper.setYearpropoRtion(CalculateUtils.makeUp(jfjgDNperNum,totaliperDN));
        List<ActivityDto> list6 =new ArrayList<>();
        list6.add(activityYDper);
        map.put("list6jgjfrs",list6);

        //常委会及机关或工委领导接访
        ActivityDto activitycwjg =new ActivityDto();
        activitycwjg.setNum(jfjg.size()+jfcw.size());
        //同比
        activitycwjg.setWithRatio(getPercent(jfjg.size()+jfcw.size(),jfjgTB.size()+jfjgTB.size()));
        //站总量比
        activitycwjg.setPropoRtion(CalculateUtils.makeUp(jfjg.size()+jfcw.size(),total.size()));
        //当年累计
        activitycwjg.setYearTotal(jfjgDN.size()+jfcwDN.size());
        //当年累计同比
        activitycwjg.setYearRtion(getPercent(jfjgDN.size()+jfcwDN.size(),jfjgDNTB.size()+jfcwDNTB.size()));
        //当年累计占总量
        activitycwjg.setYearpropoRtion(CalculateUtils.makeUp(jfjgDN.size()+jfcwDN.size(),totleDN.size()));

        List<ActivityDto> list7 =new ArrayList<>();
        list7.add(activitycwjg);
        map.put("list7ycwjg",list7);
        // //常委会及机关或工委领导接访 人数
        ActivityDto activitycwjgPer =new ActivityDto();
        activitycwjgPer.setNum(jfjgperNum+jfcwperNum);
        //同比
        activitycwjgPer.setWithRatio(getPercent(jfjgperNum+jfcwperNum,getpersonNum(jfjgTB)+getpersonNum(jfcwTB)));
        //站总量比
        activitycwjgPer.setPropoRtion(CalculateUtils.makeUp(jfjgperNum+jfcwperNum,totaliper));
        //当年累计
        activitycwjgPer.setYearTotal(jfjgDNperNum+jfcwDNperNum);
        //当年累计同比
        activitycwjgPer.setYearRtion(getPercent(jfjgDNperNum+jfcwDNperNum,getpersonNum(jfjgDNTB)+getpersonNum(jfcwDNTB)));
        //当年累计占总量
        activitycwjgPer.setYearpropoRtion(CalculateUtils.makeUp(jfjgDNperNum+jfcwDNperNum,totaliperDN));
        List<ActivityDto> list8 =new ArrayList<>();
        list8.add(activitycwjgPer);
        map.put("list8cwjgrs",list8);
//常委会领导阅信
        ActivityDto activityCwyx =new ActivityDto();
        activityCwyx.setNum(yxcw.size());
        //同比
        activityCwyx.setWithRatio(getPercent(yxcw.size(),yxcwTB.size()));
        //站总量比
        activityCwyx.setPropoRtion(CalculateUtils.makeUp(yxcw.size(),total.size()));
        //当年累计
        activityCwyx.setYearTotal(yxcwDN.size());
        //当年累计同比
        activityCwyx.setYearRtion(getPercent(yxcwDN.size(),yxcwDNTB.size()));
        //当年累计占总量
        activityCwyx.setYearpropoRtion(CalculateUtils.makeUp(yxcwDN.size(),totleDN.size()));
        List<ActivityDto> list9 =new ArrayList<>();
        list9.add(activityCwyx);
        map.put("list9Cwyx",list9);

        //机关或工委领导阅信
        ActivityDto activityJgyx =new ActivityDto();
        activityJgyx.setNum(yxjg.size());
        //同比
        activityJgyx.setWithRatio(getPercent(yxjg.size(),yxjgTB.size()));
        //站总量比
        activityJgyx.setPropoRtion(CalculateUtils.makeUp(yxjg.size(),total.size()));
        //当年累计
        activityJgyx.setYearTotal(yxjgDN.size());
        //当年累计同比
        activityJgyx.setYearRtion(getPercent(yxjgDN.size(),yxjgDNTB.size()));
        //当年累计占总量
        activityJgyx.setYearpropoRtion(CalculateUtils.makeUp(yxjgDN.size(),totleDN.size()));

        List<ActivityDto> list10 =new ArrayList<>();
        list10.add(activityJgyx);
        map.put("list10Jgyx",list10);

        ActivityDto activityYxcwjg =new ActivityDto();
        activityYxcwjg.setNum(yxjg.size()+yxcw.size());
        //同比
        activityYxcwjg.setWithRatio(getPercent(yxjg.size()+yxcw.size(),yxjgTB.size()+yxcwTB.size()));
        //站总量比
        activityYxcwjg.setPropoRtion(CalculateUtils.makeUp(yxjg.size()+yxcw.size(),total.size()));
        //当年累计
        activityYxcwjg.setYearTotal(yxjgDN.size()+yxcwDN.size());
        //当年累计同比
        activityYxcwjg.setYearRtion(getPercent(yxjgDN.size()+yxcwDN.size(),yxjgDNTB.size()+yxcwDNTB.size()));
        //当年累计占总量
        activityYxcwjg.setYearpropoRtion(CalculateUtils.makeUp(yxjgDN.size()+yxcwDN.size(),totleDN.size()));
        List<ActivityDto> list11 =new ArrayList<>();
        list11.add(activityYxcwjg);
        map.put("list11Yxcwjg",list11);
        return map;
    }
    private  Map<String, List<ActivityVO2>> getlead(List<ActivityVO2> collect) {
        Map<String, List<ActivityVO2>> map= new HashMap<>();
        //领导接访约访 常委会领导 001002001
        List<ActivityVO2> jfcw = new ArrayList<>();
        //领导接访约访 机关（工委）领导  001002002
        List<ActivityVO2> jfjg = new ArrayList<>();
        //领导阅批 常委会领导  002002001
        List<ActivityVO2> yxcw = new ArrayList<>();
        //领导阅批 机关（工委）领导  002002002
        List<ActivityVO2> yxjg = new ArrayList<>();
        for (ActivityVO2 activity : collect) {
            String xfSourceID = activity.getXfSourceID();
            if (xfSourceID.equals("001002001")){
                jfcw.add(activity);
            }else if (xfSourceID.equals("001002002")){
                jfjg.add(activity);
            }else if (xfSourceID.equals("002002001")){
                yxcw.add(activity);
            }else if (xfSourceID.equals("002002002")){
                yxjg.add(activity);
            }
        }
        map.put("jfcw",jfcw);
        map.put("jfjg",jfjg);
        map.put("yxcw",yxcw);
        map.put("yxjg",yxjg);
        return map;
    }
    /**
     * 本级及下一级人大领导接访阅信统计表（省、市级用）
     * @param affiliationMatter
     * @return
     * @throws ParseException
     */
    @Override
    public Map<String, Object> NpcCongressList(AffiliationMatter affiliationMatter) throws ParseException {
        Map<String, Object> map= new HashMap<>();
        Dept dept = deptMapper.districtType(affiliationMatter.getCreateOrgID());
        //只统计省市
        if ("2".equals(String.valueOf(dept.getType())) ||"3".equals(String.valueOf(dept.getType())) ){
            List<Dept> depts = deptMapper.selectDeptByIdList(dept.getDeptID());
            List<ActivityVO7> list =new ArrayList<>();
            for (Dept dept1 : depts) {
                //单位组织id  起了别名 OrganizationId
                affiliationMatter.setCreateOrgIDS(String.valueOf(dept1.getOrganizationId()));
                affiliationMatter.setEndTime(DateTimeUtils.getTodayTime(affiliationMatter.getEndTime()));
                List<ActivityVO2> activityVO2s = activityMapper.behalfList(affiliationMatter);
                List<ActivityVO2> collect = activityVO2s.stream().filter((n) -> n.getXfSourceID().equals("001002001") || n.getXfSourceID().equals("001002002") || n.getXfSourceID().equals("002002001") || n.getXfSourceID().equals("002002002")).collect(Collectors.toList());
                Map<String, List<ActivityVO2>> getlead = getlead(collect);
                List<ActivityVO2> jfcw = getlead.get("jfcw");   //常委会领导接访
                List<ActivityVO2> jfjg = getlead.get("jfjg");   //机关或工委会领导接访
                List<ActivityVO2> yxcw = getlead.get("yxcw");   //常委会领导阅信
                List<ActivityVO2> yxjg = getlead.get("yxjg");   //机关或工委会领导阅信
                ActivityVO7 activityVO7 = new ActivityVO7();
                activityVO7.setOrgName(dept1.getOrgName());
                activityVO7.setLdjfPc(jfcw.size()+jfjg.size());
                activityVO7.setLdjfRs(getpersonNum(jfcw)+getpersonNum(jfjg));
                activityVO7.setCwjfPc(jfcw.size());
                activityVO7.setCwjfRs(getpersonNum(jfcw));
                activityVO7.setJgjfPc(jfjg.size());
                activityVO7.setJgjfRs(getpersonNum(jfjg));
                activityVO7.setLdyx(yxcw.size()+yxjg.size());
                activityVO7.setCwyx(yxcw.size());
                activityVO7.setJgyx(yxjg.size());
                list.add(activityVO7);
            }
            //总计
            ActivityVO7 activitySum = subordinateSum(list);
            activitySum.setOrgName("合计");
            list.add(activitySum);
            map.put("state","scopeIn");
            map.put("list",list);
            return map;
        }else {
            map.put("state","scopeOut");
            return map;
        }

    }

    @Override
    public List<ActivityDTO> excludeZDY(ZdyQuery zdyQuery) {

       List<ActivityDTO> list = activityMapper.selectCustom(zdyQuery);
       list = list.stream().collect(Collectors.collectingAndThen(Collectors.toCollection(() ->new TreeSet<>(Comparator.comparing(ActivityDTO::getId))),ArrayList::new));
        list = list.stream().sorted(Comparator.comparing(ActivityDTO::getCreateTime)).collect(Collectors.toList());
        List<String> alone = zdyQuery.getAlone();
        if(alone.contains("contentClassify")){
            checkContentClassify(list);
        }
        return list;
    }

    /**
     * 所属内容分类拆分
     * @param list
     * @return
     */
    @Override
    public List<ActivityDTO> checkContentClassify(List<ActivityDTO> list) {
        List<Dictionary> fyn = dictionaryMapper.selectDictionaryByDictID("FYN");
        for (ActivityDTO activityDTO : list) {
            StringBuffer sb = new StringBuffer(activityDTO.getContentClassify());
            String finalZoneID = activityDTO.getCcmID();
            while (finalZoneID !=null && finalZoneID.length() > 0) {
                for (Dictionary d : fyn) {
                    if (d.getDictValue().equals(finalZoneID)) {
                        switch (d.getDictValue().length()){
                            case 3:
                                activityDTO.setContentClassify1(d.getDescription());
                                break;
                            case 6:
                                activityDTO.setContentClassify2(d.getDescription());
                                break;
                            case 9:
                                activityDTO.setContentClassify3(d.getDescription());
                                break;
                            case 12:
                                activityDTO.setContentClassify4(d.getDescription());
                                break;
                            case 15:
                                activityDTO.setContentClassify5(d.getDescription());
                                break;
                            default:
                                if(StringUtils.isBlank(activityDTO.getContentClassify1())){
                                    activityDTO.setContentClassify1(activityDTO.getContentClassify());
                                }
                                break;
                        }
                    }
                }
                if(finalZoneID.length()<3){
                    finalZoneID = "";
                }else {
                    finalZoneID = finalZoneID.substring(0,finalZoneID.length()-3);
                }
            }
            activityDTO.setContentClassify(sb.toString());
        }
        return list;
    }

    @Override
    public List<ActivityDTO> excludeXFRSX(MatterQuery matterQuery) {
        return activityMapper.selectXFRSX(matterQuery);
    }

    /**
     * 本级及下级人大各项总和
     * @param list
     * @return
     */
    private ActivityVO7 subordinateSum(List<ActivityVO7> list) {
        ActivityVO7 activityVOZJ = new ActivityVO7();
        Integer ldjfPcnumber =0 ;
        Integer ldjfRsnumber =0 ;
        Integer cwjfPcnumber =0 ;
        Integer cwjfRsnumber =0 ;
        Integer jgjfPcnumber =0 ;
        Integer jgjfRsnumber =0 ;
        Integer ldyxnumber =0 ;
        Integer cwyxnumber =0 ;
        Integer jgyxnumber =0 ;
        for (ActivityVO7 activityVO7 : list) {
            ldjfPcnumber = ldjfPcnumber+activityVO7.getLdjfPc();;
            ldjfRsnumber =ldjfRsnumber+ activityVO7.getLdjfRs();
            cwjfPcnumber =cwjfPcnumber+ activityVO7.getCwjfPc();
            cwjfRsnumber =cwjfRsnumber+ activityVO7.getCwjfRs();
            jgjfPcnumber =jgjfPcnumber+ activityVO7.getJgjfPc();
            jgjfRsnumber =jgjfRsnumber+ activityVO7.getJgjfRs();
            ldyxnumber = ldyxnumber+activityVO7.getLdyx();
            cwyxnumber = cwyxnumber+activityVO7.getCwyx();
            jgyxnumber =jgyxnumber+ activityVO7.getJgyx();
        }
        activityVOZJ.setLdjfPc(ldjfPcnumber);
        activityVOZJ.setLdjfRs(ldjfRsnumber);
        activityVOZJ.setCwjfPc(cwjfPcnumber);
        activityVOZJ.setCwjfRs(cwjfRsnumber);
        activityVOZJ.setJgjfPc(jgjfPcnumber);
        activityVOZJ.setJgjfRs(jgjfRsnumber);
        activityVOZJ.setLdyx(ldyxnumber);
        activityVOZJ.setCwyx(cwyxnumber);
        activityVOZJ.setJgyx(jgyxnumber);

        return activityVOZJ;
    }

}
