package com.dlsm.service.impl;

import com.dlsm.mapper.*;
import com.dlsm.model.*;
import com.dlsm.model.Dictionary;
import com.dlsm.model.dto.ActivityDto;
import com.dlsm.model.dto.ActivityDto1;
import com.dlsm.model.dto.MatterDto;
import com.dlsm.model.export.GradeExport;
import com.dlsm.model.export.MatterDTO2;
import com.dlsm.model.export.MatterExport;
import com.dlsm.model.export.PersonExport;
import com.dlsm.model.vo.*;
import com.dlsm.service.ExportService;
import com.dlsm.utils.DateTimeUtils;
import com.dlsm.utils.StringUtils;
import org.apache.commons.collections.map.HashedMap;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.*;
import java.util.concurrent.atomic.AtomicInteger;
import java.util.concurrent.atomic.AtomicReference;
import java.util.stream.Collectors;
import java.util.stream.Stream;


/**
 * 固定报表导出
 *
 * @author xunfeng
 * @date 2022-03-03
 */
@Service
public class ExportServiceImpl implements ExportService {

    @Autowired
    private ExportMapper exportMapper;
    @Autowired
    private FamilyMapper familyMapper;
    @Autowired
    private FwTaskActMapper fwTaskActMapper;
    @Autowired
    private MatterRelationMapper relationMapper;
    @Autowired
    private MatterMapper matterMapper;

    @Autowired
    private ActivityMapper activityMapper;
    @Autowired
    private PersonMapper personMapper;
    @Autowired
    private DictionaryMapper dictionaryMapper;
    @Autowired
    private DeptMapper deptMapper;
    @Autowired
    private LeadBehalfMapper behalfMapper;

    @Override
    public Person selectPerson(Long id) {

        Person person = exportMapper.selectPerson(id);
        List<Family> families = familyMapper.selectFamilyList(id);
        if (StringUtils.isNotEmpty(families)){
            for (Family family : families) {
               if (StringUtils.isEmpty(person.getPersonFamily())){
                    person.setPersonFamily(family.getRelationship()+":"+family.getName()+","+family.getPhone()+","+family.getCompany());
                }else {
                   person.setPersonFamily(person.getPersonFamily()+family.getRelationship()+":"+family.getName()+","+family.getPhone()+","+family.getCompany());
               }
            }
        }else {
            person.setPersonFamily("");
        }
        if (StringUtils.isNotNull(person.getBirthday())){
            Date birthday = person.getBirthday();
            String dayMonthYear = DateTimeUtils.getDayMonthYear(birthday);
            person.setBirthday1(dayMonthYear);
        }
        if (person.getIsRepresent().equals("0")){
            person.setIsRepresent("否");
        }else if (person.getIsRepresent().equals("1")){
            person.setIsRepresent("是");
        }
        if (person.getIsEXserviceman().equals("0")){
            person.setIsEXserviceman("否");
        }else if (person.getIsEXserviceman().equals("1")){
            person.setIsEXserviceman("是");
        }
        if (person.getIsPoor().equals("0")){
            person.setIsPoor("否");
        }else if (person.getIsPoor().equals("1")){
            person.setIsPoor("是");
        }
        if (person.getIsFocusGroup().equals("0")){
            person.setIsFocusGroup("否");
        }else if (person.getIsFocusGroup().equals("1")){
            person.setIsFocusGroup("是");
        }
        if (person.getIsFocusPerson().equals("0")){
            person.setIsFocusPerson("否");
        }else if (person.getIsFocusPerson().equals("1")){
            person.setIsFocusPerson("是");
        }

        return person;
    }

    /**
     * 本系统相关记录
     * @param id
     * @return
     */
    @Override
    public Map<String, Object> personInitial(Long id) {
        Map<String, Object> map = new HashMap<>();
        List<MatterDto> matters = exportMapper.personInitial(id);
        if (matters.size()==1){
            map.put("visit","首次信访");
        }else {
            map.put("visit","多次信访");
        }
        map.put("registerTypecreateTime", matters.get(0).getRegisterType()+"  "+ DateTimeUtils.getDayMonthYear(matters.get(0).getCreateTime()));
        //来访
        int comeNum = matters.stream().filter((n) -> n.getRegisterTypeID().equals("001")).collect(Collectors.toList()).size();
        map.put("comeNum",comeNum);
        //来信
        int letterNum = matters.stream().filter((n) -> n.getRegisterTypeID().equals("002")).collect(Collectors.toList()).size();
        map.put("letterNum",letterNum);
        //来电
        int phoneNum = matters.stream().filter((n) -> n.getRegisterTypeID().equals("003")).collect(Collectors.toList()).size();
       map.put("phoneNum",phoneNum);
        //网上
        int netNum = matters.stream().filter((n) -> n.getRegisterTypeID().equals("004")).collect(Collectors.toList()).size();
        map.put("netNum",netNum);
        int size = matters.size();
        map.put("letterSum",size);
        // TODO: 2022/3/29  初次访问 统计 size1   重复反映  未反应
        //纯案数     初次访问 统计 size1   重复反映  未反应
        Integer visitSum = getvisitSum(matters);
        map.put("visitSum",visitSum);
        //越级访问
        int surpassNum = matters.stream().filter((n) -> String.valueOf(n.getIsleapfrog()).equals("1")).collect(Collectors.toList()).size();
        map.put("surpassNum",surpassNum);
        List<String> list =new ArrayList<>();
            for (MatterDto matter : matters) {
                String abnormalID = matter.getAbnormalID();
                if (StringUtils.isNotEmpty(abnormalID)){
                    String[] split = abnormalID.split(",");
                    for (String s : split) {
                        list.add(s);
                    }
                }
            }

       //非指定场所访
        int improperSum = list.stream().filter((n) -> n.equals("001002001") ||  n.equals("001002002")|| n.equals("001002003") || n.equals("001002004") ||  n.equals("001002005")||  n.equals("001002006")).collect(Collectors.toList()).size();
        map.put("improperSum",improperSum);
        //行为异常访
        int behaviorNotNum = list.stream().filter((n) -> n.equals("001003001") ||  n.equals("001003002")|| n.equals("001003003") || n.equals("001003004") ||  n.equals("001003005")||  n.equals("001003006")||  n.equals("001003007")|| n.equals("001003008")|| n.equals("001003009") || n.equals("001003010")).collect(Collectors.toList()).size();
        map.put("behaviorNotNum",behaviorNotNum);
        //携带危险器械
        int riskNum = list.stream().filter((n) -> n.equals("001003005")).collect(Collectors.toList()).size();
        map.put("riskNum",riskNum);
        //扬言信
        int threatenNum = list.stream().filter((n) -> n.equals("002001001") || n.equals("002001002")||  n.equals("002001003") ||n.equals("002001004") ||n.equals("002001005") ).collect(Collectors.toList()).size();
        map.put("threatenNum",threatenNum);
        //网上扬言
        int netraiseSum = list.stream().filter((n) -> n.equals("003001001") || n.equals("003001002")||  n.equals("003001003") ||n.equals("003001004") ||n.equals("003001005") ).collect(Collectors.toList()).size();
        map.put("netraiseSum",netraiseSum);
        //电话扬言
        int phoneraise = list.stream().filter((n) -> n.equals("004001001") || n.equals("004001002")||  n.equals("004001003") || n.equals("004001004") || n.equals("004001005") ).collect(Collectors.toList()).size();
        map.put("phoneraise",phoneraise);
        //累计异常信访
        map.put("Sum",list.size());

     //查询反映的信访事项信息
        List<MatterLetter> List = new ArrayList<MatterLetter>();
        for (MatterDto matter : matters) {
            MatterLetter matterLetter = new MatterLetter();

            matterLetter.setMatterNum(matter.getMatterNum());
            matterLetter.setXfName(matter.getXfName());
            //查询事项的处理结果
            List<MatterRelation> matterRelations = relationMapper.RelationList(matter.getId());
            //过滤重复的
            if (StringUtils.isNotEmpty(matterRelations)) {
                List<String> myList = new ArrayList<>();
                if (StringUtils.isNotEmpty(matterRelations)) {
                    List<String> newRelation = new ArrayList<>();
                    for (MatterRelation relation : matterRelations) {
                        newRelation.add(relation.getMatterA());
                        newRelation.add(relation.getMatterB());
                    }
                    myList = newRelation.stream().distinct().collect(Collectors.toList());
                }
                List<MatterDto> matterDtos = matterMapper.MessageList(myList);
                matterLetter.setCreateTime(DateTimeUtils.getDayMonthYear(matterDtos.get(0).getCreateTime()));
                if (StringUtils.isNotNull(matterDtos.get(matterDtos.size() - 1))) {
                    matterLetter.setLastTime(DateTimeUtils.getDayMonthYear(matterDtos.get(myList.size() - 1).getCreateTime()));
                }
                matterLetter.setNumber(String.valueOf(myList.size()));
            }else {
            matterLetter.setCreateTime(DateTimeUtils.getDayMonthYear(matter.getCreateTime()));
            matterLetter.setLastTime(DateTimeUtils.getDayMonthYear(matter.getCreateTime()));
            matterLetter.setNumber(String.valueOf(1));
            }
            //查询处理结果
            String id1 = matter.getId();
            List<FwTaskAct> takidstate = fwTaskActMapper.Takidstate(id1);
            if (StringUtils.isNotEmpty(takidstate)){
                matterLetter.setBusinessName(takidstate.get(0).getBusinessName());
            }else {
                matterLetter.setBusinessName("未办理");
            }
            List.add(matterLetter);
        }
        // TODO: 2022/4/12  人员反馈信息做可能做成成动态的()
        List<MatterLetter> matterLetters = List.subList(0, Math.min(5, List.size()));
        map.put("list",matterLetters);
        return map;
    }

    /**
     * 同件联名信署名人员名单
     * @param id
     * @return
     */
    @Override
    public Map<String, Object> networkList(String id) {
        Map<String, Object> map = new HashMap<>();
        List<ActivityVO1> activityVO = activityMapper.networkList(id);
        ActivityVO1 newactivityVO1 = new ActivityVO1();
            if (activityVO.size()==1){
                    BeanUtils.copyProperties(activityVO.get(0),newactivityVO1);
            }else {
                for (ActivityVO1 activityVO1 : activityVO) {
                    String objectName = activityVO1.getObjectName();
                    if (StringUtils.isNotEmpty(objectName)){
                        BeanUtils.copyProperties(activityVO1,newactivityVO1);
                    }
                }
        }
        //信访编号
        map.put("activityNum",newactivityVO1.getActivityNum());
        //来信群体名称
        map.put("objectName",newactivityVO1.getObjectName());
        //登记单位
        map.put("createOrg",newactivityVO1.getCreateOrg());
        //登记时间
        map.put("createPerson",newactivityVO1.getCreatePerson());
        //登记人
        map.put("createTimeName",DateTimeUtils.getDayMonthYear(newactivityVO1.getCreateTime()));
        //涉及的信访事项名称及编号
        List<Matter> matters = matterMapper.networkMatterList(newactivityVO1.getMatterID());
        String xfNamematterNum= "";
        for (Matter matter1 : matters) {
            if (StringUtils.isEmpty(xfNamematterNum)){
                xfNamematterNum=matter1.getXfName()+matter1.getMatterNum();
            }else {
                xfNamematterNum=xfNamematterNum+";"+matter1.getXfName()+matter1.getMatterNum();
            }

        }
        map.put("xfNamematterNum",xfNamematterNum);

        //人员名单
        String personID = newactivityVO1.getPersonID();
        List<String> personList = new ArrayList<>();
            if (personID.contains(",")) {
                String[] split = personID.split(",");
                for (String s : split) {
                    personList.add(s);
                }
            }else {
                personList.add(personID);
            }
            // 002002 联名信  1    001002 集体访 2  其他没有对应的类型 3
            List<Person> people = personMapper.PersonList(personList);
            List<PersonVO> peopleVo = new ArrayList<>();
            int i=0;
            //联名信
            if (newactivityVO1.getXfTypeID().equals("002002")){
                for (Person person : people) {
                    PersonVO newPeople = new PersonVO();
                    i=i+1;
                    newPeople.setSerial(String.valueOf(i));
                    newPeople.setName(person.getName());
                    newPeople.setIDType(person.getIDType());
                    newPeople.setIDNumber(person.getIDNumber());
                    newPeople.setMobilePhone(person.getMobilePhone());
                    peopleVo.add(newPeople);
                }
                map.put("mode","1");
                //集体访
            }else if (newactivityVO1.getXfTypeID().equals("001002")){
                for (Person person : people) {
                    PersonVO newPeople = new PersonVO();
                    i=i+1;
                    if (("1").equals(String.valueOf(i))){
                        newPeople.setIsRepresent("是");
                    }else {
                        newPeople.setIsRepresent("否");
                    }
                    newPeople.setSerial(String.valueOf(i));
                    newPeople.setName(person.getName());
                    newPeople.setIDType(person.getIDType());
                    newPeople.setIDNumber(person.getIDNumber());
                    newPeople.setMobilePhone(person.getMobilePhone());
                    peopleVo.add(newPeople);
                }
                map.put("mode","2");
                // 其他没有对应的类型
            }else {
                map.put("mode","3");
           }
                //联名人数
              map.put("personnumber",newactivityVO1.getXfNumber());
                //联名人员基本信息
              map.put("peopleVo",peopleVo);
        return map;
    }

    /**
     * 重复反映信访事项排查表
     *
     * @param matterDTO2
     * @return
     */
    @Override
    public List<Map<String, Object>> matterExclude(MatterDTO2 matterDTO2) {

        List<Matter> matters = exportMapper.selectMatters(matterDTO2);//筛选符合条件的matter
        List<Map<String, Object>> mapList = new ArrayList<>();
        Date startTime = matterDTO2.getStartTime();
        Date endTime = matterDTO2.getEndTime();
        long time1 = endTime.getTime();
        long time2 = startTime.getTime();
        List<String> createOrgIds = matterDTO2.getCreateOrgIds();
        matters.forEach(matter -> {//遍历matter列表
            SimpleDateFormat simpleDateFormat = new SimpleDateFormat("yyyy-MM-dd");
            Map<String, Object> map = new HashMap<>();
            String id = matter.getId();//得到此时的matterId
            MatterExport matterExport = exportMapper.selectMatterById(id);
            //根据id去查
            List<MatterRelationVo> matterRelation = exportMapper.relationList(id);//查询matterA与matterB的列表
            if (matterRelation.size() > 0) {
                AtomicReference<Integer> matterCount = new AtomicReference<>(0);//信访总次数
                AtomicReference<Integer> matterVisitCount = new AtomicReference<>(0);//来访反应次数
                if (matterExport.getRegisterTypeId().equals("001")) {
                    matterVisitCount.set(matterVisitCount.get() + 1);
                }
                AtomicReference<Integer> matterLetterCount = new AtomicReference<>(0);//来信反应次数
                if (matterExport.getRegisterTypeId().equals("002")) {
                    matterLetterCount.set(matterLetterCount.get() + 1);
                }
                AtomicReference<Integer> nowInternetCount = new AtomicReference<>(0);//当前网上反应次数
                if (matterExport.getRegisterTypeId().equals("004")) {
                    nowInternetCount.set(nowInternetCount.get() + 1);
                }
                AtomicReference<Integer> nowPhoneCount = new AtomicReference<>(0);//当前来电反应次数
                if (matterExport.getRegisterTypeId().equals("003")) {
                    nowPhoneCount.set(nowPhoneCount.get() + 1);
                }
                MatterDto matterDto = matterMapper.MessageAbstract(id);

                map.put("xfName", matterDto.getXfName());
                map.put("name", matterDto.getName());
                map.put("happenRegion", matterDto.getHappenRegion());
                map.put("belongs", matterDto.getBelongs());
                map.put("abstractName", matterDto.getAbstractName());
                Set<String> set = new HashSet<>();
                matterRelation.forEach(matterRelationVo -> {//遍历
                    String matterB = matterRelationVo.getMatterB();//得到matterB
                    String matterA = matterRelationVo.getMatterA();//得到matterA
                    set.add(matterA);
                    set.add(matterB);
                    if (id.equals(matterA)) {
                        MatterExport matter_b = exportMapper.selectMatterById(matterB);//查询matterB
                        String registerTypeIDB = matter_b.getRegisterTypeId();
                        Integer createOrgIDB = matter_b.getCreateOrgID();
                        Date createTimeBB = matter_b.getCreateTime();
                        long timeB = createTimeBB.getTime();
                        if (createOrgIds.contains(String.valueOf(createOrgIDB)) && (time2 <= timeB && timeB <= time1)) {
                            if (registerTypeIDB.equals("001")) {
                                matterVisitCount.set(matterVisitCount.get() + 1);
                            }
                            if (registerTypeIDB.equals("002")) {
                                matterLetterCount.set(matterLetterCount.get() + 1);
                            }
                            if (registerTypeIDB.equals("003")) {
                                nowPhoneCount.set(nowPhoneCount.get() + 1);
                            }
                            if (registerTypeIDB.equals("004")) {
                                nowInternetCount.set(nowInternetCount.get() + 1);
                            }
                        }
                        map.put("matterCount", Integer.parseInt(String.valueOf(matterLetterCount)) +
                                Integer.parseInt(String.valueOf(matterVisitCount))
                                + Integer.parseInt(String.valueOf(nowInternetCount))
                                + Integer.parseInt(String.valueOf(nowPhoneCount)));
                        map.put("matterVisitCount", Integer.valueOf(String.valueOf(matterVisitCount)));
                        map.put("matterLetterCount", Integer.valueOf(String.valueOf(matterLetterCount)));
                        map.put("nowInternetCount", Integer.valueOf(String.valueOf(nowInternetCount)));
                        map.put("nowPhoneCount", Integer.valueOf(String.valueOf(nowPhoneCount)));
                    }
                    if (id.equals(matterB)) {
                        MatterExport matter_a = exportMapper.selectMatterById(matterA);//查询matterB
                        Integer createOrgIDA = matter_a.getCreateOrgID();
                        Date createTimeAA = matter_a.getCreateTime();
                        long timeA = createTimeAA.getTime();
                        if (createOrgIds.contains(String.valueOf(createOrgIDA)) && (timeA >= time2 && timeA <= time1)) {
                            if (matter_a.getRegisterType().equals("001")) {
                                matterVisitCount.set(matterVisitCount.get() + 1);
                            }
                            if (matter_a.getRegisterType().equals("002")) {
                                matterLetterCount.set(matterLetterCount.get() + 1);
                            }
                            if (matter_a.getRegisterType().equals("003")) {
                                nowPhoneCount.set(nowPhoneCount.get() + 1);
                            }
                            if (matter_a.getRegisterType().equals("004")) {
                                nowInternetCount.set(nowInternetCount.get() + 1);
                            }
                        }
                        map.put("matterCount", Integer.parseInt(String.valueOf(matterLetterCount)) +
                                Integer.parseInt(String.valueOf(matterVisitCount))
                                + Integer.parseInt(String.valueOf(nowInternetCount))
                                + Integer.parseInt(String.valueOf(nowPhoneCount)));
                        map.put("matterVisitCount", Integer.valueOf(String.valueOf(matterVisitCount)));
                        map.put("matterLetterCount", Integer.valueOf(String.valueOf(matterLetterCount)));
                        map.put("nowInternetCount", Integer.valueOf(String.valueOf(nowInternetCount)));
                        map.put("nowPhoneCount", Integer.valueOf(String.valueOf(nowPhoneCount)));
                    }
                });
                map.put("historyCount",set.size());
                //首次
                MatterRelationVo relationVo = matterRelation.get(matterRelation.size() - 1);
                if (id.equals(relationVo.getMatterA())) {
                    MatterExport matterB = exportMapper.selectMatterById(relationVo.getMatterB());
                    if (createOrgIds.contains(String.valueOf(matterB.getCreateOrgID()))) {
                        map.put("nowNature", matterExport.getRegisterType());
                        String format = simpleDateFormat.format(matterB.getCreateTime());
                        map.put("nowReflectTime", format);
                        map.put("nowReflectUnit", matterB.getCreateOrg());
                    }
                }
                if (id.equals(relationVo.getMatterB())) {
                    MatterExport matterA = exportMapper.selectMatterById(relationVo.getMatterA());
                    if (createOrgIds.contains(String.valueOf(matterA.getCreateOrgID()))) {
                        map.put("nowNature", matterExport.getRegisterType());
                        String format = simpleDateFormat.format(matterA.getCreateTime());
                        map.put("nowReflectTime", format);
                        map.put("nowReflectUnit", matterA.getCreateOrg());
                    }
                }
                //最近
                MatterRelationVo matterRelationVo1 = matterRelation.get(0);
                if (id.equals(matterRelationVo1.getMatterA())) {
                    MatterExport matterB = exportMapper.selectMatterById(relationVo.getMatterB());
                    if (createOrgIds.contains(String.valueOf(matterB.getCreateOrgID()))) {
                        map.put("firstNature", matterExport.getRegisterType());
                        String format = simpleDateFormat.format(matterB.getCreateTime());
                        map.put("firstReflectTime", format);
                        map.put("firstReflectUnit", matterB.getCreateOrg());
                    }
                }
                if (id.equals(matterRelationVo1.getMatterB())) {
                    MatterExport matterA = exportMapper.selectMatterById(relationVo.getMatterA());
                    if (createOrgIds.contains(String.valueOf(matterA.getCreateOrgID()))) {
                        map.put("firstNature", matterExport.getRegisterType());
                        String format = simpleDateFormat.format(matterA.getCreateTime());
                        map.put("firstReflectTime", format);
                        map.put("firstReflectUnit", matterA.getCreateOrg());
                    }
                }
                mapList.add(map);
            }
        });
        return mapList;
    }

    /**
     * 信访老户排查表
     *
     * @param personExport1
     * @return
     */
    @Override
    public List<Map<String, Object>> matterOldUser(PersonExport personExport1) {
        List<Map<String, Object>> mapList = new ArrayList<>();
        List<PersonExport> personExports = exportMapper.selectPersons(personExport1);
        personExports.forEach(personExport -> {
            Map<String, Object> map = new HashMap<>();
            Integer id1 = personExport.getId();
            List<Activity_Person> activity_people = exportMapper.selectActivityIDById(String.valueOf(id1));//连表查询
            int size = activity_people.size();
            if (size >= 2) {//如果大于两条记录说明是老户符合条数
                Person person = exportMapper.selectPerson(id1.longValue());//查出此id对应在人员表中的人员
                AtomicReference<Integer> matterCounts = new AtomicReference<>(0);
                AtomicReference<Integer> matterVisitCount = new AtomicReference<>(0);
                AtomicReference<Integer> matterLetterCount = new AtomicReference<>(0);
                AtomicReference<Integer> matterPhoneCount = new AtomicReference<>(0);
                AtomicReference<Integer> matterLineCount = new AtomicReference<>(0);

                map.put("historyCount", size);
                //户口所在地处理
                String domicileId = person.getDomicileId();
                if (StringUtils.isNotEmpty(domicileId)) {
                    String substring1 = domicileId.substring(0, 3);//上上级
                    String substring = domicileId.substring(0, 6);//上级
                    String s = exportMapper.selectDomicileById(substring1);//上上级
                    String s1 = exportMapper.selectDomicileById(substring);//上级
                    String domicileNew = s + "/" + s1 + "/" + person.getDomicile();
                    person.setDomicile(domicileNew);
                    map.put("idCardRegion", person.getDomicile());
                } else {
                    map.put("idCardRegion", " ");
                }
                map.put("name", person.getName());
                map.put("idCardAddress", person.getIdCardAddress());
                map.put("IDNumber", person.getIDNumber());
                SimpleDateFormat simpleDateFormat = new SimpleDateFormat("yyyy-MM-dd");
                long time1 = personExport1.getStartTime().getTime();
                long time2 = personExport1.getEndTime().getTime();
                List<String> createOrgIds = personExport1.getCreateOrgIds();
                activity_people.stream().filter(p -> StringUtils.isNotEmpty(p.getRegisterTypeId()) && (p.getCreateTime() != null))
                        .forEach(activity_person1 -> {//遍历连表之后的记录
                            String createOrgIdAc = activity_person1.getCreateOrgId();
                            Date createTimeAc = activity_person1.getCreateTime();//时间
                            long acTime = createTimeAc.getTime();
                            String registerTypeId = activity_person1.getRegisterTypeId();
                            if (createOrgIds.contains(createOrgIdAc) && (acTime <= time2 && acTime >= time1)) {
                                //此时为当期
                                if (registerTypeId.equals("001")) {
                                    matterVisitCount.set(matterVisitCount.get() + 1);
                                }
                                if (registerTypeId.equals("002")) {
                                    matterLetterCount.set(matterLetterCount.get() + 1);
                                }
                                if (registerTypeId.equals("003")) {
                                    matterPhoneCount.set(matterPhoneCount.get() + 1);
                                }
                                if (registerTypeId.equals("004")) {
                                    matterLineCount.set(matterLineCount.get() + 1);
                                }
                            }
                            map.put("matterVisitCount", Integer.valueOf(String.valueOf(matterVisitCount)));
                            map.put("matterLineCount", Integer.valueOf(String.valueOf(matterLineCount)));
                            map.put("matterLetterCount", Integer.valueOf(String.valueOf(matterLetterCount)));
                            map.put("matterPhoneCount", Integer.valueOf(String.valueOf(matterPhoneCount)));
                            map.put("matterCounts", Integer.parseInt(String.valueOf(matterLetterCount)) +
                                    Integer.parseInt(String.valueOf(matterVisitCount)) +
                                    Integer.parseInt(String.valueOf(matterLineCount)) +
                                    Integer.parseInt(String.valueOf(matterPhoneCount)));
                        });
                Activity_Person activityPerson_curr = activity_people.get(0);
                if (activityPerson_curr.getCreateOrgId() != null && createOrgIds.contains(activityPerson_curr.getCreateOrgId())) {
                    map.put("firstType", activityPerson_curr.getRegisterType());
                    String format = simpleDateFormat.format(activityPerson_curr.getCreateTime());
                    map.put("firstTime", format);
                }

                //最近
                Activity_Person activity_person_first = activity_people.get(activity_people.size() - 1);
                if (createOrgIds.contains(activity_person_first.getCreateOrgId())) {
                    map.put("currentType", activity_person_first.getRegisterType());
                    String format = simpleDateFormat.format(activity_person_first.getCreateTime());
                    map.put("currentTime", format);
                }
                mapList.add(map);
            }
        });
        return mapList;
    }

    @Override
    public Map<String, Object> peopleActivity(String id) {
        Map<String, Object> map =new HashMap<>();
        ActivityVO2 activityVO2 = exportMapper.peopleActivity(id);
        //信访编号
        map.put("activityNum",activityVO2.getActivityNum());
        //信访形式
        map.put("registerType",activityVO2.getRegisterType());
        //信访来源
        map.put("xfSource",activityVO2.getXfSource());
        //信访类型
        map.put("xfType",activityVO2.getXfType());
        //信访性质
        map.put("xfNature",activityVO2.getXfNature());
        //姓名或名称
        map.put("name",activityVO2.getName());
        //联系方式
        map.put("mobilePhone",activityVO2.getMobilePhone());
        //证件类型
        map.put("IDType",activityVO2.getIDType());
        //证件号码
        map.put("IDNumber",activityVO2.getIDNumber());
        //所属地区
        map.put("idCardRegion",activityVO2.getIdCardRegion());
        //详细地址
        map.put("idCardAddress",activityVO2.getIdCardAddress());
        //现住址
        map.put("address",activityVO2.getAddress());
        //是否为诉求主体
        String isSubject = activityVO2.getIsSubject();
        if (isSubject.equals("1")){
            map.put("isSubject","是");
        }else {
            map.put("isSubject","否");
        }
        //与诉求主体的关系
        map.put("relationWithSubject",activityVO2.getRelationWithSubject());
        //诉求主体姓名或名称
        map.put("objectName",activityVO2.getObjectName());
        //异常信访类型
        String isAbnormal = activityVO2.getAbnormalID();
        if (StringUtils.isNotEmpty(isAbnormal)){
            String[] split = isAbnormal.split(",");
            String isAbnormalMore="";
            for (String s : split) {
                Dictionary yz = dictionaryMapper.DictionaryOne("YZ", s);
                String description = yz.getDescription();
                if (StringUtils.isNotEmpty(isAbnormalMore)){
                    isAbnormalMore=isAbnormalMore+"；"+description;
                }else {
                    isAbnormalMore=description;
                }
            }
            map.put("isAbnormal",isAbnormalMore);
        }else {
            map.put("isAbnormal",isAbnormal);
        }
        //信访人数
        map.put("xfNumber",activityVO2.getXfNumber());
        String personID = activityVO2.getPersonID();
        if (personID.contains(",")){
            List<String> personList = new ArrayList<>();
            String[] split = personID.split(",");
            for (String s : split) {
                personList.add(s);
            }
            //总信访人数
//            map.put("xfNumber",activityVO2.getXfNumber());
            //共同信访人数
            personList.remove(personList.get(0));
            List<Person> people = personMapper.PersonList(personList);
            List<Person> newpeople = people.subList(0, Math.min(4, people.size()));
            String personName="";
            for (Person person : newpeople) {
                if (StringUtils.isNotEmpty(personName)){
                    String idNumber = person.getIDNumber();
                    if (StringUtils.isNotEmpty(idNumber)){
                        personName=personName+";"+person.getName()+":"+idNumber;
                    }else {
                        personName=personName+";"+person.getName();
                    }
                }else {
                    String idNumber = person.getIDNumber();
                    if (StringUtils.isNotEmpty(idNumber)){
                        personName=person.getName()+":"+idNumber;
                    }else {
                        personName=person.getName();
                    }
                }
            }
            map.put("personName",personName);
        }else {
//            map.put("xfNumber","1");
            map.put("personName","");
        }
        //本次登记单位
        map.put("createOrg",activityVO2.getCreateOrg());
        //本次登记时间
        map.put("createTime",DateTimeUtils.getDayMonthYear(activityVO2.getCreateTime()));
        //本次登记人
        map.put("createPerson",activityVO2.getCreatePerson());
        //此信访人在本系统相关记录
        List<MatterDto> matters = exportMapper.personInitial(activityVO2.getPerid());
        if (matters.size()==1){
            map.put("firstMore","首次信访");
        }else {
            map.put("firstMore","多次信访");
        }

        map.put("registerTypecreateTime", matters.get(0).getRegisterType()+"  "+ DateTimeUtils.getDayMonthYear(matters.get(0).getCreateTime()));

        //来访
        int visitorNum = matters.stream().filter((n) -> n.getRegisterTypeID().equals("001")).collect(Collectors.toList()).size();
        map.put("visitorNum",visitorNum);
        //来信
        int letterNum = matters.stream().filter((n) -> n.getRegisterTypeID().equals("002")).collect(Collectors.toList()).size();
        map.put("letterNum",letterNum);
        //来电
        int phoneNum = matters.stream().filter((n) -> n.getRegisterTypeID().equals("003")).collect(Collectors.toList()).size();
        map.put("phoneNum",phoneNum);
        //网上
        int internetNum = matters.stream().filter((n) -> n.getRegisterTypeID().equals("004")).collect(Collectors.toList()).size();
        map.put("internetNum",internetNum);
        //
        int size = matters.size();
        map.put("letterSum",size);
        //共信访
        //纯案数     初次访问 统计 size1   重复反映  未反应
        Integer newNum = getvisitSum(matters);
        map.put("visitSum",newNum);
        //越级访问
        int surpassNum = matters.stream().filter((n) -> String.valueOf(n.getIsleapfrog()).equals("1")).collect(Collectors.toList()).size();
        map.put("surpassNum",surpassNum);
        List<String> list =new ArrayList<>();
        for (MatterDto matter : matters) {
            String abnormalID = matter.getAbnormalID();
            if (StringUtils.isNotEmpty(abnormalID)){
                String[] split = abnormalID.split(",");
                for (String s : split) {
                    list.add(s);
                }
            }
        }
            //非指定场所访
            Long notbelongNum = list.stream().filter((n) -> n.equals("001002001") ||  n.equals("001002002")|| n.equals("001002003") || n.equals("001002004") ||  n.equals("001002005")||  n.equals("001002006")).count();
            map.put("notbelongNum",String.valueOf(notbelongNum));
            //行为异常访
            Long abnormalNum = list.stream().filter((n) -> n.equals("001003001") ||  n.equals("001003002")|| n.equals("001003003") || n.equals("001003004") ||  n.equals("001003005")||  n.equals("001003006")||  n.equals("001003007")|| n.equals("001003008")|| n.equals("001003009") || n.equals("001003010")).count();
            map.put("abnormalNum",String.valueOf(abnormalNum));
            //携带危险器械
            Long riskNum = list.stream().filter((n) -> n.equals("001003005")).count();;
            map.put("riskNum",String.valueOf(riskNum));
            //扬言信
           Long threatenNum = list.stream().filter((n) -> n.equals("002001001") || n.equals("002001002")||  n.equals("002001003") ||n.equals("002001004") ||n.equals("002001005") ).count();
            map.put("threatenNum",String.valueOf(threatenNum));
            //网上扬言
            Long netcomplainNum = list.stream().filter((n) -> n.equals("003001001") || n.equals("003001002")||  n.equals("003001003") ||n.equals("003001004") ||n.equals("003001005") ).count();
            map.put("netcomplainNum",String.valueOf(netcomplainNum));
            //电话扬言
            Long phonecomplainNum = list.stream().filter((n) -> n.equals("004001001") || n.equals("004001002")||  n.equals("004001003") ||n.equals("004001004") ||n.equals("004001005") ).count();
            map.put("phonecomplainNum",String.valueOf(phonecomplainNum));
            //累计异常信访
            map.put("Sum",list.size());

        String matterID = activityVO2.getMatterID();
        String[] split = matterID.split(",");
        MatterDto matterDto1 ;
        MatterDto matterDto2 ;
        MatterDto matterDto3 ;
        int i=0;
        List<MatterDto> list1 =new ArrayList<>();
        List<MatterDto> list2 =new ArrayList<>();
        List<MatterDto> list3 =new ArrayList<>();
        for (String s : split) {
            i=i+1;
            MatterDto matterVO = matterMapper.onceMatter(s);

            //反映内容分类
            Dictionary dictionary;
            String contentClassifyID = matterVO.getContentClassifyID();
            String[] split1 = contentClassifyID.split(",");
            List<Matter> MatterDiscipline = new ArrayList<>();
            for (String contentClass : split1) {
                Matter matter =new Matter();
                dictionary = dictionaryMapper.DictionaryBasic(contentClass);
                matter.setContentClassify(dictionary.getDescription());
                for (int a = 3; a <contentClass.length() ; a+=3) {
                    if (StringUtils.isNotEmpty(dictionary.getParentValue())){
                        String dictValue = dictionary.getDictValue().substring(0,dictionary.getDictValue().length() - 3);
                        dictionary= dictionaryMapper.DictionaryBasic(dictValue);
                        String description = dictionary.getDescription();
                        matter.setContentClassify(description+"->"+matter.getContentClassify());
                    }else {
                        matter.setContentClassify(dictionary.getDescription()+"->"+matter.getContentClassify());
                    }
                }
                MatterDiscipline.add(matter);
            }
            Matter matter02 =new Matter();
            for (Matter matter : MatterDiscipline) {
                if (StringUtils.isEmpty(matter02.getContentClassify())){
                    matter02.setContentClassify(matter.getContentClassify());
                }else {
                    matter02.setContentClassify(matter.getContentClassify()+" "+matterVO.getContentClassify());
                }
            }
            matterVO.setContentClassify(matter02.getContentClassify());
            List<MatterRelation> matterRelations = relationMapper.RelationList(s);
            if (matterRelations.size()<=1){
                matterVO.setVisit("初次");
            }else {
                matterVO.setVisit("重复");
            }
            if ("1".equals(String.valueOf(matterVO.getIsAccept()))){
                matterVO.setIsAcceptName("否");
            }else {
                matterVO.setIsAcceptName("是");
            }
            if ("1".equals(String.valueOf(i))){
                matterDto1=matterVO;
                list1.add(matterDto1);
            } else if ("2".equals(String.valueOf(i))) {
                matterDto2=matterVO;
                list2.add(matterDto2);
            }else {
                matterDto3=matterVO;
                list3.add(matterDto3);
            }
        }
        map.put("list1",list1);
        map.put("list2",list2);
        map.put("list3",list3);
        return map;
    }

    private Integer getvisitSum(List<MatterDto> matters) {
        Integer newNum=0;
        int Num=0;
        for (MatterDto matter : matters) {
            List<MatterRelation> matterRelations = relationMapper.RelationList(matter.getId());
            //过滤重复的
            if (StringUtils.isNotEmpty(matterRelations)) {
                    List<String> myList = new ArrayList<>();
                    Num= Num+1;
                    List<String> newRelation = new ArrayList<>();
                    for (MatterRelation relation : matterRelations) {
                        newRelation.add(relation.getMatterA());
                        newRelation.add(relation.getMatterB());
                    }
                    myList = newRelation.stream().distinct().collect(Collectors.toList());
                    if (String.valueOf(Num).equals("1")){
                        newNum  =matters.size()-myList.size()+ 1;
                    }else {
                        newNum  =newNum-myList.size()+ 1;
                    }
            }else {
                if ("0".equals(String.valueOf(Num))){
                    newNum  =matters.size();
                }else {
                    newNum  =newNum+0;
                }
            }
        }
        return newNum;
    }

    @Override
    public Map<String, Object> GradeExportList(GradeExport gradeExport) throws ParseException {
        Dept dept = deptMapper.districtType(gradeExport.getCreateOrgID());
        //设置时间结束时间格式 23时59分59秒
        gradeExport.setEndTime(DateTimeUtils.getTodayTime(gradeExport.getEndTime()));
        Map<String, Object> map = new HashMap<>();
        gradeExport.setGrade("全国人大代表");
        List<GradeExport> gradeExports = GradeStatistics(gradeExport);
        map.put("gradeExports",gradeExports);
        gradeExport.setGrade("省人大代表");
        List<GradeExport> provinceExports = GradeStatistics(gradeExport);
        map.put("provinceExports",provinceExports);
        //一个空的集合对象
        List<GradeExport>  newNull =  new ArrayList<>();
        GradeExport newGrade =new GradeExport();
        newGrade.setBatchNum(0);
        newGrade.setPerNum(0);
        newGrade.setBehalfNum(0);
        newGrade.setBehalfPer(0);
        newGrade.setLeadNumPer(0);
        newGrade.setLeadNum(0);
        newGrade.setLetterSum(0);
        newGrade.setSendlettereNum(0);
        newGrade.setRotateNum(0);
        newNull.add(newGrade);
        //Grade  2 省   3 市  4县
        if ("2".equals(String.valueOf(dept.getType()))){
            List<GradeExport> sumGrade = countySum(gradeExports, provinceExports, newNull, newNull);
            map.put("sumGrade",sumGrade);
            map.put("Grade","a");
        }else  if ("3".equals(String.valueOf(dept.getType()))){
            gradeExport.setGrade("市人大代表");
            List<GradeExport> cityExports = GradeStatistics(gradeExport);
            map.put("cityExports",cityExports);
            List<GradeExport> sumGrade = countySum(gradeExports, provinceExports, cityExports, newNull);
            map.put("sumGrade",sumGrade);
            map.put("Grade","b");
        }else {
            gradeExport.setGrade("市人大代表");
            List<GradeExport> cityExports = GradeStatistics(gradeExport);
            map.put("cityExports",cityExports);
            gradeExport.setGrade("县人大代表");
            List<GradeExport> countyExports = GradeStatistics(gradeExport);
            map.put("countyExports",countyExports);
            List<GradeExport> sumGrade = countySum(gradeExports, provinceExports, cityExports, countyExports);
            map.put("sumGrade",sumGrade);
            map.put("Grade","c");
        }
        return map;
    }

    private  List<GradeExport>  countySum( List<GradeExport> gradeExports, List<GradeExport> provinceExports, List<GradeExport> cityExports, List<GradeExport> countyExports) {
        List<GradeExport> sumGrade =new ArrayList<>();
        //如果县级
        GradeExport sum = new GradeExport();
        //代表来访，引导来访  批次数 总数
        sum.setBatchNum(gradeExports.get(0).getBatchNum()+provinceExports.get(0).getBatchNum()+cityExports.get(0).getBatchNum()+countyExports.get(0).getBatchNum());
        //代表来访 引导来访 人数 总人数
        sum.setPerNum(gradeExports.get(0).getPerNum()+provinceExports.get(0).getPerNum()+cityExports.get(0).getPerNum()+countyExports.get(0).getPerNum());
        //代表来访 批次数
        sum.setBehalfNum(gradeExports.get(0).getBehalfNum()+provinceExports.get(0).getBehalfNum()+cityExports.get(0).getBehalfNum()+countyExports.get(0).getBehalfNum());
        //代表来访 人数
        sum.setBehalfPer(gradeExports.get(0).getBehalfPer()+provinceExports.get(0).getBehalfPer()+cityExports.get(0).getBehalfPer()+countyExports.get(0).getBehalfPer());
        //代表引导来访  批次数
        sum.setLeadNum(gradeExports.get(0).getLeadNum()+provinceExports.get(0).getLeadNum()+cityExports.get(0).getLeadNum()+countyExports.get(0).getLeadNum());
        //代表引导来访  人数
        sum.setLeadNumPer(gradeExports.get(0).getLeadNumPer()+provinceExports.get(0).getLeadNumPer()+cityExports.get(0).getLeadNumPer()+countyExports.get(0).getLeadNumPer());
        //代表来信转信件数
        sum.setLetterSum(gradeExports.get(0).getLetterSum()+provinceExports.get(0).getLetterSum()+cityExports.get(0).getLetterSum()+countyExports.get(0).getLetterSum());
        //代表来信件次
        sum.setSendlettereNum(gradeExports.get(0).getSendlettereNum()+provinceExports.get(0).getSendlettereNum()+cityExports.get(0).getSendlettereNum()+countyExports.get(0).getSendlettereNum());
        //代表转信件次
        sum.setRotateNum(gradeExports.get(0).getRotateNum()+provinceExports.get(0).getRotateNum()+cityExports.get(0).getRotateNum()+countyExports.get(0).getRotateNum());
        sumGrade.add(sum);
        return sumGrade;
    }

    private List<GradeExport> GradeStatistics(GradeExport gradeExport) {
        List<GradeExport> totalListList = new ArrayList<>();
        List<ActivityVO1> countryList = activityMapper.hierarchyList(gradeExport);
        List<ActivityVO1> countrycollect = countryList.stream().filter((n) -> n.getXfSourceID().equals("001004") || n.getXfSourceID().equals("001003")).collect(Collectors.toList());
        GradeExport countryGrade  = new GradeExport();
        //代表来访，引导来访  批次数
        countryGrade.setBatchNum(countrycollect.size());
        //代表来访 引导来访 人数
        countryGrade.setPerNum(PersonSum(countrycollect));
        //代表来访 批次数
        List<ActivityVO1> behalf = countrycollect.stream().filter((n) -> n.getXfSourceID().equals("001004")).collect(Collectors.toList());
        countryGrade.setBehalfNum(behalf.size());
        //代表来访 人数
        countryGrade.setBehalfPer(PersonSum(behalf));

        //代表引导来访  批次数
        List<ActivityVO1> lead = countrycollect.stream().filter((n) -> n.getXfSourceID().equals("001003")).collect(Collectors.toList());
        countryGrade.setLeadNum(lead.size());
        //代表引导来访  人数
        countryGrade.setLeadNumPer(PersonSum(lead));
        //代表来信转信件数
        List<ActivityVO1> letter = countryList.stream().filter((n) -> n.getXfSourceID().equals("002003") || n.getXfSourceID().equals("002006")).collect(Collectors.toList());
        countryGrade.setLetterSum(letter.size());
        //代表来信件次
        List<ActivityVO1> Sendlettere = letter.stream().filter((n) -> n.getXfSourceID().equals("002006")).collect(Collectors.toList());
        countryGrade.setSendlettereNum(Sendlettere.size());
        //代表转信件次
        List<ActivityVO1> Rotate = letter.stream().filter((n) -> n.getXfSourceID().equals("002003")).collect(Collectors.toList());
        countryGrade.setRotateNum(Rotate.size());
        totalListList.add(countryGrade);
        return totalListList;
    }

    private  Integer PersonSum(List<ActivityVO1> PersonList) {
        Integer numberPer =0 ;
        for (ActivityVO1 activityVO1 : PersonList) {
            numberPer = numberPer+activityVO1.getXfNumber();
        }
        return numberPer;
    }

    @Override
    public List<ActivityDto> exclFLtjList(AffiliationMatter affiliationMatter) throws ParseException {

        //传入的时间
        Date currTime = affiliationMatter.getStartTime();
        Date lastTime = DateTimeUtils.getTodayTime(affiliationMatter.getEndTime());
        // 同比开始时间与结束时间
        Date currTBTime = DateTimeUtils.getStartHBTime(affiliationMatter.getStartTime());
        Date lastTBTime = DateTimeUtils.getEndHBTime(affiliationMatter.getEndTime());
        //当年累计时间
        Date currYearTime = DateTimeUtils.getCurrYearFirst();
        Date lastYearTime = new Date();

        // //当年累计时间 同比开始时间与结束时间
        Date currYearTBTime = DateTimeUtils.getStartHBTime(currYearTime);
        Date lastYearTBTime = DateTimeUtils.getEndHBTime(lastYearTime);
        //选择统计时间
        affiliationMatter.setStartTime(currTime);
        affiliationMatter.setEndTime(lastTime);
        List<MatterDto> matterDtos = exportMapper.exclFLtjList(affiliationMatter);
        Map<String, Integer> chuliFs = getChuliFs(matterDtos);
       // 选择统计时间 同比时间
        affiliationMatter.setStartTime(currTBTime);
        affiliationMatter.setEndTime(lastTBTime);
        List<MatterDto> matterDtosTB = exportMapper.exclFLtjList(affiliationMatter);
        Map<String, Integer> chuliFsTB = getChuliFs(matterDtosTB);
        //当年时间
        affiliationMatter.setStartTime(currYearTime);
        affiliationMatter.setEndTime(lastYearTime);
        List<MatterDto> matterDtosDN = exportMapper.exclFLtjList(affiliationMatter);
        Map<String, Integer> chuliFsDN = getChuliFs(matterDtosDN);
        //当年同比时间
        affiliationMatter.setStartTime(currYearTBTime);
        affiliationMatter.setEndTime(lastYearTBTime);
        List<MatterDto> matterDtosDNTB = exportMapper.exclFLtjList(affiliationMatter);
        Map<String, Integer> chuliFsDNTB = getChuliFs(matterDtosDNTB);
        List<ActivityDto> yfFl = new ArrayList<>();
        //转行政  交办转送
        yfFl.add(YFflzbDto(chuliFs.get("xzjb")+chuliFs.get("xzzs"),chuliFsTB.get("xzjb")+chuliFsTB.get("xzzs"),chuliFsDN.get("xzjb")+chuliFsDN.get("xzzs"),chuliFsDNTB.get("xzjb")+chuliFsDNTB.get("xzzs")));
             //交办
        yfFl.add(YFflzbDto(chuliFs.get("xzjb"),chuliFsTB.get("xzjb"),chuliFsDN.get("xzjb"),chuliFsDNTB.get("xzjb")));
             //转送
        yfFl.add(YFflzbDto(chuliFs.get("xzzs"),chuliFsTB.get("xzzs"),chuliFsDN.get("xzzs"),chuliFsDNTB.get("xzzs")));
        //转  监察
        yfFl.add(YFflzbDto(chuliFs.get("monitorjb")+chuliFs.get("monitorzs"),chuliFsTB.get("monitorjb")+chuliFsTB.get("monitorzs"),chuliFsDN.get("monitorjb")+chuliFsDN.get("monitorzs"),chuliFsDNTB.get("monitorjb")+chuliFsDNTB.get("monitorzs")));
        //交办
        yfFl.add(YFflzbDto(chuliFs.get("monitorjb"),chuliFsTB.get("monitorjb"),chuliFsDN.get("monitorjb"),chuliFsDNTB.get("monitorjb")));
        //转送
        yfFl.add(YFflzbDto(chuliFs.get("monitorzs"),chuliFsTB.get("monitorzs"),chuliFsDN.get("monitorzs"),chuliFsDNTB.get("monitorzs")));

        //转行审判
        yfFl.add(YFflzbDto(chuliFs.get("spjb")+chuliFs.get("spzs"),chuliFsTB.get("spjb")+chuliFsTB.get("spzs"),chuliFsDN.get("spjb")+chuliFsDN.get("spzs"),chuliFsDNTB.get("spjb")+chuliFsDNTB.get("spzs")));
        //交办
        yfFl.add(YFflzbDto(chuliFs.get("spjb"),chuliFsTB.get("spjb"),chuliFsDN.get("spjb"),chuliFsDNTB.get("spjb")));
        //转送
        yfFl.add(YFflzbDto(chuliFs.get("spzs"),chuliFsTB.get("spzs"),chuliFsDN.get("spzs"),chuliFsDNTB.get("spzs")));


        //转行检察
        yfFl.add(YFflzbDto(chuliFs.get("examinejb")+chuliFs.get("examinezs"),chuliFsTB.get("examinejb")+chuliFsTB.get("examinezs"),chuliFsDN.get("examinejb")+chuliFsDN.get("examinezs"),chuliFsDNTB.get("examinejb")+chuliFsDNTB.get("examinezs")));
        //交办
        yfFl.add(YFflzbDto(chuliFs.get("examinejb"),chuliFsTB.get("examinejb"),chuliFsDN.get("examinejb"),chuliFsDNTB.get("examinejb")));
        //转送
        yfFl.add(YFflzbDto(chuliFs.get("examinezs"),chuliFsTB.get("examinezs"),chuliFsDN.get("examinezs"),chuliFsDNTB.get("examinezs")));

        //转行检察
        yfFl.add(YFflzbDto(chuliFs.get("gajb")+chuliFs.get("gazs"),chuliFsTB.get("gajb")+chuliFsTB.get("gazs"),chuliFsDN.get("gajb")+chuliFsDN.get("gazs"),chuliFsDNTB.get("gajb")+chuliFsDNTB.get("gazs")));
        //交办
        yfFl.add(YFflzbDto(chuliFs.get("gajb"),chuliFsTB.get("gajb"),chuliFsDN.get("gajb"),chuliFsDNTB.get("gajb")));
        //转送
        yfFl.add(YFflzbDto(chuliFs.get("gazs"),chuliFsTB.get("gazs"),chuliFsDN.get("gazs"),chuliFsDNTB.get("gazs")));
        //人大机关处理
        yfFl.add(YFflzbDto(chuliFs.get("rd"),chuliFsTB.get("rd"),chuliFsDN.get("rd"),chuliFsDNTB.get("rd")));
        //交办
        yfFl.add(YFflzbDto(chuliFs.get("rdjb"),chuliFsTB.get("rdjb"),chuliFsDN.get("rdjb"),chuliFsDNTB.get("rdjb")));
        //转送
        yfFl.add(YFflzbDto(chuliFs.get("rdzs"),chuliFsTB.get("rdzs"),chuliFsDN.get("rdzs"),chuliFsDNTB.get("rdzs")));
        //自办
        yfFl.add(YFflzbDto(chuliFs.get("rdzb"),chuliFsTB.get("rdzb"),chuliFsDN.get("rdzb"),chuliFsDNTB.get("rdzb")));
        //存信 存件 接谈
        yfFl.add(YFflzbDto(chuliFs.get("rdcxcjjt"),chuliFsTB.get("rdcxcjjt"),chuliFsDN.get("rdcxcjjt"),chuliFsDNTB.get("rdcxcjjt")));
        return yfFl;
    }

    //处理方式
    private Map<String, Integer> getChuliFs(List<MatterDto> matterDtos) {
        Map<String, Integer> map =new HashMap<>();
        List<MatterDto> xz = matterDtos.stream().filter((n) -> !String.valueOf(n.getCreateOrgID()).equals(String.valueOf(n.getFinalDisposalID())) && String.valueOf(n.getIsRenDa()).equals("0")).collect(Collectors.toList());
        Map<String, Integer> getxz = getjbzs(xz);
        Integer xzjb = getxz.get("jb");
        Integer xzzs = getxz.get("zs");
        map.put("xzjb",xzjb);
        map.put("xzzs",xzzs);
        //转监察机关处理
        List<MatterDto> monitor = matterDtos.stream().filter((n) -> !String.valueOf(n.getCreateOrgID()).equals(String.valueOf(n.getFinalDisposalID())) && String.valueOf(n.getIsRenDa()).equals("4")).collect(Collectors.toList());
        Map<String, Integer> getmonitor = getjbzs(monitor);
        Integer monitorjb = getmonitor.get("jb");
        Integer monitorzs = getmonitor.get("zs");
        map.put("monitorjb",monitorjb);
        map.put("monitorzs",monitorzs);
        //转审判机关处理
        List<MatterDto> sp = matterDtos.stream().filter((n) -> !String.valueOf(n.getCreateOrgID()).equals(String.valueOf(n.getFinalDisposalID())) && String.valueOf(n.getIsRenDa()).equals("2")).collect(Collectors.toList());
        Map<String, Integer> getsp = getjbzs(sp);
        Integer spjb = getsp.get("jb");
        Integer spzs = getsp.get("zs");
        map.put("spjb",spjb);
        map.put("spzs",spzs);
        //转检察机关处理
        List<MatterDto> examine = matterDtos.stream().filter((n) -> !String.valueOf(n.getCreateOrgID()).equals(String.valueOf(n.getFinalDisposalID())) && String.valueOf(n.getIsRenDa()).equals("3")).collect(Collectors.toList());
        Map<String, Integer> getexamine = getjbzs(examine);
        Integer examinejb = getexamine.get("jb");
        Integer examinezs = getexamine.get("zs");
        map.put("examinejb",examinejb);
        map.put("examinezs",examinezs);
        //转公安机关处理
        List<MatterDto> ga = matterDtos.stream().filter((n) -> !String.valueOf(n.getCreateOrgID()).equals(String.valueOf(n.getFinalDisposalID())) && String.valueOf(n.getIsRenDa()).equals("5")).collect(Collectors.toList());
        Map<String, Integer> getjbzsga = getjbzs(ga);
        Integer gajb = getjbzsga.get("jb");
        Integer gazs = getjbzsga.get("zs");
        map.put("gajb",gajb);
        map.put("gazs",gazs);
        //人大机关处理
        List<MatterDto> rd = matterDtos.stream().filter((n) ->  String.valueOf(n.getIsRenDa()).equals("1")).collect(Collectors.toList());
        Map<String, Integer> getjbzsra = getjbzs(rd);
        Integer rdjb = getjbzsra.get("jb");
        Integer rdzs = getjbzsra.get("zs");
        Integer rdzb = getjbzsra.get("zb");
        Integer rdcxcjjt = getjbzsra.get("cxcjjt");
        map.put("rdjb",rdjb);
        map.put("rdzs",rdzs);
        map.put("rdzb",rdzb);
        map.put("rdcxcjjt",rdcxcjjt);
        map.put("rd",rd.size());
        return map;
    }

    private Map<String,Integer> getjbzs(List<MatterDto> collect) {
        Map<String,Integer> map= new HashMap<>();
        Integer jb=0;
        Integer zs=0;
        Integer zb=0;
        Integer cxcjjt=0;
        for (MatterDto matterDto : collect) {
            String handleModelID = matterDto.getHandleModelID();
            if (StringUtils.isNotEmpty(handleModelID)){
                //交办
                if (handleModelID.equals("001003001")||handleModelID.equals("002003001")||handleModelID.equals("003003001")||handleModelID.equals("004003001")||handleModelID.equals("005003001")){
                    jb=jb+1;
               //转送
                }else if (handleModelID.equals("001003002")||handleModelID.equals("002003002")||handleModelID.equals("003003002")||handleModelID.equals("004003002")||handleModelID.equals("005003002") || handleModelID.equals("001003002")){
                    zs=zs+1;
                }else if (handleModelID.equals("001006")||handleModelID.equals("002006")||handleModelID.equals("003006")||handleModelID.equals("004006")){
                    zb=zb+1;
                }else if ("002004".equals(handleModelID)|| "001004".equals(handleModelID) || "001005".equals(handleModelID)|| "003005".equals(handleModelID)){
                    cxcjjt=cxcjjt+1;
                }
            }
        }
        map.put("jb",jb);
        map.put("zs",zs);
        map.put("zb",zb);
        map.put("cxcjjt",cxcjjt);
        return map;
    }

    //同比
    public String  getPercent(int x, int total){
        if(total == 0 && x == 0 ){
            return "0.00%";
        }else if(total == 0) {
            return "100.00%";
        }
        double f = (Double.valueOf(x) - Double.valueOf(total)) / Double.valueOf(total) * 100;
        //double f = x*100/ total;

        BigDecimal bg = new BigDecimal(f);

        double f1 = bg.setScale(2, BigDecimal.ROUND_HALF_UP).doubleValue();

        return (f1+"%");
    }
    //添加依法处理统计
    private ActivityDto YFflzbDto(Integer curSum, Integer curTB, Integer orgYear, Integer orgYearTB ) {
        return new ActivityDto( curSum, getPercent(curSum, curTB) , orgYear, getPercent(orgYear, orgYearTB));
    }

    /**
     * 初重反映信访事项统计表(三级通用)
     * @param leadBehalf
     * @return
     * @throws ParseException
     */
    @Override
    public List<ActivityDto> exclCcXfTjList(LeadBehalf leadBehalf) throws ParseException {

        Date currTime = leadBehalf.getStartTime();
        Date lastTime = DateTimeUtils.getTodayTime(leadBehalf.getEndTime());
        // 同比开始时间与结束时间
        Date currTBTime = DateTimeUtils.getStartHBTime(leadBehalf.getStartTime());
        Date lastTBTime = DateTimeUtils.getEndHBTime(leadBehalf.getEndTime());
        //当年累计时间
        Date currYearTime = DateTimeUtils.getCurrYearFirst();
        Date lastYearTime = new Date();

        // //当年累计时间 同比开始时间与结束时间
        Date currYearTBTime = DateTimeUtils.getStartHBTime(currYearTime);
        Date lastYearTBTime = DateTimeUtils.getEndHBTime(lastYearTime);
        //选择统计时间
        leadBehalf.setStartTime(currTime);
        leadBehalf.setEndTime(lastTime);
        //信访事项  总量
        List<LeadBehalf> list = behalfMapper.FirstMore(leadBehalf);
        int Xfsum = list.size();
        Map<String, Object> xfSxSum = getXfSxSum(list);
        Integer  sx =(Integer)xfSxSum.get("newList");
        List<LeadBehalf>  ccSum =(List<LeadBehalf>)xfSxSum.get("ccSum");
        List<LeadBehalf>  cfSum =(List<LeadBehalf>)xfSxSum.get("cfSum");
        //初次反映
        Map<String, List<LeadBehalf>> ccXfTjcc = getCcXfTj(ccSum);
        List<LeadBehalf> lxcc = ccXfTjcc.get("lx");
        List<LeadBehalf> lfcc = ccXfTjcc.get("lf");
        List<LeadBehalf> wscc = ccXfTjcc.get("ws");
        List<LeadBehalf> ldcc = ccXfTjcc.get("ld");
        //重复反映
        Map<String, List<LeadBehalf>> cfXfTjcf = getCcXfTj(cfSum);
        List<LeadBehalf> lxcf = cfXfTjcf.get("lx");
        List<LeadBehalf> lfcf = cfXfTjcf.get("lf");
        List<LeadBehalf> wscf = cfXfTjcf.get("ws");
        List<LeadBehalf> ldcf = cfXfTjcf.get("ld");

        //涉及纯案数
        Integer CalxSum = getCcCfSum(lxcc, lxcf);
        Integer CalfSum = getCcCfSum(lfcc, lfcf);
        Integer CawsSum = getCcCfSum(wscc, wscf);
        Integer CaldSum = getCcCfSum(ldcc, ldcf);

         //选择时间同比数据
        leadBehalf.setStartTime(currTBTime);
        leadBehalf.setEndTime(lastTBTime);
        //信访事项  总量
        List<LeadBehalf> listTB = behalfMapper.FirstMore(leadBehalf);
        Map<String, Object> xfSxSumTB = getXfSxSum(listTB);
        Integer  sxTB =(Integer)xfSxSumTB.get("newList");
        List<LeadBehalf>  ccSumTB =(List<LeadBehalf>)xfSxSumTB.get("ccSum");
        List<LeadBehalf>  cfSumTB =(List<LeadBehalf>)xfSxSumTB.get("cfSum");
        //初次反映
        Map<String, List<LeadBehalf>> ccXfTjTBcc = getCcXfTj(ccSumTB);
        List<LeadBehalf> lxccTB = ccXfTjTBcc.get("lx");
        List<LeadBehalf> lfccTB = ccXfTjTBcc.get("lf");
        List<LeadBehalf> wsccTB = ccXfTjTBcc.get("ws");
        List<LeadBehalf> ldccTB = ccXfTjTBcc.get("ld");
        //重复反映
        Map<String, List<LeadBehalf>> cfXfTjTBcf = getCcXfTj(cfSumTB);
        List<LeadBehalf> lxcfTB = cfXfTjTBcf.get("lx");
        List<LeadBehalf> lfcfTB = cfXfTjTBcf.get("lf");
        List<LeadBehalf> wscfTB = cfXfTjTBcf.get("ws");
        List<LeadBehalf> ldcfTB = cfXfTjTBcf.get("ld");

        //涉及纯案数
        Integer CalxSumTB = getCcCfSum(lxccTB, lxcfTB);
        Integer CalfSumTB = getCcCfSum(lfccTB, lfcfTB);
        Integer CawsSumTB = getCcCfSum(wsccTB, wscfTB);
        Integer CaldSumTB = getCcCfSum(ldccTB, ldcfTB);


         //当年数据
        leadBehalf.setStartTime(currYearTime);
        leadBehalf.setEndTime(lastYearTime);
        //信访事项  总量
        List<LeadBehalf> listDN = behalfMapper.FirstMore(leadBehalf);
        int XfsumDN = listDN.size();
        Map<String, Object> xfSxSumDN = getXfSxSum(listDN);
        Integer  sxDN =(Integer)xfSxSumDN.get("newList");
        List<LeadBehalf>  ccSumDN =(List<LeadBehalf>)xfSxSumDN.get("ccSum");
        List<LeadBehalf>  cfSumDN =(List<LeadBehalf>)xfSxSumDN.get("cfSum");
        //初次反映
        Map<String, List<LeadBehalf>> ccXfTjDN = getCcXfTj(ccSumDN);
        List<LeadBehalf> lxccDN = ccXfTjDN.get("lx");
        List<LeadBehalf> lfccDN = ccXfTjDN.get("lf");
        List<LeadBehalf> wsccDN = ccXfTjDN.get("ws");
        List<LeadBehalf> ldccDN = ccXfTjDN.get("ld");
        //重复反映
        Map<String, List<LeadBehalf>> cfXfTjDN = getCcXfTj(cfSumDN);
        List<LeadBehalf> lxcfDN = cfXfTjDN.get("lx");
        List<LeadBehalf> lfcfDN = cfXfTjDN.get("lf");
        List<LeadBehalf> wscfDN = cfXfTjDN.get("ws");
        List<LeadBehalf> ldcfDN = cfXfTjDN.get("ld");

        //涉及纯案数
        Integer CalxSumDN = getCcCfSum(lxccDN, lxcfDN);
        Integer CalfSumDN = getCcCfSum(lfccDN, lfcfDN);
        Integer CawsSumDN = getCcCfSum(wsccDN, wscfDN);
        Integer CaldSumDN = getCcCfSum(ldccDN, ldcfDN);

        //当年数据 同比
        leadBehalf.setStartTime(currYearTBTime);
        leadBehalf.setEndTime(lastYearTBTime);
        //信访事项  总量
        List<LeadBehalf> listDNTB = behalfMapper.FirstMore(leadBehalf);
        Map<String, Object> xfSxSumDNTB = getXfSxSum(listDNTB);
        Integer  sxDNTB =(Integer)xfSxSumDNTB.get("newList");
        List<LeadBehalf>  ccSumDNTB =(List<LeadBehalf>)xfSxSumDNTB.get("ccSum");
        List<LeadBehalf>  cfSumDNTB =(List<LeadBehalf>)xfSxSumDNTB.get("cfSum");
        //初次反映
        Map<String, List<LeadBehalf>> ccXfTjDNTB = getCcXfTj(ccSumDNTB);
        List<LeadBehalf> lxccDNTB = ccXfTjDNTB.get("lx");
        List<LeadBehalf> lfccDNTB = ccXfTjDNTB.get("lf");
        List<LeadBehalf> wsccDNTB = ccXfTjDNTB.get("ws");
        List<LeadBehalf> ldccDNTB = ccXfTjDNTB.get("ld");
        //重复反映
        Map<String, List<LeadBehalf>> cfXfTjDNTB = getCcXfTj(cfSumDNTB);
        List<LeadBehalf> lxcfDNTB = cfXfTjDNTB.get("lx");
        List<LeadBehalf> lfcfDNTB = cfXfTjDNTB.get("lf");
        List<LeadBehalf> wscfDNTB = cfXfTjDNTB.get("ws");
        List<LeadBehalf> ldcfDNTB = cfXfTjDNTB.get("ld");
        Integer CalxSumDNTB = getCcCfSum(lxccDNTB, lxcfDNTB);
        Integer CalfSumDNTB = getCcCfSum(lfccDNTB, lfcfDNTB);
        Integer CawsSumDNTB = getCcCfSum(wsccDNTB, wscfDNTB);
        Integer CaldSumDNTB = getCcCfSum(ldccDNTB, ldcfDNTB);
        List<ActivityDto> listJg =new ArrayList<>();
        //信访总量
        listJg.add(CcXfbDto(sx,sxTB,sx,sxDN,sxTB,sxDN));
        //信访事项
        listJg.add(CcXfbDto(Xfsum,listTB.size(),Xfsum,XfsumDN,listDNTB.size(),XfsumDN));
        //初次反映
        listJg.add(CcXfbDto(ccSum.size(),ccSumTB.size(),Xfsum,ccSumDN.size(),ccSumDN.size(),XfsumDN));
        //重复反映
        listJg.add(CcXfbDto(cfSum.size(),cfSumTB.size(),Xfsum,cfSumDN.size(),cfSumDN.size(),XfsumDN));
        //纯案数
        listJg.add(CcXfbDto(CalxSum+CalfSum+CawsSum+CaldSum,CalxSumTB+CalfSumTB+CawsSumTB+CaldSumTB,Xfsum,CalxSumDN+CalfSumDN+CawsSumDN+CaldSumDN,CalxSumDNTB+CalfSumDNTB+CawsSumDNTB+CaldSumDNTB,XfsumDN));
        //来信初次反映
        listJg.add(CcXfbDto(lxcc.size(),lxccTB.size(),Xfsum,lxccDN.size(),lxccDNTB.size(),XfsumDN));
        //来信重复反映
        listJg.add(CcXfbDto(lxcf.size(),lxcfTB.size(),Xfsum,lxcfDN.size(),lxcfDNTB.size(),XfsumDN));
        //来信涉及纯案数
        listJg.add(CcXfbDto(CalxSum,CalxSumTB,Xfsum,CalxSumDN,CalxSumDNTB,XfsumDN));
        //来访初次反映
        listJg.add(CcXfbDto(lfcc.size(),lfccTB.size(),Xfsum,lfccDN.size(),lfccDNTB.size(),XfsumDN));
        //来访重复反映
        listJg.add(CcXfbDto(lfcf.size(),lfcfTB.size(),Xfsum,lfcfDN.size(),lfcfDNTB.size(),XfsumDN));
        //来访涉及纯案数
        listJg.add(CcXfbDto(CalfSum,CalfSumTB,Xfsum,CalfSumDN,CalfSumDNTB,XfsumDN));
        //网上初次反映
        listJg.add(CcXfbDto(wscc.size(),wsccTB.size(),Xfsum,wsccDN.size(),wsccDNTB.size(),XfsumDN));
        //网上重复反映
        listJg.add(CcXfbDto(wscf.size(),wscfTB.size(),Xfsum,wscfDN.size(),wscfDNTB.size(),XfsumDN));
        //网上反映涉及纯案数
        listJg.add(CcXfbDto(CawsSum,CawsSumTB,Xfsum,CawsSumDN,CawsSumDNTB,XfsumDN));
        //来电初次反映
        listJg.add(CcXfbDto(ldcc.size(),ldccTB.size(),Xfsum,ldccDN.size(),ldccDNTB.size(),XfsumDN));
        //来电重复反映
        listJg.add(CcXfbDto(ldcf.size(),ldcfTB.size(),Xfsum,ldcfDN.size(),ldcfDNTB.size(),XfsumDN));
        //来电反映涉及纯案数
        listJg.add(CcXfbDto(CaldSum,CaldSumTB,Xfsum,CaldSumDN,CaldSumDNTB,XfsumDN));


        return listJg;
    }
    //统计信访事项  初次反映  重复反映 涉及纯案数
    private Map<String,Object> getXfSxSum(List<LeadBehalf> behalves) {
        Map<String,Object> map = new HashMap<>();
        List<LeadBehalf> newList = behalves.stream().collect(
                Collectors.collectingAndThen(
                        Collectors.toCollection(() -> new TreeSet<>(Comparator.comparing(LeadBehalf::getActivityID))), ArrayList::new)
        );
        List<LeadBehalf> ccSum = behalves.stream().filter((n) -> "100".equals(n.getVisitID())).collect(Collectors.toList());
        List<LeadBehalf> cfSum = behalves.stream().filter((n) -> "200".equals(n.getVisitID())).collect(Collectors.toList());
        map.put("newList",newList.size());
        map.put("ccSum",ccSum);
        map.put("cfSum",cfSum);
        return map;
    }

    //统计  来访  001  来信 002   来电  003   网上信访 004
    private Map<String,List<LeadBehalf>>  getCcXfTj(List<LeadBehalf> ccSum) {
        Map<String,List<LeadBehalf>> map = new HashMap<>();
        List<LeadBehalf> lf = new ArrayList<>();
        List<LeadBehalf> lx = new ArrayList<>();
        List<LeadBehalf> ld = new ArrayList<>();
        List<LeadBehalf> ws = new ArrayList<>();
        //来访  001  来信 002   来电  003   网上信访 004
        for (LeadBehalf behalf : ccSum) {
            if (("001").equals(behalf.getRegisterTypeID())){
                lf.add(behalf);
            }else if(("002").equals(behalf.getRegisterTypeID())){
                lx.add(behalf);
            }else if (("003").equals(behalf.getRegisterTypeID())){
                ld.add(behalf);
            }else if (("004").equals(behalf.getRegisterTypeID())){
                ws.add(behalf);
            }
        }
        map.put("lf",lf);
        map.put("lx",lx);
        map.put("ld",ld);
        map.put("ws",ws);
        return map;
    }
    //初次反映和重复反映总计  计算纯案数
    private Integer  getCcCfSum(List<LeadBehalf> lxcc,List<LeadBehalf> lfcc) {
        for (LeadBehalf behalf : lxcc) {
            lfcc.add(behalf);
        }
        Integer integer = getchuanSum(lfcc);
        return integer;
    }
    //添加依法处理统计
    private ActivityDto CcXfbDto(Integer curSum, Integer curTB,Integer curZB, Integer orgYear, Integer orgYearTB,Integer orgYearZB ) {
        return new ActivityDto( curSum, getPercent(curSum, curTB) ,getZb(curSum,curZB), orgYear, getPercent(orgYear, orgYearTB),getZb(orgYear,orgYearZB));
    }
    //计算纯案数
    private Integer getchuanSum(List<LeadBehalf> behalves) {
        Integer newNum=0;
        int Num=0;
        for (LeadBehalf behalf : behalves) {
            List<MatterRelation> matterRelations = relationMapper.RelationList(behalf.getId());
            //过滤重复的
            if (StringUtils.isNotEmpty(matterRelations)) {
                List<String> myList = new ArrayList<>();
                Num= Num+1;
                List<String> newRelation = new ArrayList<>();
                for (MatterRelation relation : matterRelations) {
                    newRelation.add(relation.getMatterA());
                    newRelation.add(relation.getMatterB());
                }
                myList = newRelation.stream().distinct().collect(Collectors.toList());
                if (String.valueOf(Num).equals("1")){
                    newNum  =behalves.size()-myList.size()+ 1;
                }else {
                    newNum  =newNum-myList.size()+ 1;
                }
            }else {
                if ("0".equals(String.valueOf(Num))){
                    newNum  =behalves.size();
                }else {
                    newNum  =newNum+0;
                }
            }
        }
        return newNum;
    }
    //获取占比
    public String getZb(int x , int total){
        if(total == 0){
            return "100.00%";
        }
        double f = (Double.valueOf(x) / Double.valueOf(total)) * 100;
        BigDecimal bg = new BigDecimal(f);
        double f1 = bg.setScale(2, BigDecimal.ROUND_HALF_UP).doubleValue();
        return (f1+"%");
    }

    /**
     * 信访事项所属系统统计表（三级通用）
     * @param affiliationMatter
     * @return
     * @throws ParseException
     */
    @Override
    public List<ActivityDto1> exclXfSsxtList(AffiliationMatter affiliationMatter) throws ParseException {
        //选择时间
        Date currTime = affiliationMatter.getStartTime();
        Date lastTime = DateTimeUtils.getTodayTime(affiliationMatter.getEndTime());
        // 同比开始时间与结束时间
        Date currTBTime = DateTimeUtils.getStartHBTime(affiliationMatter.getStartTime());
        Date lastTBTime = DateTimeUtils.getEndHBTime(affiliationMatter.getEndTime());
        //选择时间的数据
        affiliationMatter.setStartTime(currTime);
        affiliationMatter.setEndTime(lastTime);
        List<ActivityDto1> activityDto1s = exportMapper.exclXfSsxtList(affiliationMatter);
        //选择时间的数据同比数据
        affiliationMatter.setStartTime(currTBTime);
        affiliationMatter.setEndTime(lastTBTime);
        List<ActivityDto1> activityDto1sTB = exportMapper.exclXfSsxtList(affiliationMatter);
        Map<String, List<ActivityDto1>> ggxitong = getGgxitong(activityDto1s);
        Map<String, List<ActivityDto1>> ggxitongTB = getGgxitong(activityDto1sTB);
        List<ActivityDto1> newList =new ArrayList<>();

        //判断查询的数据不为空
        if (StringUtils.isNotEmpty( ggxitong.get("renda"))){
            newList.add(getNewTj("人大", ggxitong.get("renda"), ggxitongTB.get("renda")));
        }
        if (StringUtils.isNotEmpty( ggxitong.get("zuzhi"))){
            newList.add(getNewTj("组织", ggxitong.get("zuzhi"), ggxitongTB.get("zuzhi")));
        }
        if (StringUtils.isNotEmpty( ggxitong.get("zhengxie"))){
            newList.add(getNewTj("政协", ggxitong.get("zhengxie"), ggxitongTB.get("zhengxie")));
        }
        if (StringUtils.isNotEmpty( ggxitong.get("xuanchuan"))){
            newList.add(getNewTj("宣传", ggxitong.get("xuanchuan"), ggxitongTB.get("xuanchuan")));
        }
        if (StringUtils.isNotEmpty( ggxitong.get("tongzhan"))){
            newList.add(getNewTj("统战", ggxitong.get("tongzhan"), ggxitongTB.get("tongzhan")));
        }
        if (StringUtils.isNotEmpty( ggxitong.get("jigoubianzhi"))){
            newList.add(getNewTj("机构编制", ggxitong.get("jigoubianzhi"), ggxitongTB.get("jigoubianzhi")));
        }
        if (StringUtils.isNotEmpty( ggxitong.get("guofang"))){
            newList.add(getNewTj("国防", ggxitong.get("guofang"), ggxitongTB.get("guofang")));
        }
        if (StringUtils.isNotEmpty( ggxitong.get("guojiaanquan"))){
            newList.add(getNewTj("国家安全", ggxitong.get("guojiaanquan"), ggxitongTB.get("guojiaanquan")));
        }
        if (StringUtils.isNotEmpty( ggxitong.get("taiwanshiwu"))){
            newList.add(getNewTj("台湾事务", ggxitong.get("taiwanshiwu"), ggxitongTB.get("taiwanshiwu")));
        }
        if (StringUtils.isNotEmpty( ggxitong.get("zhengfuban"))){
            newList.add(getNewTj("政府办", ggxitong.get("zhengfuban"), ggxitongTB.get("zhengfuban")));
        }
        if (StringUtils.isNotEmpty( ggxitong.get("fazhangaige"))){
            newList.add(getNewTj("发展和改革", ggxitong.get("发展和改革"), ggxitongTB.get("发展和改革")));
        }
        if (StringUtils.isNotEmpty( ggxitong.get("liangshi"))){
            newList.add(getNewTj("粮食", ggxitong.get("liangshi"), ggxitongTB.get("liangshi")));
        }
        if (StringUtils.isNotEmpty( ggxitong.get("wuzichubei"))){
            newList.add(getNewTj("物资储备", ggxitong.get("wuzichubei"), ggxitongTB.get("wuzichubei")));
        }
        if (StringUtils.isNotEmpty( ggxitong.get("nengyuan"))){
            newList.add(getNewTj("能源", ggxitong.get("nengyuan"), ggxitongTB.get("nengyuan")));
        }
        if (StringUtils.isNotEmpty( ggxitong.get("jiaoyu"))){
            newList.add(getNewTj("教育", ggxitong.get("jiaoyu"), ggxitongTB.get("jiaoyu")));
        }
        if (StringUtils.isNotEmpty( ggxitong.get("keji"))){
            newList.add(getNewTj("科技", ggxitong.get("keji"), ggxitongTB.get("keji")));
        }
        if (StringUtils.isNotEmpty( ggxitong.get("jingjixinxi"))){
            newList.add(getNewTj("经济和信息化", ggxitong.get("jingjixinxi"), ggxitongTB.get("jingjixinxi")));
        }
        if (StringUtils.isNotEmpty( ggxitong.get("minzucongjiao"))){
            newList.add(getNewTj("民族宗教", ggxitong.get("minzucongjiao"), ggxitongTB.get("minzucongjiao")));
        }
        if (StringUtils.isNotEmpty( ggxitong.get("gongan"))){
            newList.add(getNewTj("公安", ggxitong.get("gongan"), ggxitongTB.get("gongan")));
        }
        if (StringUtils.isNotEmpty( ggxitong.get("minzheng"))){
            newList.add(getNewTj("民政", ggxitong.get("minzheng"), ggxitongTB.get("minzheng")));
        }
        if (StringUtils.isNotEmpty( ggxitong.get("sifa"))){
            newList.add(getNewTj("司法", ggxitong.get("sifa"), ggxitongTB.get("sifa")));
        }
        if (StringUtils.isNotEmpty( ggxitong.get("caizheng"))){
            newList.add(getNewTj("财政", ggxitong.get("caizheng"), ggxitongTB.get("caizheng")));
        }
        if (StringUtils.isNotEmpty( ggxitong.get("renlishehui"))){
            newList.add(getNewTj("人力资源和社会保障", ggxitong.get("renlishehui"), ggxitongTB.get("renlishehui")));
        }
        if (StringUtils.isNotEmpty( ggxitong.get("ziranziyuan"))){
            newList.add(getNewTj("自然资源", ggxitong.get("ziranziyuan"), ggxitongTB.get("ziranziyuan")));
        }
        if (StringUtils.isNotEmpty( ggxitong.get("shengtaihuanjin"))){
            newList.add(getNewTj("生态坏境", ggxitong.get("shengtaihuanjin"), ggxitongTB.get("shengtaihuanjin")));
        }
        if (StringUtils.isNotEmpty( ggxitong.get("zhufangchengxiang"))){
            newList.add(getNewTj("住房和城乡建设", ggxitong.get("zhufangchengxiang"), ggxitongTB.get("zhufangchengxiang")));
        }
        if (StringUtils.isNotEmpty( ggxitong.get("jiaotongyunshu"))){
            newList.add(getNewTj("交通运输", ggxitong.get("jiaotongyunshu"), ggxitongTB.get("jiaotongyunshu")));
        }
        if (StringUtils.isNotEmpty( ggxitong.get("nongyenongcun"))){
            newList.add(getNewTj("农业农村", ggxitong.get("nongyenongcun"), ggxitongTB.get("nongyenongcun")));
        }
        if (StringUtils.isNotEmpty( ggxitong.get("shuili"))){
            newList.add(getNewTj("水利", ggxitong.get("shuili"), ggxitongTB.get("shuili")));
        }
        if (StringUtils.isNotEmpty( ggxitong.get("shangwu"))){
            newList.add(getNewTj("商务", ggxitong.get("shangwu"), ggxitongTB.get("shangwu")));
        }
        if (StringUtils.isNotEmpty( ggxitong.get("wenhua"))){
            newList.add(getNewTj("文化", ggxitong.get("wenhua"), ggxitongTB.get("wenhua")));
        }
        if (StringUtils.isNotEmpty( ggxitong.get("lvyou"))){
            newList.add(getNewTj("旅游", ggxitong.get("lvyou"), ggxitongTB.get("lvyou")));
        }
        if (StringUtils.isNotEmpty( ggxitong.get("weishenjiankang"))){
            newList.add(getNewTj("卫生健康", ggxitong.get("weishenjiankang"), ggxitongTB.get("weishenjiankang")));
        }
        if (StringUtils.isNotEmpty( ggxitong.get("tuiyijunren"))){
            newList.add(getNewTj("退役军人事务", ggxitong.get("tuiyijunren"), ggxitongTB.get("tuiyijunren")));
        }
        if (StringUtils.isNotEmpty( ggxitong.get("yingjiguanli"))){
            newList.add(getNewTj("应急管理", ggxitong.get("yingjiguanli"), ggxitongTB.get("yingjiguanli")));
        }
        if (StringUtils.isNotEmpty( ggxitong.get("shengji"))){
            newList.add(getNewTj("审计", ggxitong.get("shengji"), ggxitongTB.get("shengji")));
        }
        if (StringUtils.isNotEmpty( ggxitong.get("gangaoshiwu"))){
            newList.add(getNewTj("港澳事务", ggxitong.get("gangaoshiwu"), ggxitongTB.get("gangaoshiwu")));
        }
        if (StringUtils.isNotEmpty( ggxitong.get("waishi"))){
            newList.add(getNewTj("外事", ggxitong.get("waishi"), ggxitongTB.get("waishi")));
        }
        if (StringUtils.isNotEmpty( ggxitong.get("guoyouzican"))){
            newList.add(getNewTj("国有资产监管", ggxitong.get("guoyouzican"), ggxitongTB.get("guoyouzican")));
        }
        if (StringUtils.isNotEmpty( ggxitong.get("shichangjianguan"))){
            newList.add(getNewTj("市场监管", ggxitong.get("shichangjianguan"), ggxitongTB.get("shichangjianguan")));
        }
        if (StringUtils.isNotEmpty( ggxitong.get("guangbodianshi"))){
            newList.add(getNewTj("广播电视", ggxitong.get("guangbodianshi"), ggxitongTB.get("guangbodianshi")));
        }
        if (StringUtils.isNotEmpty( ggxitong.get("tiyu"))){
            newList.add(getNewTj("体育", ggxitong.get("tiyu"), ggxitongTB.get("tiyu")));
        }
        if (StringUtils.isNotEmpty( ggxitong.get("tongji"))){
            newList.add(getNewTj("统计", ggxitong.get("tongji"), ggxitongTB.get("tongji")));
        }
        if (StringUtils.isNotEmpty( ggxitong.get("linye"))){
            newList.add(getNewTj("林业", ggxitong.get("linye"), ggxitongTB.get("linye")));
        }
        if (StringUtils.isNotEmpty( ggxitong.get("yiliaobaozhang"))){
            newList.add(getNewTj("医疗保障", ggxitong.get("yiliaobaozhang"), ggxitongTB.get("yiliaobaozhang")));
        }
        if (StringUtils.isNotEmpty( ggxitong.get("jiguanshiwu"))){
            newList.add(getNewTj("机关事务", ggxitong.get("jiguanshiwu"), ggxitongTB.get("jiguanshiwu")));
        }
        if (StringUtils.isNotEmpty( ggxitong.get("jinrongjiandu"))){
            newList.add(getNewTj("金融监督", ggxitong.get("jinrongjiandu"), ggxitongTB.get("jinrongjiandu")));
        }
        if (StringUtils.isNotEmpty( ggxitong.get("renfang"))){
            newList.add(getNewTj("人防", ggxitong.get("renfang"), ggxitongTB.get("renfang")));
        }
        if (StringUtils.isNotEmpty( ggxitong.get("xinfang"))){
            newList.add(getNewTj("信访", ggxitong.get("xinfang"), ggxitongTB.get("xinfang")));
        }
        if (StringUtils.isNotEmpty( ggxitong.get("fupinkaifa"))){
            newList.add(getNewTj("扶贫开发", ggxitong.get("fupinkaifa"), ggxitongTB.get("fupinkaifa")));
        }
        if (StringUtils.isNotEmpty( ggxitong.get("shujuziyuanguanli"))){
            newList.add(getNewTj("数据资源管理", ggxitong.get("shujuziyuanguanli"), ggxitongTB.get("shujuziyuanguanli")));
        }
        if (StringUtils.isNotEmpty( ggxitong.get("dikuangkancha"))){
            newList.add(getNewTj("地矿勘查", ggxitong.get("dikuangkancha"), ggxitongTB.get("dikuangkancha")));
        }
        if (StringUtils.isNotEmpty( ggxitong.get("jianchawei"))){
            newList.add(getNewTj("监察委", ggxitong.get("jianchawei"), ggxitongTB.get("jianchawei")));
        }
        if (StringUtils.isNotEmpty( ggxitong.get("fayuan"))){
            newList.add(getNewTj("法院", ggxitong.get("fayuan"), ggxitongTB.get("fayuan")));
        }
        if (StringUtils.isNotEmpty( ggxitong.get("jianchayuan"))){
            newList.add(getNewTj("检察院", ggxitong.get("jianchayuan"), ggxitongTB.get("jianchayuan")));
        }
        if (StringUtils.isNotEmpty( ggxitong.get("gonghui"))){
            newList.add(getNewTj("工会", ggxitong.get("gonghui"), ggxitongTB.get("gonghui")));
        }
        if (StringUtils.isNotEmpty( ggxitong.get("funv"))){
            newList.add(getNewTj("妇女", ggxitong.get("funv"), ggxitongTB.get("funv")));
        }
        if (StringUtils.isNotEmpty( ggxitong.get("gongqingtuan"))){
            newList.add(getNewTj("共青团", ggxitong.get("gongqingtuan"), ggxitongTB.get("gongqingtuan")));
        }
        if (StringUtils.isNotEmpty( ggxitong.get("canlian"))){
            newList.add(getNewTj("残联", ggxitong.get("canlian"), ggxitongTB.get("canlian")));
        }
        if (StringUtils.isNotEmpty( ggxitong.get("yinhang"))){
            newList.add(getNewTj("银行", ggxitong.get("yinhang"), ggxitongTB.get("yinhang")));
        }
        if (StringUtils.isNotEmpty( ggxitong.get("zhengjuan"))){
            newList.add(getNewTj("证券", ggxitong.get("zhengjuan"), ggxitongTB.get("zhengjuan")));
        }
        if (StringUtils.isNotEmpty( ggxitong.get("baoxian"))){
            newList.add(getNewTj("保险", ggxitong.get("baoxian"), ggxitongTB.get("baoxian")));
        }
        if (StringUtils.isNotEmpty( ggxitong.get("yancao"))){
            newList.add(getNewTj("烟草", ggxitong.get("yancao"), ggxitongTB.get("yancao")));
        }
        if (StringUtils.isNotEmpty( ggxitong.get("youzheng"))){
            newList.add(getNewTj("邮政", ggxitong.get("youzheng"), ggxitongTB.get("youzheng")));
        }
        if (StringUtils.isNotEmpty( ggxitong.get("haiguan"))){
            newList.add(getNewTj("海关", ggxitong.get("haiguan"), ggxitongTB.get("haiguan")));
        }
        if (StringUtils.isNotEmpty( ggxitong.get("shuiwu"))){
            newList.add(getNewTj("税务", ggxitong.get("shuiwu"), ggxitongTB.get("shuiwu")));
        }
        if (StringUtils.isNotEmpty( ggxitong.get("tiedao"))){
            newList.add(getNewTj("铁道", ggxitong.get("tiedao"), ggxitongTB.get("tiedao")));
        }
        if (StringUtils.isNotEmpty( ggxitong.get("minhang"))){
            newList.add(getNewTj("民航", ggxitong.get("minhang"), ggxitongTB.get("minhang")));
        }
        if (StringUtils.isNotEmpty( ggxitong.get("dianxin"))){
            newList.add(getNewTj("电信", ggxitong.get("dianxin"), ggxitongTB.get("dianxin")));
        }
        if (StringUtils.isNotEmpty( ggxitong.get("qita"))){
            newList.add(getNewTj("其他", ggxitong.get("qita"), ggxitongTB.get("qita")));
        }
        return newList;
    }

    //单个系统的各个事项数据和同比
    private ActivityDto1 getNewTj(String name,List<ActivityDto1> renda, List<ActivityDto1> rendaTB) {
        ActivityDto1 dgXtTj = getDgXtTj(renda);
        ActivityDto1 dgXtTjTB = getDgXtTj(rendaTB);
        ActivityDto1 DtoXt = new ActivityDto1();
        DtoXt.setName(name);
        DtoXt.setXfNum(dgXtTj.getXfNum());
        DtoXt.setXfNumTB(getPercent(dgXtTj.getXfNum(),dgXtTjTB.getXfNum()));
        DtoXt.setCaNum(dgXtTj.getCaNum());
        DtoXt.setCaNumTB(getPercent(dgXtTj.getCaNum(),dgXtTjTB.getCaNum()));
        DtoXt.setLxNum(dgXtTj.getLxNum());
        DtoXt.setLxNumTB(getPercent(dgXtTj.getLxNum(),dgXtTjTB.getLxNum()));
        DtoXt.setLfPcNum(dgXtTj.getLfPcNum());
        DtoXt.setLfPcNumTB(getPercent(dgXtTj.getLfPcNum(),dgXtTjTB.getLfPcNum()));
        DtoXt.setLfRsNum(dgXtTj.getLfRsNum());
        DtoXt.setLfRsNumTB(getPercent(dgXtTj.getLfRsNum(),dgXtTjTB.getLfRsNum()));
        DtoXt.setWsNum(dgXtTj.getWsNum());
        DtoXt.setWsNumTB(getPercent(dgXtTj.getWsNum(),dgXtTjTB.getWsNum()));
        DtoXt.setLdNum(dgXtTj.getLdNum());
        DtoXt.setLdNumTB(getPercent(dgXtTj.getLdNum(),dgXtTjTB.getLdNum()));
        return DtoXt;
    }
    //各个所属系统的划分
    private Map<String,List<ActivityDto1>> getGgxitong(List<ActivityDto1> activityDto1s) {
        Map<String,List<ActivityDto1>> map =new HashMap<>();
        List<ActivityDto1> renda =new ArrayList<>();
        List<ActivityDto1> zuzhi =new ArrayList<>();
        List<ActivityDto1> zhengxie =new ArrayList<>();
        List<ActivityDto1> xuanchuan =new ArrayList<>();
        List<ActivityDto1> tongzhan =new ArrayList<>();
        List<ActivityDto1> jigoubianzhi =new ArrayList<>();
        List<ActivityDto1> guofang =new ArrayList<>();
        List<ActivityDto1> guojiaanquan =new ArrayList<>();
        List<ActivityDto1> taiwanshiwu =new ArrayList<>();
        List<ActivityDto1> zhengfuban =new ArrayList<>();
        List<ActivityDto1> fazhangaige =new ArrayList<>();
        List<ActivityDto1> liangshi =new ArrayList<>();
        List<ActivityDto1> wuzichubei =new ArrayList<>();
        List<ActivityDto1> nengyuan =new ArrayList<>();
        List<ActivityDto1> jiaoyu =new ArrayList<>();
        List<ActivityDto1> keji =new ArrayList<>();
        List<ActivityDto1> jingjixinxi =new ArrayList<>();
        List<ActivityDto1> minzucongjiao =new ArrayList<>();
        List<ActivityDto1> gongan =new ArrayList<>();
        List<ActivityDto1> minzheng =new ArrayList<>();
        List<ActivityDto1> sifa =new ArrayList<>();
        List<ActivityDto1> caizheng =new ArrayList<>();
        List<ActivityDto1> renlishehui =new ArrayList<>();
        List<ActivityDto1> ziranziyuan =new ArrayList<>();
        List<ActivityDto1> shengtaihuanjin =new ArrayList<>();
        List<ActivityDto1> zhufangchengxiang =new ArrayList<>();
        List<ActivityDto1> jiaotongyunshu =new ArrayList<>();
        List<ActivityDto1> nongyenongcun =new ArrayList<>();
        List<ActivityDto1> shuili =new ArrayList<>();
        List<ActivityDto1> shangwu =new ArrayList<>();
        List<ActivityDto1> wenhua =new ArrayList<>();
        List<ActivityDto1> lvyou =new ArrayList<>();
        List<ActivityDto1> weishenjiankang =new ArrayList<>();
        List<ActivityDto1> tuiyijunren =new ArrayList<>();
        List<ActivityDto1> yingjiguanli =new ArrayList<>();
        List<ActivityDto1> shengji =new ArrayList<>();
        List<ActivityDto1> gangaoshiwu =new ArrayList<>();
        List<ActivityDto1> waishi =new ArrayList<>();
        List<ActivityDto1> guoyouzican =new ArrayList<>();
        List<ActivityDto1> shichangjianguan =new ArrayList<>();
        List<ActivityDto1> guangbodianshi =new ArrayList<>();
        List<ActivityDto1> tiyu =new ArrayList<>();
        List<ActivityDto1> tongji =new ArrayList<>();
        List<ActivityDto1> linye =new ArrayList<>();
        List<ActivityDto1> yiliaobaozhang =new ArrayList<>();
        List<ActivityDto1> jiguanshiwu =new ArrayList<>();
        List<ActivityDto1> jinrongjiandu =new ArrayList<>();
        List<ActivityDto1> renfang =new ArrayList<>();
        List<ActivityDto1> xinfang =new ArrayList<>();
        List<ActivityDto1> fupinkaifa =new ArrayList<>();
        List<ActivityDto1> shujuziyuanguanli =new ArrayList<>();
        List<ActivityDto1> dikuangkancha =new ArrayList<>();
        List<ActivityDto1> jianchawei =new ArrayList<>();
        List<ActivityDto1> fayuan =new ArrayList<>();
        List<ActivityDto1> jianchayuan =new ArrayList<>();
        List<ActivityDto1> gonghui =new ArrayList<>();
        List<ActivityDto1> funv =new ArrayList<>();
        List<ActivityDto1> gongqingtuan =new ArrayList<>();
        List<ActivityDto1> canlian =new ArrayList<>();
        List<ActivityDto1> yinhang =new ArrayList<>();
        List<ActivityDto1> zhengjuan =new ArrayList<>();
        List<ActivityDto1> baoxian =new ArrayList<>();
        List<ActivityDto1> yancao =new ArrayList<>();
        List<ActivityDto1> youzheng =new ArrayList<>();
        List<ActivityDto1> haiguan =new ArrayList<>();
        List<ActivityDto1> shuiwu =new ArrayList<>();
        List<ActivityDto1> tiedao =new ArrayList<>();
        List<ActivityDto1> minhang =new ArrayList<>();
        List<ActivityDto1> dianxin =new ArrayList<>();
        List<ActivityDto1> qita =new ArrayList<>();
        for (ActivityDto1 activityDto1 : activityDto1s) {
            //判断是所属系统是否为空
            String belongsID = activityDto1.getBelongsID();
            if (StringUtils.isNotEmpty(belongsID)){
                  String substring = belongsID.substring(0, 3);
                    if ("001".equals(substring)){   //人大
                        renda.add(activityDto1);
                    }else if ("006002".equals(belongsID)){ //组织
                        zuzhi.add(activityDto1);
                    }else if ("006006".equals(belongsID)){ //政协
                        zhengxie.add(activityDto1);
                    }else if ("006003".equals(belongsID)){ //宣传
                        xuanchuan.add(activityDto1);
                    }else if ("006005".equals(belongsID)){ //统战
                        tongzhan.add(activityDto1);
                    }else if ("006004".equals(belongsID)){ //机构编制
                        jigoubianzhi.add(activityDto1);
                    }else if ("006008".equals(belongsID)){ //国防
                        guofang.add(activityDto1);
                    }else if ("006009".equals(belongsID)){ //国家安全
                        guojiaanquan.add(activityDto1);
                    }else if ("006007".equals(belongsID)){ //台湾事务
                        taiwanshiwu.add(activityDto1);
                    } else if ("002001".equals(belongsID)) { //政府办
                        zhengfuban.add(activityDto1);
                    }else if ("002002".equals(belongsID)){ //发展和改革
                        fazhangaige.add(activityDto1);
                    } else if ("002003".equals(belongsID)) { //粮食
                        liangshi.add(activityDto1);
                    }else if ("002004".equals(belongsID)){ //物资储备
                        wuzichubei.add(activityDto1);
                    }else if ("002005".equals(belongsID)){ //能源
                        nengyuan.add(activityDto1);
                    }else if ("002006".equals(belongsID)){ //教育
                        jiaoyu.add(activityDto1);
                    }else if ("002007".equals(belongsID)){ //科技
                        keji.add(activityDto1);
                    }else if ("002008".equals(belongsID)){ //经济和信息化
                        jingjixinxi.add(activityDto1);
                    }else if ("002009".equals(belongsID)){ //民族宗教
                        minzucongjiao.add(activityDto1);
                    }else if ("007".equals(belongsID) || "008".equals(belongsID) || "002010".equals(belongsID) ){ //公安 002010 公安行政
                        gongan.add(activityDto1);
                    }else if ("002011".equals(belongsID)){ //民政
                        minzheng.add(activityDto1);
                    } else if ("002012".equals(belongsID) || "009".equals(belongsID)) { //司法
                        sifa.add(activityDto1);
                    }else if ("002013".equals(belongsID)){ //财政
                        caizheng.add(activityDto1);
                    } else if ("002014".equals(belongsID)) { //人力资源和社会保障
                        renlishehui.add(activityDto1);
                    }else if ("002015".equals(belongsID)){ //自然资源
                        ziranziyuan.add(activityDto1);
                    }else if ("002016".equals(belongsID)){ //生态坏境
                        shengtaihuanjin.add(activityDto1);
                    }else if ("002017".equals(belongsID)){ //住房和城乡建设
                        zhufangchengxiang.add(activityDto1);
                    }else if ("002018".equals(belongsID)){ //交通运输
                        jiaotongyunshu.add(activityDto1);
                    } else if ("002019".equals(belongsID)) { //农业农村
                        nongyenongcun.add(activityDto1);
                    }else if ("002020".equals(belongsID)){ //水利
                        shuili.add(activityDto1);
                    } else if ("002021".equals(belongsID)) { //商务
                        shangwu.add(activityDto1);
                    } else if ("002022".equals(belongsID) ) { //文化
                        wenhua.add(activityDto1);
                    }else if ("002023".equals(belongsID)){ //旅游
                        lvyou.add(activityDto1);
                    } else if ("002024".equals(belongsID)) { //卫生健康
                        weishenjiankang.add(activityDto1);
                    }else if ("002025".equals(belongsID)){ //退役军人事务
                        tuiyijunren.add(activityDto1);
                    }else if ("002026".equals(belongsID)){ //应急管理
                        yingjiguanli.add(activityDto1);
                    }else if ("002027".equals(belongsID)){ //审计
                        shengji.add(activityDto1);
                    }else if ("002028".equals(belongsID)){ //港澳事务
                        gangaoshiwu.add(activityDto1);
                    } else if ("002029".equals(belongsID)) { //外事
                        waishi.add(activityDto1);
                    }else if ("002030".equals(belongsID)){ //国有资产监管
                        guoyouzican.add(activityDto1);
                    } else if ("002031".equals(belongsID)) { //市场监管
                        shichangjianguan.add(activityDto1);
                    } else if ("002032".equals(belongsID)) { //广播电视
                        guangbodianshi.add(activityDto1);
                    }else if ("002033".equals(belongsID)){ //体育
                        tiyu.add(activityDto1);
                    }else if ("002034".equals(belongsID)){ //统计
                        tongji.add(activityDto1);
                    }else if ("002035".equals(belongsID)){ //林业
                        linye.add(activityDto1);
                    }else if ("002036".equals(belongsID)){ //医疗保障
                        yiliaobaozhang.add(activityDto1);
                    } else if ("002037".equals(belongsID)) { //机关事务
                        jiguanshiwu.add(activityDto1);
                    }else if ("002038".equals(belongsID)){ //金融监督
                        jinrongjiandu.add(activityDto1);
                    } else if ("002039".equals(belongsID)) { //人防
                        renfang.add(activityDto1);
                    } else if ("002040".equals(belongsID)) { //信访
                        xinfang.add(activityDto1);
                    } else if ("002041".equals(belongsID)) { //扶贫开发
                        fupinkaifa.add(activityDto1);
                    }else if ("002042".equals(belongsID)){ //数据资源管理
                        shujuziyuanguanli.add(activityDto1);
                    }else if ("002043".equals(belongsID)){ //地矿勘查
                        dikuangkancha.add(activityDto1);
                    }else if ("003".equals(belongsID)){ //监察委
                        jianchawei.add(activityDto1);
                    }else if ("004".equals(belongsID)){ //法院
                        fayuan.add(activityDto1);
                    } else if ("005".equals(belongsID)) { //检察院
                        jianchayuan.add(activityDto1);
                    }else if ("006010".equals(belongsID)){ //工会
                        gonghui.add(activityDto1);
                    } else if ("006011".equals(belongsID)) { //妇女
                        funv.add(activityDto1);    ///dad
                    } else if ("006012".equals(belongsID)) { //共青团
                        gongqingtuan.add(activityDto1);
                    } else if ("006013".equals(belongsID)) { //残联
                        canlian.add(activityDto1);
                    } else if ("006014".equals(belongsID)) { //银行
                        yinhang.add(activityDto1);
                    }else if ("006015".equals(belongsID)){ //证券
                        zhengjuan.add(activityDto1);
                    }else if ("006016".equals(belongsID)){ //保险
                        baoxian.add(activityDto1);
                    }else if ("006017".equals(belongsID)){ //烟草
                        yancao.add(activityDto1);
                    }else if ("006018".equals(belongsID)){ //邮政
                        youzheng.add(activityDto1);
                    } else if ("006019".equals(belongsID)) { //海关
                        haiguan.add(activityDto1);
                    }else if ("006020".equals(belongsID)){ //税务
                        shuiwu.add(activityDto1);
                    } else if ("006021".equals(belongsID)) { //铁道
                        tiedao.add(activityDto1);
                    }else if ("006022".equals(belongsID)){ //民航
                        minhang.add(activityDto1);
                    } else if ("006023".equals(belongsID)) { //电信
                        dianxin.add(activityDto1);
                    }else if ("002044".equals(belongsID) || "006024".equals(belongsID) || "006".equals(belongsID) ){ //其他 其他方面
                        qita.add(activityDto1);
                    }
            }else {
                qita.add(activityDto1);
            }
        }
        map.put("renda",renda);
        map.put("zuzhi",zuzhi);
        map.put("zhengxie",zhengxie);
        map.put("xuanchuan",xuanchuan);
        map.put("tongzhan",tongzhan);
        map.put("jigoubianzhi",jigoubianzhi);
        map.put("guofang",guofang);
        map.put("guojiaanquan",guojiaanquan);
        map.put("taiwanshiwu",taiwanshiwu);
        map.put("zhengfuban",zhengfuban);
        map.put("fazhangaige",fazhangaige);
        map.put("liangshi",liangshi);
        map.put("wuzichubei",wuzichubei);
        map.put("nengyuan",nengyuan);
        map.put("jiaoyu",jiaoyu);
        map.put("keji",keji);
        map.put("jingjixinxi",jingjixinxi);
        map.put("minzucongjiao",minzucongjiao);
        map.put("gongan",gongan);
        map.put("minzheng",minzheng);
        map.put("sifa",sifa);
        map.put("caizheng",caizheng);
        map.put("renlishehui",renlishehui);
        map.put("ziranziyuan",ziranziyuan);
        map.put("shengtaihuanjin",shengtaihuanjin);
        map.put("zhufangchengxiang",zhufangchengxiang);
        map.put("jiaotongyunshu",jiaotongyunshu);
        map.put("nongyenongcun",nongyenongcun);
        map.put("shuili",shuili);
        map.put("shangwu",shangwu);
        map.put("wenhua",wenhua);
        map.put("lvyou",lvyou);
        map.put("weishenjiankang",weishenjiankang);
        map.put("tuiyijunren",tuiyijunren);
        map.put("yingjiguanli",yingjiguanli);
        map.put("shengji",shengji);
        map.put("gangaoshiwu",gangaoshiwu);
        map.put("waishi",waishi);
        map.put("guoyouzican",guoyouzican);
        map.put("shichangjianguan",shichangjianguan);
        map.put("guangbodianshi",guangbodianshi);
        map.put("tiyu",tiyu);
        map.put("tongji",tongji);
        map.put("linye",linye);
        map.put("yiliaobaozhang",yiliaobaozhang);
        map.put("jiguanshiwu",jiguanshiwu);
        map.put("jinrongjiandu",jinrongjiandu);
        map.put("renfang",renfang);
        map.put("xinfang",xinfang);
        map.put("fupinkaifa",fupinkaifa);
        map.put("shujuziyuanguanli",shujuziyuanguanli);
        map.put("dikuangkancha",dikuangkancha);
        map.put("jianchawei",jianchawei);
        map.put("fayuan",fayuan);
        map.put("jianchayuan",jianchayuan);
        map.put("gonghui",gonghui);
        map.put("funv",funv);
        map.put("gongqingtuan",gongqingtuan);
        map.put("canlian",canlian);
        map.put("yinhang",yinhang);
        map.put("zhengjuan",zhengjuan);
        map.put("baoxian",baoxian);
        map.put("yancao",yancao);
        map.put("youzheng",youzheng);
        map.put("haiguan",haiguan);;
        map.put("shuiwu",shuiwu);
        map.put("tiedao",tiedao);
        map.put("minhang",minhang);
        map.put("dianxin",dianxin);
        map.put("qita",qita);
        return map;
    }

    //单个系统统计数量  信访事项  涉及纯案数  来信件次(事项)  来访批次(活动) 来访人次  晚上反映人次  来电反映人次
    private ActivityDto1 getDgXtTj(List<ActivityDto1> activityDto1s) {
        //信访数量
        int XfSum = activityDto1s.size();
        //纯案数
        Integer XfCa = getchuanSumXt(activityDto1s);
        //来信
        long Lxpx = activityDto1s.stream().filter((n) -> "002".equals(n.getRegisterTypeID())).count();
        //去重获取活动次数
        List<ActivityDto1> qcList = activityDto1s.stream().collect(
                Collectors.collectingAndThen(
                        Collectors.toCollection(() -> new TreeSet<>(Comparator.comparing(ActivityDto1::getId))), ArrayList::new)
        );
        List<Activity> laifang =new ArrayList<>();
        List<Activity> wangshang =new ArrayList<>();
        List<Activity> laidian =new ArrayList<>();
        for (ActivityDto1 activityDto1 : qcList) {
            if ("001".equals(activityDto1.getRegisterTypeID())){
                laifang.add(activityDto1);
            } else if ("004".equals(activityDto1.getRegisterTypeID())) {
                wangshang.add(activityDto1);
            }else if ("003".equals(activityDto1.getRegisterTypeID())){
                laidian.add(activityDto1);
            }
        }

        Integer lfperSum = getPerNum(laifang);
        Integer wsperSum = getPerNum(wangshang);
        Integer ldperSum = getPerNum(laidian);
        ActivityDto1 activityDto1 = new ActivityDto1();
        activityDto1.setXfNum(XfSum);
        activityDto1.setCaNum(XfCa);
        activityDto1.setLxNum((int)Lxpx);
        activityDto1.setLfPcNum(laifang.size());
        activityDto1.setLfRsNum(lfperSum);
        activityDto1.setWsNum(wsperSum);
        activityDto1.setLdNum(ldperSum);
        return activityDto1;
    }

    //计算人数
    private Integer getPerNum(List<Activity> Activitys) {
        Integer persum =0;
        for (Activity activity : Activitys) {
            persum=persum+activity.getXfNumber();
        }
        return persum;
    }

    //计算纯案数
    private Integer getchuanSumXt(List<ActivityDto1> activityDto1s) {
        Integer newNum=0;
        int Num=0;
        for (ActivityDto1 activityDto1 : activityDto1s) {
            List<MatterRelation> matterRelations = relationMapper.RelationList(activityDto1.getMid());
            //过滤重复的
            if (StringUtils.isNotEmpty(matterRelations)) {
                List<String> myList = new ArrayList<>();
                Num= Num+1;
                List<String> newRelation = new ArrayList<>();
                for (MatterRelation relation : matterRelations) {
                    newRelation.add(relation.getMatterA());
                    newRelation.add(relation.getMatterB());
                }
                myList = newRelation.stream().distinct().collect(Collectors.toList());
                if (String.valueOf(Num).equals("1")){
                    newNum  =activityDto1s.size()-myList.size()+ 1;
                }else {
                    newNum  =newNum-myList.size()+ 1;
                }
            }else {
                if ("0".equals(String.valueOf(Num))){
                    newNum  =activityDto1s.size();
                }else {
                    newNum  =newNum+0;
                }
            }
        }
        return newNum;
    }
    /**
     * 信访事项属地统计表（三级通用）
     * @param matterVO
     * @return
     * @throws ParseException
     */
    @Override
    public List<ActivityDto1> exclSdXfTj(AffiliationMatterVO matterVO) throws ParseException {
        //选择时间
        Date currTime = matterVO.getStartTime();
        Date lastTime = DateTimeUtils.getTodayTime(matterVO.getEndTime());
        // 同比开始时间与结束时间
        Date currTBTime = DateTimeUtils.getStartHBTime(matterVO.getStartTime());
        Date lastTBTime = DateTimeUtils.getEndHBTime(matterVO.getEndTime());
        matterVO.setStartTime(currTime);
        matterVO.setEndTime(lastTime);
        List<Dept> deptList = deptMapper.selectDeptByIdXzList(matterVO.getId());
        List<ActivityDto1> activityDto1List = exportMapper.exclXfSsSdList(matterVO);

        matterVO.setStartTime(currTBTime);
        matterVO.setEndTime(lastTBTime);
        List<Dept> deptListTB = deptMapper.selectDeptByIdXzList(matterVO.getId());
        List<ActivityDto1> activityDto1ListTB = exportMapper.exclXfSsSdList(matterVO);
        List<ActivityDto1> ggXzqh = getGgXzqh(deptList,activityDto1List);
        List<ActivityDto1> ggXzqhTB = getGgXzqh(deptListTB,activityDto1ListTB);

        List<ActivityDto1> JsList =new ArrayList<>();
        for (ActivityDto1 activityDto1 : ggXzqh) {
            String name = activityDto1.getName();
            for (ActivityDto1 dtoTB : ggXzqhTB) {
                if (name.equals(dtoTB.getName())){
                    JsList.add(getNewTjDg(name, activityDto1, dtoTB));
                }
            }
        }

        return JsList;
    }

    @Override
    public Dictionary selectDictonaryByDictValue(String dictID,String dictValue) {
        return dictionaryMapper.DictionaryOne(dictID, dictValue);
    }

    //各个行政地区的数据 各个系统的统计
    private List<ActivityDto1> getGgXzqh(List<Dept> deptList,List<ActivityDto1> activityDto1List) {
        Dept dept1 = new Dept();
        dept1.setDeptName(deptList.get(0).getOrgDeptName()+"直");
        //截取只剩最后一位  最后一位拼接 0
        String dictValue = deptList.get(0).getDictValue();
        String substring = dictValue.substring(0, dictValue.length() - 1);
        dept1.setDictValue(substring+"0");
        Dept dept2 = new Dept();
        dept2.setDeptName("行政区域外");
        deptList.add(dept1);
        deptList.add(dept2);
        Map<String,List<ActivityDto1>> map = new HashMap<>();
        for (int i = 1; i <=deptList.size() ; i++) {
            List<ActivityDto1> activityDto1s =new ArrayList<>();
            String activityDto="";
            String a=activityDto+String.valueOf(i);
            map.put(a,activityDto1s);
        }

          //行政区域划分
        for (ActivityDto1 activityDto1 : activityDto1List) {
            int num =0;
            for (Dept dept : deptList) {
                num=num+1;
                String activityDto="";
                if (activityDto1.getHappenRegionID().equals(dept.getDictValue())){
                    String a=activityDto+String.valueOf(num);
                    List<ActivityDto1> affiliationMatterVOS = map.get(a);
                    affiliationMatterVOS.add(activityDto1);
                    //跳出
                    break;
                }else if (String.valueOf(deptList.size()).equals(String.valueOf(num))){
                    String a=activityDto+String.valueOf(num);
                    List<ActivityDto1> affiliationMatterVOS = map.get(a);
                    affiliationMatterVOS.add(activityDto1);
                }
            }
        }
        //计算各个地区的数值统计
        List<ActivityDto1> newList =new ArrayList<>();
        String activityDto="";
        for (int i = 1; i <= map.size(); i++) {
            String a=activityDto+String.valueOf(i);
            List<ActivityDto1> affiliationMatterVOS = map.get(a);
            ActivityDto1 dgXtTj = getDgXtTj(affiliationMatterVOS);
            dgXtTj.setName(deptList.get(i-1).getDeptName());
            newList.add(dgXtTj);
        }
        return newList;
    }
    //单个系统的各个事项数据和同比
    private ActivityDto1 getNewTjDg(String name,ActivityDto1 renda, ActivityDto1 rendaTB) {

        ActivityDto1 DtoXt = new ActivityDto1();
        DtoXt.setName(name);
        DtoXt.setXfNum(renda.getXfNum());
        DtoXt.setXfNumTB(getPercent(renda.getXfNum(),rendaTB.getXfNum()));
        DtoXt.setCaNum(renda.getCaNum());
        DtoXt.setCaNumTB(getPercent(renda.getCaNum(),rendaTB.getCaNum()));
        DtoXt.setLxNum(renda.getLxNum());
        DtoXt.setLxNumTB(getPercent(renda.getLxNum(),rendaTB.getLxNum()));
        DtoXt.setLfPcNum(renda.getLfPcNum());
        DtoXt.setLfPcNumTB(getPercent(renda.getLfPcNum(),rendaTB.getLfPcNum()));
        DtoXt.setLfRsNum(renda.getLfRsNum());
        DtoXt.setLfRsNumTB(getPercent(renda.getLfRsNum(),rendaTB.getLfRsNum()));
        DtoXt.setWsNum(renda.getWsNum());
        DtoXt.setWsNumTB(getPercent(renda.getWsNum(),rendaTB.getWsNum()));
        DtoXt.setLdNum(renda.getLdNum());
        DtoXt.setLdNumTB(getPercent(renda.getLdNum(),rendaTB.getLdNum()));
        return DtoXt;
    }
}
