package com.dlsm.service.impl;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.dlsm.mapper.*;
import com.dlsm.model.*;
import com.dlsm.model.Dictionary;
import com.dlsm.model.Label;
import com.dlsm.model.dto.MatterDto;
import com.dlsm.model.export.ActivityDTO;
import com.dlsm.model.export.XfzbDTO;
import com.dlsm.model.vo.*;
import com.dlsm.service.DeptService;
import com.dlsm.service.MatterService;
import com.dlsm.utils.AhrdUitls;
import com.dlsm.utils.CalculateUtils;
import com.dlsm.utils.DateTimeUtils;
import com.dlsm.utils.StringUtils;
import lombok.AllArgsConstructor;
import org.apache.commons.collections.map.LinkedMap;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.awt.*;
import java.math.BigDecimal;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.*;
import java.util.List;
import java.util.stream.Collectors;
import java.util.stream.Stream;

/**
 * 信访事件管理Service业务层处理
 *
 * @author xunfeng
 * @date 2022-03-03
 */
@Service
public class MatterServiceImpl implements MatterService {

    @Autowired
    private MatterMapper matterMapper;

    @Autowired
    private DeptService deptService;

    @Autowired
    private ActivityMapper activityMapper;

    @Autowired
    private DictionaryMapper dictionaryMapper;


    @Autowired
    private MatterRelationMapper relationMapper;

    @Autowired
    private PersonMapper personMapper;




    // 根据来访原因ID查询子id
    @Override
    public List<String> selectLFReasonID(String identifying) {
        return matterMapper.selectLFReasonID(identifying);
    }

    // 查询信访事项
    @Override
    public List<Matter> selectMatterList(List<Activity> activityList) {
        return matterMapper.selectMatterList(activityList);
    }

    // 查询信访内容分类分析
    @Override
    public Map<String, Object> reactionContentClassify(String deptIdList, String userId, String sTime, String eTime,String identifying) throws ParseException {
        Map<String, Object> map = new HashMap<>();
        Dept dept = deptService.selectDeptByUserId(userId);
        // 当前登录用户的单位id
        String  deptId = "";
        if (deptIdList == null || deptIdList == "") {
            deptId = dept.getId().toString();
        }

        Date startTime = null;
        Date endTime = null;
        SimpleDateFormat  format = new SimpleDateFormat("yyyy-MM-dd");
        if (sTime != null && sTime != "") {
            startTime = format.parse(sTime);
            endTime = format.parse(eTime);
        }

        SimpleDateFormat f = new SimpleDateFormat("yyyy", Locale.CHINA);

        // 同比开始时间与结束时间
        Date currYearTBTime;
        Date lastYearTBTime;

        // 环比开始时间与结束时间
        Date currYearHBTime;
        Date lastYearHBTime;

        if (startTime == null) {
            // 本年的第一天
            startTime = DateTimeUtils.getCurrYearFirst();
            // 当前时间
            endTime = new Date();

            // 同比时间
            currYearTBTime = DateTimeUtils.getStartHBTime(startTime);
            lastYearTBTime = DateTimeUtils.getEndHBTime(endTime);

            // 环比时间
            currYearHBTime = DateTimeUtils.getTBTime(startTime,endTime).get("startTBTime");
            lastYearHBTime = DateTimeUtils.getTBTime(startTime,endTime).get("endTBTime");
        } else {
            endTime = DateTimeUtils.getTodayTime(endTime);
            currYearHBTime = DateTimeUtils.getStartHBTime(startTime);
            lastYearHBTime = DateTimeUtils.getEndHBTime(endTime);
           // System.err.println(DateTimeUtils.formatDate(currYearTBTime)+"环比 =====" + DateTimeUtils.formatDate(lastYearTBTime));

            currYearTBTime = DateTimeUtils.getTBTime(startTime,endTime).get("startTBTime");
            lastYearTBTime = DateTimeUtils.getTBTime(startTime,endTime).get("endTBTime");

         //   System.err.println(DateTimeUtils.formatDate(currYearHBTime)+"同比=====" + DateTimeUtils.formatDate(lastYearHBTime));
        }

        // 今年群众信访数据
        List<Activity> activityList = activityMapper.selectActivityList(deptIdList,deptId,startTime,endTime);
        // 查询今年信访事项
        List<Matter> matters = new ArrayList();
        if (activityList.size()>0) {
            // 查询今年信访事项
            matters = matterMapper.selectMatterList(activityList);
        }

        // 同比群众信访数据
        List<Activity> lastYearActivityList = activityMapper.selectActivityList(deptIdList,deptId,currYearHBTime,lastYearHBTime);
        // 查询同比信访事项
        List<Matter> mattersTB = new ArrayList<>();
        // 查询同比信访事项
        if (lastYearActivityList.size() > 0) {
            mattersTB = matterMapper.selectMatterList(lastYearActivityList);
        }

        // 环比群众信访数据
        List<Activity> HBActivityList = activityMapper.selectActivityList(deptIdList,deptId,currYearTBTime,lastYearTBTime);
        List<Matter> mattersHB = new ArrayList<>();
        // 查询环比信访事项
        if (HBActivityList.size() > 0) {
            mattersHB = matterMapper.selectMatterList(HBActivityList);
        }

        String content ;
       if (identifying == null || identifying == "") {
           // 反映建议类
           List<Matter> reflectSuggest = matters.stream().filter((n) -> StringUtils.isNotEmpty(n.getCcmID()) && n.getCcmID().startsWith("001")).collect(Collectors.toList());
           // 行政诉求类
           List<Matter> administrativeDemand = matters.stream().filter((n) -> StringUtils.isNotEmpty(n.getCcmID()) && n.getCcmID().startsWith("002")).collect(Collectors.toList());
           // 纪检监察类
           List<Matter> disciplinesSupervision = matters.stream().filter((n) -> StringUtils.isNotEmpty(n.getCcmID()) && n.getCcmID().startsWith("003")).collect(Collectors.toList());
           // 涉法涉诉类
           List<Matter> legalAndLitigationIssue = matters.stream().filter((n) -> StringUtils.isNotEmpty(n.getCcmID()) && n.getCcmID().startsWith("005")).collect(Collectors.toList());
           // 其他
           List<Matter> other = matters.stream().filter((n) -> StringUtils.isNotEmpty(n.getCcmID()) && n.getCcmID().startsWith("004")).collect(Collectors.toList());

           // 反映建议类同比
           List<Matter> reflectSuggestTB = mattersTB.stream().filter((n) -> StringUtils.isNotEmpty(n.getCcmID()) && n.getCcmID().startsWith("001")).collect(Collectors.toList());
           // 行政诉求类同比
           List<Matter> administrativeDemandTB = mattersTB.stream().filter((n) -> StringUtils.isNotEmpty(n.getCcmID()) && n.getCcmID().startsWith("002")).collect(Collectors.toList());
           // 纪检监察类同比
           List<Matter> disciplinesSupervisionTB = mattersTB.stream().filter((n) -> StringUtils.isNotEmpty(n.getCcmID()) && n.getCcmID().startsWith("003")).collect(Collectors.toList());
           // 涉法涉诉类同比
           List<Matter> legalAndLitigationIssueTB = mattersTB.stream().filter((n) -> StringUtils.isNotEmpty(n.getCcmID()) && n.getCcmID().startsWith("005")).collect(Collectors.toList());
           // 其他同比
           List<Matter> otherTB = mattersTB.stream().filter((n) -> StringUtils.isNotEmpty(n.getCcmID()) && n.getCcmID().startsWith("004")).collect(Collectors.toList());

           // 反映建议类环比
           List<Matter> reflectSuggestHB = mattersHB.stream().filter((n) -> StringUtils.isNotEmpty(n.getCcmID()) && n.getCcmID().startsWith("001")).collect(Collectors.toList());
           // 行政诉求类环比
           List<Matter> administrativeDemandHB = mattersHB.stream().filter((n) -> StringUtils.isNotEmpty(n.getCcmID()) && n.getCcmID().startsWith("002")).collect(Collectors.toList());
           // 纪检监察类环比
           List<Matter> disciplinesSupervisionHB = mattersHB.stream().filter((n) -> StringUtils.isNotEmpty(n.getCcmID()) && n.getCcmID().startsWith("003")).collect(Collectors.toList());
           // 涉法涉诉类环比
           List<Matter> legalAndLitigationIssueHB = mattersHB.stream().filter((n) -> StringUtils.isNotEmpty(n.getCcmID()) && n.getCcmID().startsWith("005")).collect(Collectors.toList());
           // 其他环比
           List<Matter> otherHB = mattersHB.stream().filter((n) -> StringUtils.isNotEmpty(n.getCcmID()) && n.getCcmID().startsWith("004")).collect(Collectors.toList());

           content =  "&nbsp;"+ "&nbsp;" + "&nbsp;"+ "&nbsp;" + DateTimeUtils.getYear(startTime) + "年" + DateTimeUtils.getMonth(startTime) + "月" + DateTimeUtils.getDay(startTime) + "日至" + DateTimeUtils.getYear(endTime) + "年" + DateTimeUtils.getMonth(endTime) + "月" + DateTimeUtils.getDay(endTime) +
                   "日，处理的" + matters.size() + "件信访事项中：涉法涉诉类" +  legalAndLitigationIssue.size() + "件，占总量" + CalculateUtils.makeUp(legalAndLitigationIssue.size(),matters.size()) +
                   "%，环比" + CalculateUtils.IncreaseDecreaseMakeUp(legalAndLitigationIssue.size(),legalAndLitigationIssueHB.size())  + "%、同比" + CalculateUtils.IncreaseDecreaseMakeUp(legalAndLitigationIssue.size(),legalAndLitigationIssueTB.size()) +
                   "%;行政诉求类：" + administrativeDemand.size() + "件，占总量" + CalculateUtils.makeUp(administrativeDemand.size(),matters.size()) +
                   "%，环比" + CalculateUtils.IncreaseDecreaseMakeUp(administrativeDemand.size(),administrativeDemandHB.size())  + "%、同比" + CalculateUtils.IncreaseDecreaseMakeUp(administrativeDemand.size(),administrativeDemandTB.size()) +
                   "%;意见建议类：" + reflectSuggest.size() + "件，占总量" + CalculateUtils.makeUp(reflectSuggest.size(),matters.size()) +
                   "%，环比" + CalculateUtils.IncreaseDecreaseMakeUp(reflectSuggest.size(),reflectSuggestHB.size())  + "%、同比" + CalculateUtils.IncreaseDecreaseMakeUp(reflectSuggest.size(),reflectSuggestTB.size()) +
                   "%;纪检监察类：" + disciplinesSupervision.size() + "件，占总量" + CalculateUtils.makeUp(disciplinesSupervision.size(),matters.size()) +
                   "%，环比" + CalculateUtils.IncreaseDecreaseMakeUp(disciplinesSupervision.size(),disciplinesSupervisionHB.size())  + "%、同比" + CalculateUtils.IncreaseDecreaseMakeUp(disciplinesSupervision.size(),disciplinesSupervisionTB.size()) +
                   "%;其它类：" + other.size() + "件，占总量" + CalculateUtils.makeUp(other.size(),matters.size()) +
                   "%，环比" + CalculateUtils.IncreaseDecreaseMakeUp( other.size(),otherHB.size())  + "%、同比" + CalculateUtils.IncreaseDecreaseMakeUp(other.size(),otherTB.size()) + "%。";

           List<Map<String,Object>> histogram = new ArrayList<>();
           HashMap<String, Object> map1 = new HashMap<>();
           HashMap<String, Object> map2 = new HashMap<>();
           HashMap<String, Object> map3 = new HashMap<>();
           HashMap<String, Object> map4 = new HashMap<>();
           HashMap<String, Object> map5 = new HashMap<>();
           map1.put("name","反映建议");
           map1.put("count",reflectSuggest.size());
           map1.put("id","001");
           map2.put("name","行政诉求");
           map2.put("count",administrativeDemand.size());
           map2.put("id","002");
           map3.put("name","纪检监察");
           map3.put("count",disciplinesSupervision.size());
           map3.put("id","003");
           map4.put("name","涉法涉诉");
           map4.put("count",legalAndLitigationIssue.size());
           map4.put("id","005");
           map5.put("name","其它");
           map5.put("count",other.size());
           map5.put("id","004");
           histogram.add(map1);
           histogram.add(map2);
           histogram.add(map3);
           histogram.add(map4);
           histogram.add(map5);
           map.put("histogram",histogram);

           List<ReflectContent> reflectContents = new ArrayList();
           reflectContents.add(ReflectContent.builder().name("反映建议").number(reflectSuggest.size()).percentage(CalculateUtils.makeUp(reflectSuggest.size(),matters.size()) + "%").build());
           reflectContents.add(ReflectContent.builder().name("行政诉求").number(administrativeDemand.size()).percentage(CalculateUtils.makeUp(administrativeDemand.size(),matters.size())+ "%").build());
           reflectContents.add(ReflectContent.builder().name("纪检监察").number(disciplinesSupervision.size()).percentage(CalculateUtils.makeUp(disciplinesSupervision.size(),matters.size())+ "%").build());
           reflectContents.add(ReflectContent.builder().name("涉法涉诉").number(legalAndLitigationIssue.size()).percentage(CalculateUtils.makeUp(legalAndLitigationIssue.size(),matters.size())+ "%").build());
           reflectContents.add(ReflectContent.builder().name("其它").number(other.size()).percentage(CalculateUtils.makeUp(other.size(),matters.size())+ "%").build());

           map.put("reflectContents",reflectContents);
           map.put("parentId","");
           map.put("content",content);
       }else {
           //加个分控判断
           List<Matter> selectMatters =new ArrayList<>();
           for (Matter matter : matters) {
               if (StringUtils.isNotEmpty(matter.getCcmID())){
                   selectMatters.add(matter);
               }
           }
           List<Matter> selectMatter = selectMatters.stream().filter((n) -> n.getCcmID().startsWith(identifying)).collect(Collectors.toList());

           List<String> childrenIDList = matterMapper.selectLFReasonID(identifying);

           List<Map<String,Object>> histogram = new ArrayList<>();
           List<ReflectContent> reflectContents = new ArrayList();

           // 问题分类名称
           String description = matterMapper.selectDescriptionByDictValue(identifying);

           if (childrenIDList.size() > 0) {

               content =  "&nbsp;"+ "&nbsp;" + "&nbsp;"+ "&nbsp;" + DateTimeUtils.getYear(startTime) + "年" + DateTimeUtils.getMonth(startTime) + "月" + DateTimeUtils.getDay(startTime) + "日至" + DateTimeUtils.getYear(endTime) + "年" + DateTimeUtils.getMonth(endTime) + "月" + DateTimeUtils.getDay(endTime) +
                       "日，处理的" + description + "类" + selectMatter.size() + "件信访事项中：";

               for (String childrenID : childrenIDList) {
                   HashMap<String, Object> map1 = new HashMap<>();
                   String name = matterMapper.selectDescriptionByDictValue(childrenID);
                   List<Matter> m1 = selectMatter.stream().filter(n -> n.getCcmID().startsWith(childrenID)).collect(Collectors.toList());
                   content = content + name + m1.size() + "件，占上一级分类" + CalculateUtils.makeUp(m1.size(),selectMatter.size()) + "%；";
                   map1.put("name",name);
                   map1.put("count",m1.size());
                   map1.put("id",childrenID);
                   reflectContents.add(ReflectContent.builder().name(name).number(m1.size()).percentage(CalculateUtils.makeUp(m1.size(),selectMatter.size())+ "%").build());
                   histogram.add(map1);
               }
               map.put("histogram",histogram);
               map.put("reflectContents",reflectContents);
               map.put("content",content);
               map.put("parentId",identifying);
           }else {
               // 父级分类
               String parentId = matterMapper.selectParentValueByDictValue(identifying);
               List<Matter> m1 = selectMatters.stream().filter(n -> n.getCcmID().startsWith(parentId)).collect(Collectors.toList());
               HashMap<String, Object> map1 = new HashMap<>();
               content = "&nbsp;"+ "&nbsp;" + "&nbsp;"+ "&nbsp;" + DateTimeUtils.getYear(startTime) + "年" + DateTimeUtils.getMonth(startTime) + "月" + DateTimeUtils.getDay(startTime) + "日至" + DateTimeUtils.getYear(endTime) + "年" + DateTimeUtils.getMonth(endTime) + "月" + DateTimeUtils.getDay(endTime) +
                        "日，共处理" + description + "类信访事项" + selectMatter.size() + "件，占上一级分类" + CalculateUtils.makeUp(selectMatter.size(),m1.size()) + "%。";
               reflectContents.add(ReflectContent.builder().name(description).number(selectMatter.size()).percentage(CalculateUtils.makeUp(selectMatter.size(),m1.size())+ "%").build());
               map1.put("name",description);
               map1.put("count",selectMatter.size());
               map1.put("id",identifying);
               histogram.add(map1);

               map.put("histogram",histogram);
               map.put("reflectContents",reflectContents);
               map.put("content",content);
               map.put("parentId",parentId);
           }
       }

        return map;
    }

    // 热点问题分析
    @Override
    public Map<String, Object> hotSpot(String deptIdList, String userId, String sTime, String eTime,String registerTypeIdList, String identifying) throws ParseException {
        Map<String, Object> map = new HashMap<>();
        Dept dept = deptService.selectDeptByUserId(userId);
        // 当前登录用户的单位id
        String  deptId = "";
        if (deptIdList == null || deptIdList == "") {
            deptId = dept.getId().toString();
        }
        Date startTime = null;
        Date endTime = null;
        SimpleDateFormat  format = new SimpleDateFormat("yyyy-MM-dd");
        if (sTime != null && sTime != "") {
            startTime = format.parse(sTime);
            endTime = format.parse(eTime);
        }

        SimpleDateFormat f = new SimpleDateFormat("yyyy", Locale.CHINA);

        // 同比开始时间与结束时间
        Date currYearTBTime;
        Date lastYearTBTime;

        // 环比开始时间与结束时间
        Date currYearHBTime;
        Date lastYearHBTime;

        if (startTime == null) {
            // 本年的第一天
            startTime = DateTimeUtils.getCurrYearFirst();
            // 当前时间
            endTime = new Date();

            // 同比时间
            currYearHBTime = DateTimeUtils.getStartHBTime(startTime);
            lastYearHBTime = DateTimeUtils.getEndHBTime(endTime);

            // 环比时间
            currYearTBTime = DateTimeUtils.getTBTime(startTime,endTime).get("startTBTime");;
            lastYearTBTime = DateTimeUtils.getTBTime(startTime,endTime).get("endTBTime");
        } else {
            endTime = DateTimeUtils.getTodayTime(endTime);

            currYearHBTime = DateTimeUtils.getStartHBTime(startTime);
            lastYearHBTime = DateTimeUtils.getEndHBTime(endTime);

            currYearTBTime = DateTimeUtils.getTBTime(startTime,endTime).get("startTBTime");
            lastYearTBTime = DateTimeUtils.getTBTime(startTime,endTime).get("endTBTime");
        }

        // 今年群众信访数据
        List<Activity> activityList = activityMapper.selectHotSpotActivityList(deptIdList,deptId,startTime,endTime,registerTypeIdList);

        // 查询今年信访事项
        List<Matter> matters = new ArrayList();
        if (activityList.size()>0) {
            // 查询今年信访事项
            matters = matterMapper.selectMatterList(activityList);
        }
        // 初访
        List<Matter> firstMatters = matters.stream().filter((n) -> "100".equals( n.getVisitID())).collect(Collectors.toList());
        // 重访
        List<Matter> repetitionMatters = matters.stream().filter((n) -> "200".equals( n.getVisitID())).collect(Collectors.toList());

        // 同比群众信访数据
        List<Activity> TBActivityList = activityMapper.selectHotSpotActivityList(deptIdList,deptId,currYearHBTime,lastYearHBTime,registerTypeIdList);
        // 查询同比信访事项
        List<Matter> mattersTB = new ArrayList<>();
        // 查询同比信访事项
        if (TBActivityList.size() > 0) {
            mattersTB = matterMapper.selectMatterList(TBActivityList);
        }

        // 环比群众信访数据
        List<Activity> HBActivityList = activityMapper.selectHotSpotActivityList(deptIdList,deptId,currYearTBTime,lastYearTBTime,registerTypeIdList);
        List<Matter> mattersHB = new ArrayList<>();
        // 查询环比信访事项
        if (HBActivityList.size() > 0) {
            mattersHB = matterMapper.selectMatterList(HBActivityList);
        }

        if (identifying == null || identifying == "") {
            // 反映建议类
            List<Matter> reflectSuggest = matters.stream().filter((n) -> StringUtils.isNotEmpty(n.getCcmID()) && n.getCcmID().startsWith("001")).collect(Collectors.toList());
            // 行政诉求类
            List<Matter> administrativeDemand = matters.stream().filter((n) -> StringUtils.isNotEmpty(n.getCcmID()) && n.getCcmID().startsWith("002")).collect(Collectors.toList());
            // 纪检监察类
            List<Matter> disciplinesSupervision = matters.stream().filter((n) -> StringUtils.isNotEmpty(n.getCcmID()) && n.getCcmID().startsWith("003")).collect(Collectors.toList());
            // 涉法涉诉类
            List<Matter> legalAndLitigationIssue = matters.stream().filter((n) -> StringUtils.isNotEmpty(n.getCcmID()) && n.getCcmID().startsWith("005")).collect(Collectors.toList());
            // 其他
            List<Matter> other = matters.stream().filter((n) -> StringUtils.isNotEmpty(n.getCcmID()) && n.getCcmID().startsWith("004")).collect(Collectors.toList());

            // 反映建议类初访
            List<Matter> reflectSuggestFirst = firstMatters.stream().filter((n) -> StringUtils.isNotEmpty(n.getCcmID()) && n.getCcmID().startsWith("001")).collect(Collectors.toList());
            // 行政诉求类初访
            List<Matter> administrativeDemandFirst = firstMatters.stream().filter((n) -> StringUtils.isNotEmpty(n.getCcmID()) && n.getCcmID().startsWith("002")).collect(Collectors.toList());
            // 纪检监察类初访
            List<Matter> disciplinesSupervisionFirst = firstMatters.stream().filter((n) -> StringUtils.isNotEmpty(n.getCcmID()) && n.getCcmID().startsWith("003")).collect(Collectors.toList());
            // 涉法涉诉类初访
            List<Matter> legalAndLitigationIssueFirst = firstMatters.stream().filter((n) -> StringUtils.isNotEmpty(n.getCcmID()) && n.getCcmID().startsWith("005")).collect(Collectors.toList());
            // 其他初访
            List<Matter> otherFirst = firstMatters.stream().filter((n) -> StringUtils.isNotEmpty(n.getCcmID()) && n.getCcmID().startsWith("004")).collect(Collectors.toList());

            // 反映建议类
            List<Matter> reflectSuggestRepetition = repetitionMatters.stream().filter((n) -> StringUtils.isNotEmpty(n.getCcmID()) && n.getCcmID().startsWith("001")).collect(Collectors.toList());
            // 行政诉求类
            List<Matter> administrativeDemandRepetition = repetitionMatters.stream().filter((n) -> StringUtils.isNotEmpty(n.getCcmID()) && n.getCcmID().startsWith("002")).collect(Collectors.toList());
            // 纪检监察类
            List<Matter> disciplinesSupervisionRepetition = repetitionMatters.stream().filter((n) -> StringUtils.isNotEmpty(n.getCcmID()) && n.getCcmID().startsWith("003")).collect(Collectors.toList());
            // 涉法涉诉类
            List<Matter> legalAndLitigationIssueRepetition = repetitionMatters.stream().filter((n) -> StringUtils.isNotEmpty(n.getCcmID()) && n.getCcmID().startsWith("005")).collect(Collectors.toList());
            // 其他
            List<Matter> otherRepetition = repetitionMatters.stream().filter((n) -> StringUtils.isNotEmpty(n.getCcmID()) && n.getCcmID().startsWith("004")).collect(Collectors.toList());


            // 反映建议类同比
            List<Matter> reflectSuggestTB = mattersTB.stream().filter((n) -> StringUtils.isNotEmpty(n.getCcmID()) && n.getCcmID().startsWith("001")).collect(Collectors.toList());
            // 行政诉求类同比
            List<Matter> administrativeDemandTB = mattersTB.stream().filter((n) -> StringUtils.isNotEmpty(n.getCcmID()) && n.getCcmID().startsWith("002")).collect(Collectors.toList());
            // 纪检监察类同比
            List<Matter> disciplinesSupervisionTB = mattersTB.stream().filter((n) -> StringUtils.isNotEmpty(n.getCcmID()) && n.getCcmID().startsWith("003")).collect(Collectors.toList());
            // 涉法涉诉类同比
            List<Matter> legalAndLitigationIssueTB = mattersTB.stream().filter((n) -> StringUtils.isNotEmpty(n.getCcmID()) && n.getCcmID().startsWith("005")).collect(Collectors.toList());
            // 其他同比
            List<Matter> otherTB = mattersTB.stream().filter((n) -> StringUtils.isNotEmpty(n.getCcmID()) && n.getCcmID().startsWith("004")).collect(Collectors.toList());

            // 反映建议类环比
            List<Matter> reflectSuggestHB = mattersHB.stream().filter((n) -> StringUtils.isNotEmpty(n.getCcmID()) && n.getCcmID().startsWith("001")).collect(Collectors.toList());
            // 行政诉求类环比
            List<Matter> administrativeDemandHB = mattersHB.stream().filter((n) -> StringUtils.isNotEmpty(n.getCcmID()) && n.getCcmID().startsWith("002")).collect(Collectors.toList());
            // 纪检监察类环比
            List<Matter> disciplinesSupervisionHB = mattersHB.stream().filter((n) -> StringUtils.isNotEmpty(n.getCcmID()) && n.getCcmID().startsWith("003")).collect(Collectors.toList());
            // 涉法涉诉类环比
            List<Matter> legalAndLitigationIssueHB = mattersHB.stream().filter((n) -> StringUtils.isNotEmpty(n.getCcmID()) && n.getCcmID().startsWith("005")).collect(Collectors.toList());
            // 其他环比
            List<Matter> otherHB = mattersHB.stream().filter((n) -> StringUtils.isNotEmpty(n.getCcmID()) && n.getCcmID().startsWith("004")).collect(Collectors.toList());

            HashMap<String, Object> histogram = new HashMap<>();
            String[] nameList = new String[]{"反映建议","行政诉求","纪检监察","涉法涉诉","其他"};
            Integer[] gross = new Integer[]{reflectSuggest.size(),administrativeDemand.size(),disciplinesSupervision.size(),legalAndLitigationIssue.size(),other.size()};
            Integer[] first = new Integer[]{reflectSuggestFirst.size(),administrativeDemandFirst.size(),disciplinesSupervisionFirst.size(),legalAndLitigationIssueFirst.size(),otherFirst.size()};
            Integer[] revisit = new Integer[]{reflectSuggestRepetition.size(),administrativeDemandRepetition.size(),disciplinesSupervisionRepetition.size(),legalAndLitigationIssueRepetition.size(),otherRepetition.size()};
            histogram.put("nameList",nameList);
            histogram.put("count",gross);
            histogram.put("firstXF",first);
            histogram.put("repetitionXF",revisit);
            map.put("histogram",histogram);

            // 热点问题表
            List<Label> lableList = matterMapper.selectHotSpotType();
            List<ReflectContent> hotTopics = new ArrayList();
            for (Label lable : lableList) {
                Integer count  = 0;
                Integer sum =0;
                for (Matter matter : matters) {
                    String hotspot = matter.getHotspot();
                    JSONArray objects = JSONArray.parseArray(hotspot);
                    for (int i = 0; i < objects.size(); i++) {
                        JSONObject jsonObject = objects.getJSONObject(i);
                        String id = jsonObject.getString("id");
                        sum++;
                        if (lable.getId().equals(id)) {
                            count++;
                        }
                    }
                }
                hotTopics.add(ReflectContent.builder().name(lable.getName()).number(count).percentage(CalculateUtils.makeUp(count,sum)+ "%").build());
            }
            map.put("hotTopics",hotTopics);

            // 反映内容排行
            List<ReflectContent> reflectContents = new ArrayList<>();
            reflectContents.add(ReflectContent.builder().name("反映建议").number(reflectSuggest.size()).zb(CalculateUtils.makeUp(reflectSuggest.size(),matters.size()) + "%")
                    .zbTB(CalculateUtils.IncreaseDecreaseMakeUp(reflectSuggest.size(),reflectSuggestTB.size()) + "%").zbHB(CalculateUtils.IncreaseDecreaseMakeUp(reflectSuggest.size(),reflectSuggestHB.size()) + "%")
                    .percentage(CalculateUtils.makeUp(reflectSuggest.size(),matters.size()) + "%").percentageTB(CalculateUtils.IncreaseDecreaseMakeUp(reflectSuggest.size(),reflectSuggestTB.size()) + "%")
                    .percentageHB(CalculateUtils.IncreaseDecreaseMakeUp(reflectSuggest.size(),reflectSuggestHB.size()) + "%").build());

            reflectContents.add(ReflectContent.builder().name("行政诉求").number(administrativeDemand.size()).zb(CalculateUtils.makeUp(administrativeDemand.size(),matters.size()) + "%")
                    .zbTB(CalculateUtils.IncreaseDecreaseMakeUp(administrativeDemand.size(),administrativeDemandTB.size()) + "%").zbHB(CalculateUtils.IncreaseDecreaseMakeUp(administrativeDemand.size(),administrativeDemandHB.size()) + "%")
                    .percentage(CalculateUtils.makeUp(administrativeDemand.size(),matters.size()) + "%").percentageTB(CalculateUtils.IncreaseDecreaseMakeUp(administrativeDemand.size(),administrativeDemandTB.size()) + "%")
                    .percentageHB(CalculateUtils.IncreaseDecreaseMakeUp(administrativeDemand.size(),administrativeDemandHB.size()) + "%").build());

            reflectContents.add(ReflectContent.builder().name("纪检监察").number(disciplinesSupervision.size()).zb(CalculateUtils.makeUp(disciplinesSupervision.size(),matters.size()) + "%")
                    .zbTB(CalculateUtils.IncreaseDecreaseMakeUp(disciplinesSupervision.size(),disciplinesSupervisionTB.size()) + "%").zbHB(CalculateUtils.IncreaseDecreaseMakeUp(disciplinesSupervision.size(),disciplinesSupervisionHB.size()) + "%")
                    .percentage(CalculateUtils.makeUp(disciplinesSupervision.size(),matters.size()) + "%").percentageTB(CalculateUtils.IncreaseDecreaseMakeUp(disciplinesSupervision.size(),disciplinesSupervisionTB.size()) + "%")
                    .percentageHB(CalculateUtils.IncreaseDecreaseMakeUp(disciplinesSupervision.size(),disciplinesSupervisionHB.size()) + "%").build());

            reflectContents.add(ReflectContent.builder().name("涉法涉诉").number(legalAndLitigationIssue.size()).zb(CalculateUtils.makeUp(legalAndLitigationIssue.size(),matters.size()) + "%")
                    .zbTB(CalculateUtils.IncreaseDecreaseMakeUp(legalAndLitigationIssue.size(),legalAndLitigationIssueTB.size()) + "%").zbHB(CalculateUtils.IncreaseDecreaseMakeUp(legalAndLitigationIssue.size(),legalAndLitigationIssueHB.size()) + "%")
                    .percentage(CalculateUtils.makeUp(legalAndLitigationIssue.size(),matters.size()) + "%").percentageTB(CalculateUtils.IncreaseDecreaseMakeUp(legalAndLitigationIssue.size(),legalAndLitigationIssueTB.size()) + "%")
                    .percentageHB(CalculateUtils.IncreaseDecreaseMakeUp(legalAndLitigationIssue.size(),legalAndLitigationIssueHB.size()) + "%").build());

            reflectContents.add(ReflectContent.builder().name("其它").number(other.size()).zb(CalculateUtils.makeUp(other.size(),matters.size()) + "%")
                    .zbTB(CalculateUtils.IncreaseDecreaseMakeUp(other.size(),otherTB.size()) + "%").zbHB(CalculateUtils.IncreaseDecreaseMakeUp(other.size(),otherHB.size()) + "%")
                    .percentage(CalculateUtils.makeUp(other.size(),matters.size()) + "%").percentageTB(CalculateUtils.IncreaseDecreaseMakeUp(other.size(),otherTB.size()) + "%")
                    .percentageHB(CalculateUtils.IncreaseDecreaseMakeUp(other.size(),otherHB.size()) + "%").build());

            map.put("reflectContents",reflectContents);
        }else {
            // 根据传入的层级过滤信访事项
            List<Matter> selectMatter = matters.stream().filter((n) -> n.getCcmID().startsWith(identifying)).collect(Collectors.toList());
            // 同比
            List<Matter> selectMatterTB = mattersTB.stream().filter((n) -> n.getCcmID().startsWith(identifying)).collect(Collectors.toList());
            // 环比
            List<Matter> selectMatterHB = mattersHB.stream().filter((n) -> n.getCcmID().startsWith(identifying)).collect(Collectors.toList());
            // 下级问题分类id
            List<String> childrenIDList = matterMapper.selectLFReasonID(identifying);
            Map<String,Object> histogram = new HashMap<>();

            // 信访总量
            List<String> nameList = new ArrayList<>();
            List<Integer> count = new ArrayList<>();
            List<Integer> first = new ArrayList<>();
            List<Integer> revisit = new ArrayList<>();
            for (String childrenID : childrenIDList) {
                String name = matterMapper.selectDescriptionByDictValue(childrenID);
                List<Matter> m1 = selectMatter.stream().filter(n -> n.getCcmID().startsWith(childrenID)).collect(Collectors.toList());
                List<Matter> m2 = selectMatter.stream().filter(n -> "100".equals(n.getVisitID()) && n.getCcmID().startsWith(childrenID)).collect(Collectors.toList());
                List<Matter> m3 = selectMatter.stream().filter(n -> "200".equals(n.getVisitID()) && n.getCcmID().startsWith(childrenID)).collect(Collectors.toList());
                nameList.add(name);
                count.add(m1.size());
                first.add(m2.size());
                revisit.add(m3.size());
            }
            histogram.put("nameList",nameList);
            histogram.put("count",count);
            histogram.put("first",first);
            histogram.put("revisit",revisit);
            map.put("histogram",histogram);

            // 热点问题表
            List<Label> lableList = matterMapper.selectHotSpotType();
            List<ReflectContent> hotTopics = new ArrayList();
            for (Label lable : lableList) {
                Integer number  = 0;
                Integer sum =0;
                for (Matter matter : selectMatter) {
                    String hotspot = matter.getHotspot();
                    JSONArray objects = JSONArray.parseArray(hotspot);
                    for (int i = 0; i < objects.size(); i++) {
                        JSONObject jsonObject = objects.getJSONObject(i);
                        String id = jsonObject.getString("id");
                        sum++;
                        if (lable.getId().equals(id)) {
                            number++;
                        }
                    }
                }
                hotTopics.add(ReflectContent.builder().name(lable.getName()).number(number).percentage(CalculateUtils.makeUp(number,sum)+ "%").build());
            }
            map.put("hotTopics",hotTopics);

            // 反映内容排行
            List<ReflectContent> reflectContents = new ArrayList();
            for (String childrenID : childrenIDList) {
                String name = matterMapper.selectDescriptionByDictValue(childrenID);
                List<Matter> m1 = selectMatter.stream().filter(n -> n.getCcmID().startsWith(childrenID)).collect(Collectors.toList());
                List<Matter> m2 = selectMatterTB.stream().filter(n -> n.getCcmID().startsWith(childrenID)).collect(Collectors.toList());
                List<Matter> m3 = selectMatterHB.stream().filter(n -> n.getCcmID().startsWith(childrenID)).collect(Collectors.toList());
                reflectContents.add(ReflectContent.builder().name(name).number(m1.size()).zb(CalculateUtils.makeUp(m1.size(),matters.size()) + "%")
                        .zbTB(CalculateUtils.IncreaseDecreaseMakeUp(m2.size(),mattersTB.size()) + "%").zbHB(CalculateUtils.IncreaseDecreaseMakeUp(m3.size(),mattersHB.size()) + "%")
                        .percentage(CalculateUtils.makeUp(m1.size(),selectMatter.size()) + "%").percentageTB(CalculateUtils.IncreaseDecreaseMakeUp(m2.size(),selectMatterTB.size()) + "%")
                        .percentageHB(CalculateUtils.IncreaseDecreaseMakeUp(m3.size(),selectMatterHB.size()) + "%").build());
            }

            map.put("reflectContents",reflectContents);
        }

        return map;
    }

    /**
     * 人民群众信访事项摘录单
     * @param id
     * @return
     */
    @Override
    public MatterDto MessageAbstract(String id) {
        MatterDto matterDto = matterMapper.MessageAbstract(id);


        if (String.valueOf(matterDto.getIsAccept()).equals("0")){
            matterDto.setIsAcceptName("是");
        }else {
            matterDto.setIsAcceptName("否");
        }

        //反映内容分类
        Dictionary dictionary;
        if (StringUtils.isEmpty(matterDto.getContentClassifyMainID())){
            String contentClassifyID = matterDto.getContentClassifyID();
            dictionary = dictionaryMapper.DictionaryBasic(contentClassifyID.substring(0,contentClassifyID.length() - 3));
            for (int i = 3; i <contentClassifyID.length() ; i+=3) {
                if (StringUtils.isNotEmpty(dictionary.getParentValue())){
                    String dictValue = dictionary.getParentValue();
                    String description = dictionary.getDescription();
                    matterDto.setContentClassify(description+"->"+matterDto.getContentClassify());
                    dictionary= dictionaryMapper.DictionaryBasic(dictValue);
                }else {
                    matterDto.setContentClassify(dictionary.getDescription()+"->"+matterDto.getContentClassify());
                }
            }
        }else {
            String contentClassifyID1 = matterDto.getContentClassifyID();
            String[] split = contentClassifyID1.split(",");
            List<Matter> MatterDiscipline = new ArrayList<>();
            for (String s : split) {
                Matter matter =new Matter();
                dictionary = dictionaryMapper.DictionaryBasic(s);
                matter.setContentClassify(dictionary.getDescription());
                for (int i = 3; i <s.length() ; i+=3) {
                    if (StringUtils.isNotEmpty(dictionary.getParentValue())){
                        String dictValue = dictionary.getDictValue().substring(0,dictionary.getDictValue().length() - 3);
                        dictionary= dictionaryMapper.DictionaryBasic(dictValue);
                        String description = dictionary.getDescription();
                        matter.setContentClassify(description+"->"+matter.getContentClassify());
                    }else {
                        matter.setContentClassify(dictionary.getDescription()+"->"+matterDto.getContentClassify());
                    }
                }
                MatterDiscipline.add(matter);
                matterDto.setContentClassify("");
            }
            for (Matter matter : MatterDiscipline) {
                if (StringUtils.isEmpty(matterDto.getContentClassify())){
                    matterDto.setContentClassify(matter.getContentClassify());
                }else {
                    matterDto.setContentClassify(matter.getContentClassify()+" "+matterDto.getContentClassify());
                }
            }
        }
        //共同信访人主要身份信息
          String personID = matterDto.getPersonID();
            if (personID.contains(",")){
                List<String> personList = new ArrayList<>();
                String[] split = personID.split(",");
                for (String s : split) {
                    personList.add(s);
                }
                personList.remove(personList.get(0));
                List<Person> people = personMapper.PersonList(personList);
                List<Person> newpeople = people.subList(0, Math.min(4, people.size()));
                for (Person person : newpeople) {
                    if (StringUtils.isNull( matterDto.getPersonName())){
                        String idNumber = person.getIDNumber();
                        if (StringUtils.isNotEmpty(idNumber)){
                            matterDto.setPersonName(person.getName()+":"+idNumber);
                        }else {
                            matterDto.setPersonName(person.getName());
                        }
                    }else {
                        String idNumber = person.getIDNumber();
                        if (StringUtils.isNotEmpty(idNumber)){
                            matterDto.setPersonName(matterDto.getPersonName()+";"+person.getName()+":"+idNumber);
                        }else {
                            matterDto.setPersonName(matterDto.getPersonName()+";"+person.getName());
                        }
                    }
                }
            }


        //一共信访次数
        List<MatterRelation> matterRelation = relationMapper.RelationList(matterDto.getId());
        //把反馈的数据提出
        List<MatterDto> matterDtos;
        //反馈次数的id拿出
        List<String> myList = new ArrayList<>();
        if (StringUtils.isNotEmpty(matterRelation)){
            List<String> newRelation = new ArrayList<>();
        for (MatterRelation relation : matterRelation) {
            newRelation.add(relation.getMatterA());
            newRelation.add(relation.getMatterB());
          }
             myList = newRelation.stream().distinct().collect(Collectors.toList());
            matterDtos = matterMapper.MessageList(myList);
        }else {
            //反馈次数只有一次
            myList.add(matterDto.getId());
            matterDtos = matterMapper.MessageList(myList);
        }
        //事项去重

        int size = matterDtos.size();
        if (size>1){
            matterDto.setVisit("重复反映");
        }else {
            matterDto.setVisit("初次反映");
        }
        //首次反映时间
        matterDto.setCreateTimefirst(DateTimeUtils.getDayMonthYear(matterDtos.get(0).getCreateTime()));
        //最近反映时间
        if (StringUtils.isNotNull(matterDtos.get(size-1).getCreateTime())){
            matterDto.setLastcreateTimeName(DateTimeUtils.getDayMonthYear(matterDtos.get(size-1).getCreateTime()));
        }
        matterDto.setCreateOrg(matterDtos.get(0).getCreateOrg());
        matterDto.setLastcreateOrg(matterDtos.get(size-1).getCreateOrg());
        //总来访
        matterDto.setSameNum(String.valueOf(size));
        //来信
        int letterNum = matterDtos.stream().filter(n -> "002".equals(n.getRegisterTypeID())).collect(Collectors.toList()).size();
        matterDto.setLetterNum(String.valueOf(letterNum));
        //网上信访
        int internetNum = matterDtos.stream().filter(n -> "004".equals(n.getRegisterTypeID())).collect(Collectors.toList()).size();
        matterDto.setInternet(String.valueOf(internetNum));
        //电话信访
        int phoneNum = matterDtos.stream().filter(n -> "003".equals(n.getRegisterTypeID())).collect(Collectors.toList()).size();
        matterDto.setPhoneNum(String.valueOf(phoneNum));
        //累计反映
        matterDto.setSum(String.valueOf(size));
        //县人大登记
        int countyNum = matterDtos.stream().filter(n -> "4".equals(String.valueOf(n.getType()))).collect(Collectors.toList()).size();
        matterDto.setCountyNum(String.valueOf(countyNum));
        //市人大登记
        int cityNum = matterDtos.stream().filter(n -> "3".equals(String.valueOf(n.getType()))).collect(Collectors.toList()).size();
        matterDto.setCityNum(String.valueOf(cityNum));
        //省人大登记
        int provinceNum = matterDtos.stream().filter(n -> "2".equals(String.valueOf(n.getType()))).collect(Collectors.toList()).size();
        matterDto.setProvinceNum(String.valueOf(provinceNum));
        //异常访 次数
        int isAbnormal = matterDtos.stream().filter(n -> "1".equals(String.valueOf(n.getIsAccept()))).collect(Collectors.toList()).size();
        matterDto.setOneabnormalSum(String.valueOf(isAbnormal));
        //越级访
        int isleapfrogNum = matterDtos.stream().filter((n) -> String.valueOf(n.getIsleapfrog()).equals("1")).collect(Collectors.toList()).size();
        matterDto.setIsleapfrogNum(String.valueOf(isleapfrogNum));
        List<String> list =new ArrayList<>();
        for (MatterDto dto : matterDtos) {
            String abnormalID = dto.getAbnormalID();
            if (StringUtils.isNotEmpty(abnormalID)){
                String[] split = abnormalID.split(",");
                for (String s : split) {
                    list.add(s);
                }
            }
        }
        //非指定场所访
        int notbelongNum = list.stream().filter((n) -> n.equals("001002001") ||  n.equals("001002002")|| n.equals("001002003") || n.equals("001002004") ||  n.equals("001002005")||  n.equals("001002006")).collect(Collectors.toList()).size();
        matterDto.setNotbelongNum(String.valueOf(notbelongNum));
        //行为异常访
        int abnormalNum = list.stream().filter((n) -> n.equals("001003001") ||  n.equals("001003002")|| n.equals("001003003") || n.equals("001003004") ||  n.equals("001003005")||  n.equals("001003006")||  n.equals("001003007")|| n.equals("001003008")|| n.equals("001003009") || n.equals("001003010")).collect(Collectors.toList()).size();
        matterDto.setAbnormalNum(String.valueOf(abnormalNum));
        //携带危险器械
        int riskNum = list.stream().filter((n) -> n.equals("001003005")).collect(Collectors.toList()).size();
        matterDto.setRiskNum(String.valueOf(riskNum));
        //扬言信
        int threatenNum = list.stream().filter((n) -> n.equals("002001001") || n.equals("002001002")||  n.equals("002001003") ||n.equals("002001004") ||n.equals("002001005") ).collect(Collectors.toList()).size();
        matterDto.setThreatenNum(String.valueOf(threatenNum));
        //网上扬言
        int netcomplainNum = list.stream().filter((n) -> n.equals("003001001") || n.equals("003001002")||  n.equals("003001003") ||n.equals("003001004") ||n.equals("003001005") ).collect(Collectors.toList()).size();
        matterDto.setNetcomplainNum(String.valueOf(netcomplainNum));
        //电话扬言
        int phonecomplainNum = list.stream().filter((n) -> n.equals("004001001") || n.equals("004001002")||  n.equals("004001003") ||n.equals("004001004") ||n.equals("004001005") ).collect(Collectors.toList()).size();
        matterDto.setPhonecomplainNum(String.valueOf(phonecomplainNum));
        //累计异常信访
        matterDto.setAbnormalSum(String.valueOf(isAbnormal));

        //本系统办理情况
        List<MatterDto> matterDtoOneself = matterMapper.TransactList(myList);
        //信访事项曾交办
        List<MatterDto> matterDtoOneselfNew = new ArrayList<>();
        for (MatterDto dto : matterDtoOneself) {
            if (StringUtils.isNotNull(dto)){
                matterDtoOneselfNew.add(dto);
            }
        }
        int assignNum = matterDtoOneselfNew.stream().filter((n) -> n.getHandleModelID().equals("001003001") || n.getHandleModelID().equals("002003001")||  n.getHandleModelID().equals("003003001") ||n.getHandleModelID().equals("004003001") ||n.getHandleModelID().equals("005003001") ).collect(Collectors.toList()).size();

        matterDto.setAssignNum(String.valueOf(assignNum));
        //信访事项转送
        int passNum = matterDtoOneselfNew.stream().filter((n) -> n.getHandleModelID().equals("001003002") || n.getHandleModelID().equals("002003002")||  n.getHandleModelID().equals("003003003") ||n.getHandleModelID().equals("004003004") ||n.getHandleModelID().equals("005003005") ).collect(Collectors.toList()).size();
        matterDto.setPassNum(String.valueOf(passNum));
        //县人大办理
        List<MatterDto> collect = matterDtoOneselfNew.stream().filter((n) -> String.valueOf(n.getType()).equals("4")).collect(Collectors.toList());
        int countytransactSCum = collect.stream().filter((n) -> String.valueOf(n.getIsRenDa()).equals("1") && String.valueOf(n.getAgent()).equals("1")).collect(Collectors.toList()).size();
        matterDto.setCountytransactSum(String.valueOf(countytransactSCum));
        //市级人大办理
        List<MatterDto> collect1 = matterDtoOneselfNew.stream().filter((n) -> String.valueOf(n.getType()).equals("3")).collect(Collectors.toList());
        int citytransactNum = collect1.stream().filter((n) -> String.valueOf(n.getIsRenDa()).equals("1") && String.valueOf(n.getAgent()).equals("1")).collect(Collectors.toList()).size();
        matterDto.setCitytransactNum(String.valueOf(citytransactNum));
        //省级人大处理
        List<MatterDto> collect2 = matterDtoOneselfNew.stream().filter((n) -> String.valueOf(n.getType()).equals("2")).collect(Collectors.toList());
        int provincetransactNum = collect2.stream().filter((n) -> String.valueOf(n.getIsRenDa()).equals("1") && String.valueOf(n.getAgent()).equals("1")).collect(Collectors.toList()).size();
        matterDto.setProvincetransactNum(String.valueOf(provincetransactNum));

        //当前办理方式
        MatterDto matterDto2 = matterDtos.get(size - 1);
        matterDto.setHandleModel(matterDto2.getHandleModel());
        //当前去向单位
        matterDto.setFinalDisposal(matterDto2.getFinalDisposal());
        //最近的反馈内容摘要
        matterDto.setNewabstractName(matterDto2.getAbstractName());
        return matterDto;
    }



    //
    @Override
    public Map<String, Object> morePersonList(String id) {
        Map<String, Object> map = new HashMap<>();
        List<MatterVO> matters = matterMapper.morePersonList(id);
        MatterVO newmatter = new MatterVO();
        if (matters.size() == 1) {
            newmatter = matters.get(0);
        } else {
            for (MatterVO matter : matters) {
                if (StringUtils.isNotEmpty(matter.getObjectName())) {
                    newmatter = matter;
                }
            }
        }
        //反映群体名称
        map.put("objectName", newmatter.getObjectName());
        //信访事项名称
        map.put("xfName", newmatter.getXfName());
        String personID = newmatter.getPersonID();
        List<String> personList = new ArrayList<>();
        String[] split = personID.split(",");
        for (String s : split) {
            personList.add(s);
        }
        //涉及人数
        map.put("xfNumber", newmatter.getXfNumber());
        List<MatterRelation> matterRelations = relationMapper.RelationList(newmatter.getId());
        //多次反应事项id
          List<String> myList = new ArrayList<>();
          List<MatterDto> matterDtos;
            if (StringUtils.isNotEmpty(matterRelations)) {
                List<String> newRelation = new ArrayList<>();
                for (MatterRelation relation : matterRelations) {
                    newRelation.add(relation.getMatterA());
                    newRelation.add(relation.getMatterB());
                }
                myList = newRelation.stream().distinct().collect(Collectors.toList());
                 matterDtos = matterMapper.MessageList(myList);
            }else {
                myList.add(newmatter.getId());
                matterDtos = matterMapper.MessageList(myList);
            }
        //集体访
        int groupNum = matterDtos.stream().filter((n) -> n.getXfTypeID().equals("001002")).collect(Collectors.toList()).size();
         map.put("groupNum",groupNum);
            //联名信
        int jointlyNum = matterDtos.stream().filter((n) -> n.getXfTypeID().equals("002002")).collect(Collectors.toList()).size();
        map.put("jointlyNum",jointlyNum);
            //省人大登记
        int provincialNum = matterDtos.stream().filter((n) -> String.valueOf(n.getType()).equals("2")).collect(Collectors.toList()).size();
        map.put("provincialNum",provincialNum);
        //市人大登记
        int cityNum = matterDtos.stream().filter((n) -> String.valueOf(n.getType()).equals("3")).collect(Collectors.toList()).size();
        map.put("cityNum",cityNum);
        //县人大登记
        int countyNum = matterDtos.stream().filter((n) -> String.valueOf(n.getType()).equals("4")).collect(Collectors.toList()).size();
        map.put("countyNum",countyNum);
        List<PersonVO> newperson = new ArrayList<>();
        int i=0;
        for (String s : personList) {
            List<PersonVO> person = personMapper.MorePerson(s);
            PersonVO personVO =new PersonVO();
            i=i+1;
            personVO.setSerial(String.valueOf(i));
            personVO.setName(person.get(0).getName());
            personVO.setIDType(person.get(0).getIDType());
            personVO.setIDNumber(person.get(0).getIDNumber());
            personVO.setMobilePhone(person.get(0).getMobilePhone());
            personVO.setCreateTimeName(DateTimeUtils.getDayMonthYear(person.get(0).getCreateTime()));
            personVO.setLastTimeName(DateTimeUtils.getDayMonthYear(person.get(person.size()-1).getCreateTime()));
            int oneinterviewSum = person.stream().filter((n) -> String.valueOf(n.getXfTypeID()).equals("001002")).collect(Collectors.toList()).size();
            personVO.setOneinterviewSum(String.valueOf(oneinterviewSum));
            int onejointlySum = person.stream().filter((n) -> String.valueOf(n.getXfTypeID()).equals("002002")).collect(Collectors.toList()).size();
            personVO.setOnejointlySum(String.valueOf(onejointlySum));
            personVO.setOneSum(String.valueOf(person.size()));
            int behalfNum = person.stream().filter((n) -> String.valueOf(n.getIsMain()).equals("1") && n.getXfTypeID().equals("001002")).collect(Collectors.toList()).size();
            personVO.setBehalfNum(String.valueOf(behalfNum));
            newperson.add(personVO);
        }
        map.put("newperson",newperson);
        return map;
    }

    @Override
    public LinkedList<Map>  excludeSXZJQX(MatterQuery matterQuery) {
        LinkedList<Map> maps = new LinkedList<>();
        List<MatterVO> matterVOS = matterMapper.selectSXZJQX(matterQuery);
        matterVOS = matterVOS.stream().collect(Collectors.collectingAndThen(Collectors.toCollection(() -> new TreeSet<>(Comparator.comparing(MatterVO :: getDid))), ArrayList::new));
       matterVOS.stream().collect(Collectors.groupingBy(MatterVO::getFinalDisposal))
               .entrySet().stream().forEach(p->{
            List<MatterVO> v = p.getValue();
            Map map = new HashMap();
            map.put("id", v.size() > 0 ? v.get(0).getFinalDisposalID() : 0);
            map.put("qxdw", p.getKey());
            map.put("jbzs", v.stream().filter(p1 -> "交办".equals(p1.getHandleModel()) || "转送".equals(p1.getHandleModel())).count());
            map.put("jb", (int) v.stream().filter(p1 -> "交办".equals(p1.getHandleModel())).count());
            map.put("zs", (int) v.stream().filter(p1 -> "转送".equals(p1.getHandleModel())).count());
            map.put("fkzs", (int) v.stream().filter(p1 -> "转送".equals(p1.getHandleModel()) && p1.getIsAccept() == 1).count());
            map.put("hbfk", v.stream().filter(p1 -> "交办".equals(p1.getHandleModel()) && "转送".equals(p1.getHandleModel()) && p1.getIsAccept() == 1).count());
            map.put("jbaqhb", (int) v.stream().filter(p1 -> "交办".equals(p1.getHandleModel()) && StringUtils.isNotEmpty(p1.getSolveCode()) && p1.getXcDay() >= 60).count());
            map.put("hbl", AhrdUitls.getZb((int) map.get("jbaqhb"), (int) map.get("jb")));
            map.put("zsaqhb", (int) v.stream().filter(p1 -> "转送".equals(p1.getHandleModel()) && StringUtils.isNotEmpty(p1.getSolveCode()) && p1.getXcDay() >= 60).count());
            map.put("fkl", AhrdUitls.getZb((int) map.get("zsaqhb"), (int) map.get("zs")));
            map.put("aqhb", (int) map.get("jbaqhb") + (int) map.get("zsaqhb"));
            map.put("hbfkl", AhrdUitls.getZb((int) map.get("aqhb"), (int) map.get("fkzs")));
            maps.add(map);
        });
        //排序规则
        if("1".equals(matterQuery.getOrderByType())){
            maps.sort((o1, o2) -> o1.get("id").toString().compareTo(o2.get("id").toString()));
        }else  {
            maps.sort((o1, o2) -> o2.get("jbzs").toString().compareTo(o1.get("jbzs").toString()));
        }
        return maps;
    }

    @Override
    public LinkedList<XfzbDTO> excludeXSJBZSQK(MatterQuery matterQuery) throws ParseException {
        LinkedList<XfzbDTO> maps = new LinkedList<>();
        List<MatterVO> list = matterMapper.selectSXZJQX(matterQuery);
        List<MatterVO> listJd = list.stream().filter(p -> StringUtils.isNotEmpty(p.getBusinessID()) && "17".equals(p.getBusinessID()))
                .sorted(Comparator.comparing(MatterVO::getHistoryTime).reversed())
                .collect(Collectors.collectingAndThen(Collectors.toCollection(() -> new TreeSet<>(Comparator.comparing(MatterVO :: getDid))), ArrayList::new));
       // List<MatterVO> collect = list.stream().filter(p -> p.getXcDay() > 60).collect(Collectors.toList());
        list = list.stream().collect(Collectors.collectingAndThen(Collectors.toCollection(() -> new TreeSet<>(Comparator.comparing(MatterVO :: getDid))), ArrayList::new));
        //List<MatterVO> collect2 = list.stream().filter(p -> p.getXcDay() > 60).collect(Collectors.toList());

        matterQuery.setCurrent();//当年时间
        List<MatterVO> allList = matterMapper.selectSXZJQX(matterQuery);
        List<MatterVO> allListJd = allList.stream().filter(p -> StringUtils.isNotEmpty(p.getBusinessID()) && "17".equals(p.getBusinessID()))
                .sorted(Comparator.comparing(MatterVO::getHistoryTime).reversed())
                .collect(Collectors.collectingAndThen(Collectors.toCollection(() -> new TreeSet<>(Comparator.comparing(MatterVO :: getDid))), ArrayList::new));
        allList = allList.stream().collect(Collectors.collectingAndThen(Collectors.toCollection(() -> new TreeSet<>(Comparator.comparing(MatterVO :: getDid))), ArrayList::new));

        matterQuery.setTime();//同比时间
        List<MatterVO> orgList = matterMapper.selectSXZJQX(matterQuery);
        List<MatterVO> orgListJd = orgList.stream().filter(p -> StringUtils.isNotEmpty(p.getBusinessID()) && "17".equals(p.getBusinessID()))
                .sorted(Comparator.comparing(MatterVO::getHistoryTime).reversed())
                .collect(Collectors.collectingAndThen(Collectors.toCollection(() -> new TreeSet<>(Comparator.comparing(MatterVO :: getDid))), ArrayList::new));
        orgList = orgList.stream().collect(Collectors.collectingAndThen(Collectors.toCollection(() -> new TreeSet<>(Comparator.comparing(MatterVO :: getDid))), ArrayList::new));

        matterQuery.setOrgCurrent();//历年时间
        List<MatterVO> orgAllList = matterMapper.selectSXZJQX(matterQuery);
        List<MatterVO> orgAllListJd = orgAllList.stream().filter(p -> StringUtils.isNotEmpty(p.getBusinessID()) && "17".equals(p.getBusinessID()))
                .sorted(Comparator.comparing(MatterVO::getHistoryTime).reversed())
                .collect(Collectors.collectingAndThen(Collectors.toCollection(() -> new TreeSet<>(Comparator.comparing(MatterVO :: getDid))), ArrayList::new));
        orgAllList = orgAllList.stream().collect(Collectors.collectingAndThen(Collectors.toCollection(() -> new TreeSet<>(Comparator.comparing(MatterVO :: getDid))), ArrayList::new));

        int a = list.size();
        int all = allList.size();
        int b = orgList.size();
        int bll = orgAllList.size();
        maps.add(new XfzbDTO(a+"",AhrdUitls.getPercent(a,b),AhrdUitls.getZb(a,a),all+"",AhrdUitls.getPercent(all,bll),AhrdUitls.getPercent(b,b)));

        //受理范围内（件批次）
        int a1 = AhrdUitls.getMatterIsAccept(list,0);
        int a2 = AhrdUitls.getMatterIsAccept(allList,0);
        int b1 = AhrdUitls.getMatterIsAccept(orgList,0);
        int b2 = AhrdUitls.getMatterIsAccept(orgAllList, 0);
        maps.add(new XfzbDTO(a1 + "", AhrdUitls.getPercent(a1, b1), AhrdUitls.getZb(a1, a), a2 + "", AhrdUitls.getPercent(a2, b2), AhrdUitls.getPercent(b1, b)));
        //受理范围内（件批次）
        a1 = AhrdUitls.getMatterIsAccept(list, 1);
        a2 = AhrdUitls.getMatterIsAccept(allList, 1);
        b1 = AhrdUitls.getMatterIsAccept(orgList, 1);
        b2 = AhrdUitls.getMatterIsAccept(orgAllList, 1);
        maps.add(new XfzbDTO(a1 + "", AhrdUitls.getPercent(a1, b1), AhrdUitls.getZb(a1, a), a2 + "", AhrdUitls.getPercent(a2, b2), AhrdUitls.getPercent(b1, b)));
        //受理数（件批次）
        a1 = (int) list.stream().filter(p -> "0".equals(p.getIsAcceptPerson())).count();
        a2 = (int) allList.stream().filter(p -> "0".equals(p.getIsAcceptPerson())).count();
        b1 = (int) orgList.stream().filter(p -> "0".equals(p.getIsAcceptPerson())).count();
        b2 = (int) orgAllList.stream().filter(p -> "0".equals(p.getIsAcceptPerson())).count();
        maps.add(new XfzbDTO(a1 + "", AhrdUitls.getPercent(a1, b1), AhrdUitls.getZb(a1, a), a2 + "", AhrdUitls.getPercent(a2, b2), AhrdUitls.getPercent(b1, b)));
        //交办数（件批次）
        a1 = AhrdUitls.getMatterHandleModel(list, "交办",null, null);
        a2 = AhrdUitls.getMatterHandleModel(allList, "交办",null,null);
        b1 = AhrdUitls.getMatterHandleModel(orgList, "交办",null,null);
        b2 = AhrdUitls.getMatterHandleModel(orgAllList, "交办",null,null);
        Integer jbs1 = new Integer(a1);
        Integer jbs2 = new Integer(a2);
        Integer jbs3 = new Integer(b1);
        Integer jbs4 = new Integer(b2);
        maps.add(new XfzbDTO(a1 + "", AhrdUitls.getPercent(a1, b1), AhrdUitls.getZb(a1, a), a2 + "", AhrdUitls.getPercent(a2, b2), AhrdUitls.getPercent(b1, b)));
        //转送数（件批次）
        a1 = AhrdUitls.getMatterHandleModel(list, "转送",null,null);
        a2 = AhrdUitls.getMatterHandleModel(allList, "转送",null,null);
        b1 = AhrdUitls.getMatterHandleModel(orgList, "转送",null,null);
        b2 = AhrdUitls.getMatterHandleModel(orgAllList, "转送",null,null);
        maps.add(new XfzbDTO(a1 + "", AhrdUitls.getPercent(a1, b1), AhrdUitls.getZb(a1, a), a2 + "", AhrdUitls.getPercent(a2, b2), AhrdUitls.getPercent(b1, b)));
        //需反馈的转送数1
        a1 = (int) list.stream().filter(p1 -> "转送".equals(p1.getHandleModel()) && p1.getIsAnswer() == 1).count();
        a2 = (int) allList.stream().filter(p1 -> "转送".equals(p1.getHandleModel()) && p1.getIsAnswer() == 1).count();
        b1 = (int) orgList.stream().filter(p1 -> "转送".equals(p1.getHandleModel()) && p1.getIsAnswer() == 1).count();
        b2 = (int) orgAllList.stream().filter(p1 -> "转送".equals(p1.getHandleModel()) && p1.getIsAnswer() == 1).count();
        Integer zss1 = new Integer(a1);
        Integer zss2 = new Integer(a2);
        Integer zss3 = new Integer(b1);
        Integer zss4 = new Integer(b2);
        maps.add(new XfzbDTO(a1 + "", AhrdUitls.getPercent(a1, b1), AhrdUitls.getZb(a1, a), a2 + "", AhrdUitls.getPercent(a2, b2), AhrdUitls.getPercent(b1, b)));

        //交办按期回报数（件批次）
        a1 = AhrdUitls.getMatterHandleModel(listJd, "交办",false,null);
        a2 = AhrdUitls.getMatterHandleModel(allListJd, "交办",false,null);
        b1 = AhrdUitls.getMatterHandleModel(orgListJd, "交办",false,null);
        b2 = AhrdUitls.getMatterHandleModel(orgAllListJd, "交办",false,null);
        maps.add(new XfzbDTO(a1 + "", AhrdUitls.getPercent(a1, b1), AhrdUitls.getZb(a1, a), a2 + "", AhrdUitls.getPercent(a2, b2), AhrdUitls.getPercent(b1, b)));
        //交办逾期未回报数（件批次）
        //a1 = AhrdUitls.getMatterHandleModel(listJd, "交办",true,null);
        //a2 = AhrdUitls.getMatterHandleModel(allListJd, "交办",true,null);
        //b1 = AhrdUitls.getMatterHandleModel(orgListJd, "交办",true,null);
        //b2 = AhrdUitls.getMatterHandleModel(orgAllListJd, "交办",true,null);
        a1 = jbs1 - a1;
        a2 = jbs2 - a2;
        b1 = jbs3 - b1;
        b2 = jbs4 - b2;
        maps.add(new XfzbDTO(a1 + "", AhrdUitls.getPercent(a1, b1), AhrdUitls.getZb(a1, a), a2 + "", AhrdUitls.getPercent(a2, b2), AhrdUitls.getPercent(b1, b)));
        //转送按期反馈数（件批次）2
        a1 = AhrdUitls.getMatterHandleModel(AhrdUitls.getIsAnswer(listJd), "转送",false,null);
        a2 = AhrdUitls.getMatterHandleModel(AhrdUitls.getIsAnswer(allListJd), "转送",false,null);
        b1 = AhrdUitls.getMatterHandleModel(AhrdUitls.getIsAnswer(orgListJd), "转送",false,null);
        b2 = AhrdUitls.getMatterHandleModel(AhrdUitls.getIsAnswer(orgAllListJd), "转送",false,null);
        maps.add(new XfzbDTO(a1 + "", AhrdUitls.getPercent(a1, b1), AhrdUitls.getZb(a1, a), a2 + "", AhrdUitls.getPercent(a2, b2), AhrdUitls.getPercent(b1, b)));
        //转送逾期未反馈数（件批次）
        //a1 = AhrdUitls.getMatterHandleModel(AhrdUitls.getIsAnswer(listJd), "转送",true,null);
        //a2 = AhrdUitls.getMatterHandleModel(AhrdUitls.getIsAnswer(allListJd), "转送",true,null);
        //b1 = AhrdUitls.getMatterHandleModel(AhrdUitls.getIsAnswer(orgListJd), "转送",true,null);
        //b2 = AhrdUitls.getMatterHandleModel(AhrdUitls.getIsAnswer(orgAllListJd), "转送",true,null);
        a1 = zss1 - a1;
        a2 = zss2 - a2;
        b1 = zss3 - b1;
        b2 = zss4 - b2;
        maps.add(new XfzbDTO(a1 + "", AhrdUitls.getPercent(a1, b1), AhrdUitls.getZb(a1, a), a2 + "", AhrdUitls.getPercent(a2, b2), AhrdUitls.getPercent(b1, b)));
        return maps;
    }

    @Override
    public LinkedList<XfzbDTO> excludeSJJBZSQK(MatterQuery matterQuery) throws ParseException {
        LinkedList<XfzbDTO> maps = new LinkedList<>();
        List<MatterVO> list = matterMapper.selectSJJBZSQK(matterQuery);
        list = list.stream().collect(Collectors.collectingAndThen(Collectors.toCollection(()-> new TreeSet<>(Comparator.comparing(MatterVO::getDid))),ArrayList::new));
        matterQuery.setCurrent();//当年时间
        List<MatterVO> allList = matterMapper.selectSXZJQX(matterQuery);
        allList = allList.stream().collect(Collectors.collectingAndThen(Collectors.toCollection(()-> new TreeSet<>(Comparator.comparing(MatterVO::getDid))),ArrayList::new));
        matterQuery.setTime();//同比时间
        List<MatterVO> orgList = matterMapper.selectSXZJQX(matterQuery);
        orgList = orgList.stream().collect(Collectors.collectingAndThen(Collectors.toCollection(()-> new TreeSet<>(Comparator.comparing(MatterVO::getDid))),ArrayList::new));
        matterQuery.setOrgCurrent();//历年时间
        List<MatterVO> orgAllList = matterMapper.selectSXZJQX(matterQuery);
        orgAllList = orgAllList.stream().collect(Collectors.collectingAndThen(Collectors.toCollection(()-> new TreeSet<>(Comparator.comparing(MatterVO::getDid))),ArrayList::new));
        int a = list.size();
        int all = allList.size();
        int b = orgList.size();
        int bll = orgAllList.size();
        //上级交办转送数
        maps.add(new XfzbDTO(a + "", AhrdUitls.getPercent(a, b), all + "", AhrdUitls.getPercent(all, bll)));
        //省级登记交办转送数
        a = AhrdUitls.getMatterHandleModel(list,"", null,"2");
        all = AhrdUitls.getMatterHandleModel(allList,"", null,"2");
        b = AhrdUitls.getMatterHandleModel(orgList,"", null,"2");
        bll = AhrdUitls.getMatterHandleModel(orgAllList,"", null,"2");
        maps.add(new XfzbDTO(a + "", AhrdUitls.getPercent(a, b), all + "", AhrdUitls.getPercent(all, bll)));
        //市级登记交办转送数
        a = AhrdUitls.getMatterHandleModel(list,"", null,"3");
        all = AhrdUitls.getMatterHandleModel(allList,"", null,"3");
        b = AhrdUitls.getMatterHandleModel(orgList,"", null,"3");
        bll = AhrdUitls.getMatterHandleModel(orgAllList,"", null,"3");
        maps.add(new XfzbDTO(a + "", AhrdUitls.getPercent(a, b), all + "", AhrdUitls.getPercent(all, bll)));
        //上级交办数
        a = AhrdUitls.getMatterHandleModel(list,"交办", null,null);
        all = AhrdUitls.getMatterHandleModel(allList,"交办", null,null);
        b = AhrdUitls.getMatterHandleModel(orgList,"交办", null,null);
        bll = AhrdUitls.getMatterHandleModel(orgAllList,"交办", null,null);
        maps.add(new XfzbDTO(a + "", AhrdUitls.getPercent(a, b), all + "", AhrdUitls.getPercent(all, bll)));
        //省级登记件交办数
        a = AhrdUitls.getMatterHandleModel(list,"交办", null,"2");
        all = AhrdUitls.getMatterHandleModel(allList,"交办", null,"2");
        b = AhrdUitls.getMatterHandleModel(orgList,"交办", null,"2");
        bll = AhrdUitls.getMatterHandleModel(orgAllList,"交办", null,"2");
        maps.add(new XfzbDTO(a + "", AhrdUitls.getPercent(a, b), all + "", AhrdUitls.getPercent(all, bll)));
        //市级登记件交办数
        a = AhrdUitls.getMatterHandleModel(list,"交办", null,"3");
        all = AhrdUitls.getMatterHandleModel(allList,"交办", null,"3");
        b = AhrdUitls.getMatterHandleModel(orgList,"交办", null,"3");
        bll = AhrdUitls.getMatterHandleModel(orgAllList,"交办", null,"3");
        maps.add(new XfzbDTO(a + "", AhrdUitls.getPercent(a, b), all + "", AhrdUitls.getPercent(all, bll)));
        //上级转送数
        a = AhrdUitls.getMatterHandleModel(list,"转送", null,null);
        all = AhrdUitls.getMatterHandleModel(allList,"转送", null,null);
        b = AhrdUitls.getMatterHandleModel(orgList,"转送", null,null);
        bll = AhrdUitls.getMatterHandleModel(orgAllList,"转送", null,null);
        maps.add(new XfzbDTO(a + "", AhrdUitls.getPercent(a, b), all + "", AhrdUitls.getPercent(all, bll)));
        //省级登记件转送数
        a = AhrdUitls.getMatterHandleModel(list,"转送", null,"2");
        all = AhrdUitls.getMatterHandleModel(allList,"转送", null,"2");
        b = AhrdUitls.getMatterHandleModel(orgList,"转送", null,"2");
        bll = AhrdUitls.getMatterHandleModel(orgAllList,"转送", null,"2");
        maps.add(new XfzbDTO(a + "", AhrdUitls.getPercent(a, b), all + "", AhrdUitls.getPercent(all, bll)));
        //市级登记件转送数
        a = AhrdUitls.getMatterHandleModel(list,"转送", null,"3");
        all = AhrdUitls.getMatterHandleModel(allList,"转送", null,"3");
        b = AhrdUitls.getMatterHandleModel(orgList,"转送", null,"3");
        bll = AhrdUitls.getMatterHandleModel(orgAllList,"转送", null,"3");
        maps.add(new XfzbDTO(a + "", AhrdUitls.getPercent(a, b), all + "", AhrdUitls.getPercent(all, bll)));
        //需反馈的上级转送数
        a = (int) list.stream().filter(p1 -> "转送".equals(p1.getHandleModel()) && p1.getIsAccept() == 1).count();
        all = (int) allList.stream().filter(p1 -> "转送".equals(p1.getHandleModel()) && p1.getIsAccept() == 1).count();
        b = (int) orgList.stream().filter(p1 -> "转送".equals(p1.getHandleModel()) && p1.getIsAccept() == 1).count();
        bll = (int) orgAllList.stream().filter(p1 -> "转送".equals(p1.getHandleModel()) && p1.getIsAccept() == 1).count();
        maps.add(new XfzbDTO(a + "", AhrdUitls.getPercent(a, b), all + "", AhrdUitls.getPercent(all, bll)));
        //需反馈的省级登记转送数
        a = (int) list.stream().filter(p1 -> "转送".equals(p1.getHandleModel()) && p1.getIsAccept() == 1 && "2".equals(p1.getType())).count();
        all = (int) allList.stream().filter(p1 -> "转送".equals(p1.getHandleModel()) && p1.getIsAccept() == 1 && "2".equals(p1.getType())).count();
        b = (int) orgList.stream().filter(p1 -> "转送".equals(p1.getHandleModel()) && p1.getIsAccept() == 1 && "2".equals(p1.getType())).count();
        bll = (int) orgAllList.stream().filter(p1 -> "转送".equals(p1.getHandleModel()) && p1.getIsAccept() == 1 && "2".equals(p1.getType())).count();
        maps.add(new XfzbDTO(a + "", AhrdUitls.getPercent(a, b), all + "", AhrdUitls.getPercent(all, bll)));
        //需反馈的市级登记转送数
        a = (int) list.stream().filter(p1 -> "转送".equals(p1.getHandleModel()) && p1.getIsAccept() == 1 && "3".equals(p1.getType())).count();
        all = (int) allList.stream().filter(p1 -> "转送".equals(p1.getHandleModel()) && p1.getIsAccept() == 1 && "3".equals(p1.getType())).count();
        b = (int) orgList.stream().filter(p1 -> "转送".equals(p1.getHandleModel()) && p1.getIsAccept() == 1 && "3".equals(p1.getType())).count();
        bll = (int) orgAllList.stream().filter(p1 -> "转送".equals(p1.getHandleModel()) && p1.getIsAccept() == 1 && "3".equals(p1.getType())).count();
        maps.add(new XfzbDTO(a + "", AhrdUitls.getPercent(a, b), all + "", AhrdUitls.getPercent(all, bll)));
        //上级交办转件已办结数
        a = (int) list.stream().filter(p -> "交办".equals(p.getHandleModel()) || "转送".equals(p.getHandleModel())).filter(p->"99".equals(p.getBusinessID())).count();
        all = (int) allList.stream().filter(p -> "交办".equals(p.getHandleModel()) || "转送".equals(p.getHandleModel())).filter(p->"99".equals(p.getBusinessID())).count();
        b = (int) orgList.stream().filter(p -> "交办".equals(p.getHandleModel()) || "转送".equals(p.getHandleModel())).filter(p->"99".equals(p.getBusinessID())).count();
        bll = (int) orgAllList.stream().filter(p -> "交办".equals(p.getHandleModel()) || "转送".equals(p.getHandleModel())).filter(p->"99".equals(p.getBusinessID())).count();
        maps.add(new XfzbDTO(a + "", AhrdUitls.getPercent(a, b), all + "", AhrdUitls.getPercent(all, bll)));
        //办结率（%）
        String bjl = AhrdUitls.getZb(a, list.size());
        String tb = AhrdUitls.getPercentTb(bjl,AhrdUitls.getZb(b, orgList.size()));
        String dnlj = AhrdUitls.getZb(bll, orgAllList.size());
        String orgTb = AhrdUitls.getPercentTb(AhrdUitls.getZb(all,allList.size()),dnlj);
        maps.add(new XfzbDTO(bjl, tb, dnlj, orgTb));
        //省级登记交办转送件已办结数
        a = (int) list.stream().filter(p -> "交办".equals(p.getHandleModel()) || "转送".equals(p.getHandleModel())).filter(p -> "99".equals(p.getBusinessID()) && "2".equals(p.getType())).count();
        all = (int) allList.stream().filter(p -> "交办".equals(p.getHandleModel()) || "转送".equals(p.getHandleModel())).filter(p->"99".equals(p.getBusinessID())&& "2".equals(p.getType())).count();
        b = (int) orgList.stream().filter(p -> "交办".equals(p.getHandleModel()) || "转送".equals(p.getHandleModel())).filter(p->"99".equals(p.getBusinessID()) && "2".equals(p.getType())).count();
        bll = (int) orgAllList.stream().filter(p -> "交办".equals(p.getHandleModel()) || "转送".equals(p.getHandleModel())).filter(p->"99".equals(p.getBusinessID()) && "2".equals(p.getType())).count();
        maps.add(new XfzbDTO(a + "", AhrdUitls.getPercent(a, b), all + "", AhrdUitls.getPercent(all, bll)));
        //办结率（%）
        bjl = AhrdUitls.getZb(a, AhrdUitls.getMatterHandleModel(list,null,null,"2"));
        tb = AhrdUitls.getPercentTb(bjl, AhrdUitls.getZb(b, AhrdUitls.getMatterHandleModel(orgList,null,null,"2")));
        dnlj = AhrdUitls.getZb(bll, AhrdUitls.getMatterHandleModel(orgAllList,null,null,"2"));
        orgTb = AhrdUitls.getPercentTb(AhrdUitls.getZb(bll, AhrdUitls.getMatterHandleModel(allList,null,null,"2")),dnlj);
        maps.add(new XfzbDTO(bjl, tb, dnlj, orgTb));
        // 市级登记交办转送件已办结数
        a = (int) list.stream().filter(p -> "交办".equals(p.getHandleModel()) || "转送".equals(p.getHandleModel())).filter(p -> "99".equals(p.getBusinessID()) && "3".equals(p.getType())).count();
        all = (int) allList.stream().filter(p -> "交办".equals(p.getHandleModel()) || "转送".equals(p.getHandleModel())).filter(p -> "99".equals(p.getBusinessID()) && "3".equals(p.getType())).count();
        b = (int) orgList.stream().filter(p -> "交办".equals(p.getHandleModel()) || "转送".equals(p.getHandleModel())).filter(p -> "99".equals(p.getBusinessID()) && "3".equals(p.getType())).count();
        bll = (int) orgAllList.stream().filter(p -> "交办".equals(p.getHandleModel()) || "转送".equals(p.getHandleModel())).filter(p -> "99".equals(p.getBusinessID()) && "3".equals(p.getType())).count();
        maps.add(new XfzbDTO(a + "", AhrdUitls.getPercent(a, b), all + "", AhrdUitls.getPercent(all, bll)));
        // 办结率（%）
        bjl = AhrdUitls.getZb(a, AhrdUitls.getMatterHandleModel(list, null, null, "3"));
        tb = AhrdUitls.getPercentTb(bjl, AhrdUitls.getZb(b, AhrdUitls.getMatterHandleModel(orgList, null, null, "3")));
        dnlj = AhrdUitls.getZb(bll, AhrdUitls.getMatterHandleModel(orgAllList, null, null, "3"));
        orgTb = AhrdUitls.getPercentTb(AhrdUitls.getZb(bll, AhrdUitls.getMatterHandleModel(allList, null, null, "3")), dnlj);
        maps.add(new XfzbDTO(bjl, tb, dnlj, orgTb));
        // 上级登记交办件已回报数
        a = (int) list.stream().filter(p -> "交办".equals(p.getHandleModel()) && p.getXcDay() <= 60).count();
        all = (int) allList.stream().filter(p -> "交办".equals(p.getHandleModel()) && p.getXcDay() <= 60).count();
        b = (int) orgList.stream().filter(p -> "交办".equals(p.getHandleModel()) && p.getXcDay() <= 60).count();
        bll = (int) orgAllList.stream().filter(p -> "交办".equals(p.getHandleModel()) && p.getXcDay() <= 60).count();
        maps.add(new XfzbDTO(a + "", AhrdUitls.getPercent(a, b), all + "", AhrdUitls.getPercent(all, bll)));
        // 回报率（%）
        bjl = AhrdUitls.getZb(a, AhrdUitls.getMatterHandleModel(list, "交办", null, null));
        tb = AhrdUitls.getPercentTb(bjl, AhrdUitls.getZb(b, AhrdUitls.getMatterHandleModel(orgList, "交办", null, null)));
        dnlj = AhrdUitls.getZb(bll, AhrdUitls.getMatterHandleModel(orgAllList, "交办", null, null));
        orgTb = AhrdUitls.getPercentTb(AhrdUitls.getZb(bll, AhrdUitls.getMatterHandleModel(allList, "交办", null, null)), dnlj);
        maps.add(new XfzbDTO(bjl, tb, dnlj, orgTb));
        // 省级登记交办件已回报数
        a = (int) list.stream().filter(p -> "交办".equals(p.getHandleModel()) && p.getXcDay() <= 60 && "2".equals(p.getType())).count();
        all = (int) allList.stream().filter(p -> "交办".equals(p.getHandleModel()) && p.getXcDay() <= 60 && "2".equals(p.getType())).count();
        b = (int) orgList.stream().filter(p -> "交办".equals(p.getHandleModel()) && p.getXcDay() <= 60 && "2".equals(p.getType())).count();
        bll = (int) orgAllList.stream().filter(p -> "交办".equals(p.getHandleModel()) && p.getXcDay() <= 60 && "2".equals(p.getType())).count();
        maps.add(new XfzbDTO(a + "", AhrdUitls.getPercent(a, b), all + "", AhrdUitls.getPercent(all, bll)));
        // 回报率（%）
        bjl = AhrdUitls.getZb(a, AhrdUitls.getMatterHandleModel(list, "交办", null, "2"));
        tb = AhrdUitls.getPercentTb(bjl, AhrdUitls.getZb(b, AhrdUitls.getMatterHandleModel(orgList, "交办", null, "2")));
        dnlj = AhrdUitls.getZb(bll, AhrdUitls.getMatterHandleModel(orgAllList, "交办", null, "2"));
        orgTb = AhrdUitls.getPercentTb(AhrdUitls.getZb(bll, AhrdUitls.getMatterHandleModel(allList, "交办", null, "2")), dnlj);
        maps.add(new XfzbDTO(bjl, tb, dnlj, orgTb));
        // 市级登记交办件已回报数
        a = (int) list.stream().filter(p -> "交办".equals(p.getHandleModel()) && p.getXcDay() <= 60 && "3".equals(p.getType())).count();
        all = (int) allList.stream().filter(p -> "交办".equals(p.getHandleModel()) && p.getXcDay() <= 60 && "3".equals(p.getType())).count();
        b = (int) orgList.stream().filter(p -> "交办".equals(p.getHandleModel()) && p.getXcDay() <= 60 && "3".equals(p.getType())).count();
        bll = (int) orgAllList.stream().filter(p -> "交办".equals(p.getHandleModel()) && p.getXcDay() <= 60 && "3".equals(p.getType())).count();
        maps.add(new XfzbDTO(a + "", AhrdUitls.getPercent(a, b), all + "", AhrdUitls.getPercent(all, bll)));
        // 回报率（%）
        bjl = AhrdUitls.getZb(a, AhrdUitls.getMatterHandleModel(list, "交办", null, "3"));
        tb = AhrdUitls.getPercentTb(bjl, AhrdUitls.getZb(b, AhrdUitls.getMatterHandleModel(orgList, "交办", null, "3")));
        dnlj = AhrdUitls.getZb(bll, AhrdUitls.getMatterHandleModel(orgAllList, "交办", null, "3"));
        orgTb = AhrdUitls.getPercentTb(AhrdUitls.getZb(bll, AhrdUitls.getMatterHandleModel(allList, "交办", null, "3")), dnlj);
        maps.add(new XfzbDTO(bjl, tb, dnlj, orgTb));
        //上级登记转送已反馈数
        a = (int) list.stream().filter(p -> "转送".equals(p.getHandleModel()) && p.getXcDay() <= 60).count();
        all = (int) allList.stream().filter(p -> "转送".equals(p.getHandleModel()) && p.getXcDay() <= 60).count();
        b = (int) orgList.stream().filter(p -> "转送".equals(p.getHandleModel()) && p.getXcDay() <= 60).count();
        bll = (int) orgAllList.stream().filter(p -> "转送".equals(p.getHandleModel()) && p.getXcDay() <= 60).count();
        maps.add(new XfzbDTO(a + "", AhrdUitls.getPercent(a, b), all + "", AhrdUitls.getPercent(all, bll)));
        //反馈率（%）
        bjl = AhrdUitls.getZb(a, AhrdUitls.getMatterHandleModel(list, "转送", null, null));
        tb = AhrdUitls.getPercentTb(bjl, AhrdUitls.getZb(b, AhrdUitls.getMatterHandleModel(orgList, "转送", null, null)));
        dnlj = AhrdUitls.getZb(bll, AhrdUitls.getMatterHandleModel(orgAllList, "转送", null, null));
        orgTb = AhrdUitls.getPercentTb(AhrdUitls.getZb(bll, AhrdUitls.getMatterHandleModel(allList, "转送", null, null)), dnlj);
        maps.add(new XfzbDTO(bjl, tb, dnlj, orgTb));
        //省级登记转送件已反馈数
        a = (int) list.stream().filter(p -> "转送".equals(p.getHandleModel()) && p.getXcDay() <= 60 && "2".equals(p.getType())).count();
        all = (int) allList.stream().filter(p -> "转送".equals(p.getHandleModel()) && p.getXcDay() <= 60 && "2".equals(p.getType())).count();
        b = (int) orgList.stream().filter(p -> "转送".equals(p.getHandleModel()) && p.getXcDay() <= 60 && "2".equals(p.getType())).count();
        bll = (int) orgAllList.stream().filter(p -> "转送".equals(p.getHandleModel()) && p.getXcDay() <= 60 && "2".equals(p.getType())).count();
        maps.add(new XfzbDTO(a + "", AhrdUitls.getPercent(a, b), all + "", AhrdUitls.getPercent(all, bll)));
        //反馈率（%）
        bjl = AhrdUitls.getZb(a, AhrdUitls.getMatterHandleModel(list, "转送", null, "2"));
        tb = AhrdUitls.getPercentTb(bjl, AhrdUitls.getZb(b, AhrdUitls.getMatterHandleModel(orgList, "转送", null, "2")));
        dnlj = AhrdUitls.getZb(bll, AhrdUitls.getMatterHandleModel(orgAllList, "转送", null, "2"));
        orgTb = AhrdUitls.getPercentTb(AhrdUitls.getZb(bll, AhrdUitls.getMatterHandleModel(allList, "转送", null, "2")), dnlj);
        maps.add(new XfzbDTO(bjl, tb, dnlj, orgTb));
        //市级登记转送件已反馈数
        a = (int) list.stream().filter(p -> "转送".equals(p.getHandleModel()) && p.getXcDay() <= 60 && "3".equals(p.getType())).count();
        all = (int) allList.stream().filter(p -> "转送".equals(p.getHandleModel()) && p.getXcDay() <= 60 && "3".equals(p.getType())).count();
        b = (int) orgList.stream().filter(p -> "转送".equals(p.getHandleModel()) && p.getXcDay() <= 60 && "3".equals(p.getType())).count();
        bll = (int) orgAllList.stream().filter(p -> "转送".equals(p.getHandleModel()) && p.getXcDay() <= 60 && "3".equals(p.getType())).count();
        maps.add(new XfzbDTO(a + "", AhrdUitls.getPercent(a, b), all + "", AhrdUitls.getPercent(all, bll)));
        //反馈率（%）
        bjl = AhrdUitls.getZb(a, AhrdUitls.getMatterHandleModel(list, "转送", null, "3"));
        tb = AhrdUitls.getPercentTb(bjl, AhrdUitls.getZb(b, AhrdUitls.getMatterHandleModel(orgList, "转送", null, "3")));
        dnlj = AhrdUitls.getZb(bll, AhrdUitls.getMatterHandleModel(orgAllList, "转送", null, "3"));
        orgTb = AhrdUitls.getPercentTb(AhrdUitls.getZb(bll, AhrdUitls.getMatterHandleModel(allList, "转送", null, "3")), dnlj);
        maps.add(new XfzbDTO(bjl, tb, dnlj, orgTb));

        return maps;
    }

    @Override
    public LinkedList<Map> excludeWTSD(MatterQuery matterQuery) {
         LinkedList<Map> res = new LinkedList<>();
        List<MatterVO> list = matterMapper.selectWTSD(matterQuery);
        matterQuery.setTime();
        List<MatterVO> orgList = matterMapper.selectWTSD(matterQuery);
        LinkedList<DeptVO> depts = deptService.selectDeptByOrgId(matterQuery.getOrgID().get(0));
        DeptVO curDept = depts.get(0);
        depts.add(curDept);//复制本级到最后
        for (int i = 1; i < depts.size()+2; i++) {
            Map map =new HashMap();
            String deptName = null ;
            List<MatterVO> aList ;
            List<MatterVO> bList ;
            if(i < depts.size()){
                DeptVO dept = depts.get(i);
                deptName = dept.getDeptName();
                aList = list.stream().filter(p -> StringUtils.isNotEmpty(p.getHappenRegionID()) && p.getHappenRegionID().indexOf(dept.getDictValue()) != -1).collect(Collectors.toList());
                bList = orgList.stream().filter(p -> StringUtils.isNotEmpty(p.getHappenRegionID()) && p.getHappenRegionID().indexOf(dept.getDictValue()) != -1).collect(Collectors.toList());
                map.put("xzqh",deptName);
                if(i == depts.size()-1 ){
                    map.put("xzqh","登记单位行政区化本级");
                }
                map.put("lfpc",aList.size());
                map.put("pctb", AhrdUitls.getPercent(aList.size(), bList.size()));
                map.put("lfrs",aList.stream().collect(Collectors.summingInt(MatterVO::getXfNumber)));
                map.put("rstb",AhrdUitls.getPercent((int) map.get("lfrs"),bList.stream().collect(Collectors.summingInt(MatterVO::getXfNumber))));
                map.put("cas", aList.size() - AhrdUitls.getChunAnSum(aList));
                map.put("catb",AhrdUitls.getPercent(aList.size() - AhrdUitls.getChunAnSum(aList),bList.size() - AhrdUitls.getChunAnSum(bList)));
                //问题属地
                map.put("hjsdpc",aList.stream().filter(p->StringUtils.isNotEmpty(p.getDomicileID()) && p.getDomicileID().indexOf(dept.getHjDictValue()) != -1).count());
                map.put("hjsdrs",aList.stream().filter(p->StringUtils.isNotEmpty(p.getDomicileID()) && p.getDomicileID().indexOf(dept.getHjDictValue()) != -1).collect(Collectors.summingInt(MatterVO::getXfNumber)));
                //问题属地外的本行政区划内
                map.put("hjfsdpc",aList.stream().filter(p-> StringUtils.isNotEmpty(p.getDomicileID()) && p.getDomicileID().indexOf(dept.getHjDictValue()) == -1 && p.getDomicileID().indexOf(curDept.getHjDictValue()) != -1).count());
                map.put("hjfsdrs",aList.stream().filter(p->StringUtils.isNotEmpty(p.getDomicileID()) && p.getDomicileID().indexOf(dept.getHjDictValue()) == -1 && p.getDomicileID().indexOf(curDept.getHjDictValue()) != -1).collect(Collectors.summingInt(MatterVO::getXfNumber)));
                //本行政区划外
                map.put("hjqwpc",aList.stream().filter(p->StringUtils.isNotEmpty(p.getDomicileID()) && p.getDomicileID().indexOf(curDept.getHjDictValue()) == -1).count());
                map.put("hjqwrs",aList.stream().filter(p->StringUtils.isNotEmpty(p.getDomicileID()) && p.getDomicileID().indexOf(curDept.getHjDictValue()) == -1).collect(Collectors.summingInt(MatterVO::getXfNumber)));
            }else {
                //本级外 、 境外
                DeptVO dept = curDept;
                if(i == depts.size() ){
                    aList = list.stream().filter(p -> StringUtils.isNotEmpty(p.getHappenRegionID()) && p.getHappenRegionID().indexOf(curDept.getDictValue()) == -1).collect(Collectors.toList());
                    bList = orgList.stream().filter(p -> StringUtils.isNotEmpty(p.getHappenRegionID()) && p.getHappenRegionID().indexOf(curDept.getDictValue()) == -1).collect(Collectors.toList());
                    map.put("xzqh","登记单位行政区域外");
                }else {
                    //境外数据为空
                    aList = new ArrayList<>();
                    bList = new ArrayList<>();
                    map.put("xzqh","境外");
                }
                map.put("lfpc",aList.size());
                map.put("pctb", AhrdUitls.getPercent(aList.size(), bList.size()));
                map.put("lfrs",aList.stream().collect(Collectors.summingInt(MatterVO::getXfNumber)));
                map.put("rstb",AhrdUitls.getPercent((int) map.get("lfrs"),bList.stream().collect(Collectors.summingInt(MatterVO::getXfNumber))));
                map.put("cas", aList.size() - AhrdUitls.getChunAnSum(aList));
                map.put("catb",AhrdUitls.getPercent(aList.size() - AhrdUitls.getChunAnSum(aList),bList.size() - AhrdUitls.getChunAnSum(bList)));
                //问题属地
                map.put("hjsdpc",aList.stream().filter(p->StringUtils.isNotEmpty(p.getDomicileID()) && p.getDomicileID().indexOf(dept.getHjDictValue()) != -1).count());
                map.put("hjsdrs",aList.stream().filter(p-> StringUtils.isNotEmpty(p.getDomicileID()) && p.getDomicileID().indexOf(dept.getHjDictValue()) != -1).collect(Collectors.summingInt(MatterVO::getXfNumber)));
                //问题属地外的本行政区划内
                map.put("hjfsdpc",aList.stream().filter(p->StringUtils.isNotEmpty(p.getDomicileID()) && p.getDomicileID().indexOf(dept.getHjDictValue()) == -1 && p.getDomicileID().indexOf(curDept.getHjDictValue()) != -1).count());
                map.put("hjfsdrs",aList.stream().filter(p->StringUtils.isNotEmpty(p.getDomicileID()) && p.getDomicileID().indexOf(dept.getHjDictValue()) == -1 && p.getDomicileID().indexOf(curDept.getHjDictValue()) != -1).collect(Collectors.summingInt(MatterVO::getXfNumber)));
                //本行政区划外
                map.put("hjqwpc",aList.stream().filter(p->StringUtils.isNotEmpty(p.getDomicileID()) && p.getDomicileID().indexOf(curDept.getHjDictValue()) == -1).count());
                map.put("hjqwrs",aList.stream().filter(p->StringUtils.isNotEmpty(p.getDomicileID()) && p.getDomicileID().indexOf(curDept.getHjDictValue()) == -1).collect(Collectors.summingInt(MatterVO::getXfNumber)));
            }

            //境外
            map.put("jwpc", aList.stream().filter(p -> StringUtils.isNotEmpty(p.getNationalityID()) && !"134044".equals(p.getNationalityID()) && !"134045".equals(p.getNationalityID())
                    && !"134046".equals(p.getNationalityID()) && !"134047".equals(p.getNationalityID())).count());
            map.put("jwrs", aList.stream().filter(p -> StringUtils.isNotEmpty(p.getNationalityID()) && !"134044".equals(p.getNationalityID()) && !"134045".equals(p.getNationalityID())
                    && !"134046".equals(p.getNationalityID()) && !"134047".equals(p.getNationalityID())).collect(Collectors.summingInt(MatterVO::getXfNumber)));
            //未标明
            if(i > depts.size() ){
                map.put("wbm","0");
            }else {
                System.out.println("======="+ deptName);
                map.put("wbm",aList.stream().filter(p->p.getSum1()< p.getXfNumber() || StringUtils.isEmpty(p.getDomicileID())).count());
            }

            map.put("wbmrs", (int) map.get("lfrs") - (int) map.get("hjsdrs") - (int) map.get("hjfsdrs") - (int) map.get("hjqwrs") - (int) map.get("jwrs"));
            res.add(map);
        }
        return res;
    }


    @Override
    public List<ActivityDTO> selectRepeatXf(MatterQuery matterQuery) {
        return matterMapper.selectRepeatXf(matterQuery);
    }

    @Override
    public List<ActivityDTO> excludeExcelLeader(MatterQuery matterQuery) {
        return matterMapper.selectLeader(matterQuery);
    }

    @Override
    public List<ActivityDTO> excludeExcelCollectiveResponse(MatterQuery matterQuery) {
        return matterMapper.excludeExcelCollectiveResponse(matterQuery);
    }
}
