package com.dlsm.utils;


import lombok.SneakyThrows;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.Date;
import java.util.HashMap;
import java.util.Map;
import java.util.*;

public class DateTimeUtils {
    public static String YYYYMMDD = "yyyyMMdd";
    public static  SimpleDateFormat format = new SimpleDateFormat("yyyy-MM-dd");
    public static  SimpleDateFormat formatYear = new SimpleDateFormat("yyyy");
    public static  SimpleDateFormat formatHMS = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");



    public static final String getYYYYMMDD(final Date date)
    {
        return parseDateToStr(YYYYMMDD, date);
    }

    public static final String parseDateToStr(final String format, final Date date)
    {
        return new SimpleDateFormat(format).format(date);
    }


    /**
     * 默认日期格式
     */
    public static String DEFAULT_FORMAT = "yyyy-MM-dd";

    /**
     * 格式化日期
     * @param date 日期对象
     * @return String 日期字符串
     */
    public static String formatDate(Date date){
        SimpleDateFormat f = new SimpleDateFormat(DEFAULT_FORMAT);
        String sDate = f.format(date);
        return sDate;
    }

    /**
     * 获取当年的第一天
     */
    public static Date getCurrYearFirst(){
        Calendar currCal=Calendar.getInstance();
        int currentYear = currCal.get(Calendar.YEAR);
        return getYearFirst(currentYear);
    }

    /**
     * 获取当年的最后一天
     */
    public static Date getCurrYearLast() throws ParseException {
        Calendar currCal=Calendar.getInstance();
        int currentYear = currCal.get(Calendar.YEAR);
        Date date = getYearLast(currentYear);
        SimpleDateFormat  f = new SimpleDateFormat("yyyy-MM-dd 23:59:59");
        String time = f.format(date);
        SimpleDateFormat format = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        Date dateTime = format.parse(time);
        return dateTime;
    }

    /**
     * 获取某年第一天日期
     */
    public static Date getYearFirst(Integer year){
        Calendar calendar = Calendar.getInstance();
        calendar.clear();
        calendar.set(Calendar.YEAR, year);
        Date currYearFirst = calendar.getTime();

        return currYearFirst;
    }

    /**
     * 获取某年最后一天日期
     */
    public static Date getYearLast(Integer year) {
        Calendar calendar = Calendar.getInstance();
        calendar.clear();
        calendar.set(Calendar.YEAR, year);
        calendar.roll(Calendar.DAY_OF_YEAR, -1);
        Date currYearLast = calendar.getTime();
        SimpleDateFormat  f = new SimpleDateFormat("yyyy-MM-dd 23:59:59");
        String time = f.format(currYearLast);
        SimpleDateFormat format = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        Date dateTime = new Date();
        try {
            dateTime = format.parse(time);
        } catch (ParseException e) {
            e.printStackTrace();
        }
        return dateTime;
    }

    /**
     * 获取年份
     */
    public static String getYear(Date date){
        Calendar calendar = Calendar.getInstance();
        calendar.clear();
        calendar.setTime(date);
        String year = String.valueOf(calendar.get(Calendar.YEAR));

        return year;
    }

    /**
     * 获取月份
     */
    public static String getMonth(Date date){
        Calendar calendar = Calendar.getInstance();
        calendar.clear();
        calendar.setTime(date);
        String month = String.valueOf(calendar.get(Calendar.MONTH) + 1);

        return month;
    }

    /**
     * 获取日
     */
    public static String getDay(Date date){
        Calendar calendar = Calendar.getInstance();
        calendar.clear();
        calendar.setTime(date);
        String day = String.valueOf(calendar.get(Calendar.DAY_OF_MONTH));

        return day;
    }

    /**
     * 获取去年开始时间
     * @return
     */
    public static String getOrgStartTime(){
        return formatDate(getStartHBTime(getCurrYearFirst()));
    }

    /**
     * 获取去年结束时间
     * @return
     */
    public static String getOrgEndTime() throws ParseException {
        return formatDate(getStartHBTime(getCurrYearLast()));
    }

    /**
     * 获取同比开始时间
     */
    public static Date getStartHBTime(Date time){
        String sTime = formatHMS.format(time);
        String oldYear = String.valueOf(Integer.valueOf(sTime.substring(0,4)));
        String year = String.valueOf(Integer.valueOf(sTime.substring(0,4)) - 1);

        Date HBTime = null;
        try {
            HBTime = formatHMS.parse(sTime.replace(oldYear,year));
        } catch (ParseException e) {
            e.printStackTrace();
        }

        return HBTime;
    }

     //设置当天时间给  时分秒 23  59  59
    public static Date getTodayTime(Date time) throws ParseException {

        Calendar endCalendar = Calendar.getInstance();
        endCalendar.setTime(time);
        endCalendar.set(Calendar.HOUR_OF_DAY, 23);
        endCalendar.set(Calendar.MINUTE, 59);
        endCalendar.set(Calendar.SECOND, 59);
        Date eTime = endCalendar.getTime();
        String format = formatHMS.format(eTime);
        Date parse = formatHMS.parse(format);

        return parse;
    }

    /**
     * 获取同比结束时间
     */
    public static Date getEndHBTime(Date time) throws ParseException {
        Calendar endCalendar = Calendar.getInstance();
        endCalendar.setTime(time);
        endCalendar.set(Calendar.HOUR_OF_DAY, 23);
        endCalendar.set(Calendar.MINUTE, 59);
        endCalendar.set(Calendar.SECOND, 59);
        Date eTime = endCalendar.getTime();
        String sTime = formatHMS.format(eTime);
        String oldYear = String.valueOf(Integer.valueOf(sTime.substring(0,4)));
        String year = String.valueOf(Integer.valueOf(sTime.substring(0,4)) - 1);

        Date HBTime = null;
        try {
            HBTime = formatHMS.parse(sTime.replace(oldYear,year));
        } catch (ParseException e) {
            e.printStackTrace();
        }

        return HBTime;
    }

    /**
     * 获取环比开始时间与结束时间
     */
    public static Map<String,Date> getTBTime(Date startTime,Date endTime) throws ParseException {
        Map<String,Date> map = new HashMap();
        Calendar startCalendar = Calendar.getInstance();
        startCalendar.setTime(startTime);
        Calendar endCalendar = Calendar.getInstance();
        endCalendar.setTime(endTime);
        int days = differentDays(startTime, endTime);
        startCalendar.add(Calendar.DATE,-days);
        endCalendar.add(Calendar.DATE,-days);

        endCalendar.set(Calendar.HOUR_OF_DAY, 23);
        endCalendar.set(Calendar.MINUTE, 59);
        endCalendar.set(Calendar.SECOND, 59);

        Date sTime = startCalendar.getTime();
        String st= format.format(sTime);
        Date eTime = endCalendar.getTime();
        String et= format.format(eTime);

        map.put("startTBTime",format.parse(st));
        map.put("endTBTime",format.parse(et));

        return map;
    }

    /**
     * 获取上一年同月的第一天
     *
     * @return
     */
    @SneakyThrows
    public static Date getYearFirstDay() {
        Calendar calendar = Calendar.getInstance();
        calendar.setTime(new Date());
        calendar.set(Calendar.DAY_OF_MONTH, 1);
        calendar.add(Calendar.MONTH, 0);
        calendar.add(Calendar.YEAR, -1);
        Date time = calendar.getTime();
        String formattime = format.format(time);
        return format.parse(formattime);
    }

    /**
     * 获取上一年同月最后一天
     *
     * @return
     */
    @SneakyThrows
    public static Date getYearLastDay() {
        Calendar calendar = Calendar.getInstance();
        calendar.setTime(new Date());
        calendar.set(calendar.DAY_OF_MONTH,calendar.getActualMaximum(calendar.DAY_OF_MONTH));
        calendar.add(Calendar.YEAR, -1);
        calendar.set(Calendar.HOUR_OF_DAY, 23);
        calendar.set(Calendar.MINUTE, 59);
        calendar.set(Calendar.SECOND, 59);
        Date time = calendar.getTime();
        String format = formatHMS.format(time);
        return  formatHMS.parse(format);
    }

    /**
     * 获取前月的第一天 ：1号
     *
     * @return
     */
    @SneakyThrows
    public static Date getLatMonthFirstDay() {
        Calendar calendar = Calendar.getInstance();
        calendar.setTime(new Date());
        calendar.set(Calendar.DAY_OF_MONTH, 1);
        calendar.add(Calendar.MONTH, -1);
        Date time = calendar.getTime();
        String formattime = format.format(time);
        return format.parse(formattime);
    }

    /**
     * 获取前月的最后一天
     *
     * @return
     */
    @SneakyThrows
    public static Date getLastMonthLastDay() {
        Calendar calendar = Calendar.getInstance();
        calendar.setTime(new Date());
        calendar.set(calendar.DAY_OF_MONTH,calendar.getActualMaximum(calendar.DAY_OF_MONTH));
        calendar.add(Calendar.MONTH, -1);
        calendar.set(Calendar.HOUR_OF_DAY, 23);
        calendar.set(Calendar.MINUTE, 59);
        calendar.set(Calendar.SECOND, 59);
        Date time = calendar.getTime();
        String format = formatHMS.format(time);
        return  formatHMS.parse(format);
    }

    /**
     *  获取时间   年  月  日
     */
    public static Map<String, String> getTimeYearMonthDay(Date date) {
        Map<String, String> map = new HashMap<>();
        Calendar cal = Calendar.getInstance();
        cal.setTime(date);
        int yearint = cal.get(Calendar.YEAR);//获取年份
        String year = String.valueOf(yearint);
        cal.add(Calendar.MONTH, 1);
        int monthint = cal.get(Calendar.MONTH);//获取月份
        String month = String.valueOf(monthint);
        int dayint = cal.get(Calendar.DATE);//获取月份
        String day = String.valueOf(dayint);
        map.put("year", year);
        map.put("month", month);
        map.put("day", day);
        return map;
    }

    /**
     *  获取时间两个时间相差天数
     */
    public static int differentDays(Date date1,Date date2){
        Calendar cal1 = Calendar.getInstance();
        cal1.setTime(date1);

        Calendar cal2 = Calendar.getInstance();
        cal2.setTime(date2);
        int day1= cal1.get(Calendar.DAY_OF_YEAR);
        int day2 = cal2.get(Calendar.DAY_OF_YEAR);

        int year1 = cal1.get(Calendar.YEAR);
        int year2 = cal2.get(Calendar.YEAR);
        if(year1 != year2) {
            int timeDistance = 0 ;
            for(int i = year1 ; i < year2 ; i ++) {
                if(i%4==0 && i%100!=0 || i%400==0) {   //闰年
                    timeDistance += 366;
                }
                else {   //不是闰年
                    timeDistance += 365;
                }
            }
            return timeDistance + (day2-day1) ;
        } else {
            return day2-day1;
        }
    }

    /**
     *  获取每个月的第一天
     */
    public static Date getMonthDay(int year,int month) {
        Calendar cal = Calendar.getInstance();
        //设置年份
        cal.set(Calendar.YEAR,year);
        //设置月份
        cal.set(Calendar.MONTH, month-1);
        //获取某月最小天数
        int firstDay = cal.getActualMinimum(Calendar.DAY_OF_MONTH);
        //设置日历中月份的最小天数
        cal.set(Calendar.DAY_OF_MONTH, firstDay);
        String firstDayOfMonth = formatHMS.format(cal.getTime());
        Date date = new Date();
        try {
            date = formatHMS.parse(firstDayOfMonth);
        } catch (ParseException e) {
            e.printStackTrace();
        }
        return date;
    }

    //时间格式处理为 为年月日
    @SneakyThrows
    public static String getDayMonthYear(Date date) {
        Calendar calendar = Calendar.getInstance();
        calendar.setTime(date);
        Date time = calendar.getTime();
        String formattime = format.format(time);
        return formattime;
    }
}
