package com.dlsm.utils;

import com.alibaba.excel.EasyExcel;
import com.alibaba.excel.ExcelWriter;
import com.alibaba.excel.util.ListUtils;
import com.alibaba.excel.write.handler.WriteHandler;
import com.alibaba.excel.write.metadata.WriteSheet;
import com.alibaba.excel.write.metadata.WriteWorkbook;
import com.alibaba.excel.write.metadata.style.WriteCellStyle;
import com.alibaba.excel.write.metadata.style.WriteFont;
import com.alibaba.excel.write.style.HorizontalCellStyleStrategy;
import com.dlsm.model.export.ActivityDTO;
import com.dlsm.utils.excel.ExcelFillCellMergeStrategy;
import org.apache.poi.ss.usermodel.BorderStyle;
import org.apache.poi.ss.usermodel.HorizontalAlignment;
import org.apache.poi.ss.usermodel.IndexedColors;
import org.apache.poi.ss.usermodel.VerticalAlignment;
import org.springframework.core.io.ClassPathResource;

import javax.servlet.http.HttpServletResponse;
import java.io.*;
import java.util.*;

/**
 * Created with IntelliJ IDEA.
 *
 * @Author: dzy
 * @Date: 2022/03/23/10:18
 * @Description:
 */
public class ExcelUtil {


    /**
     * 根据模版导出
     */
    public static void excludeTepm(HttpServletResponse response,String templateName,List list){

        ExcelWriter excelWriter = null;
        try {
            response.addHeader("Content-Disposition", "attachment;filename=" + System.currentTimeMillis() + ".xlsx");
            response.setContentType("multipart/form-data");
            InputStream inputStream = new ClassPathResource("/static/temp/excel/"+ templateName + ".xlsx").getInputStream();
            excelWriter = EasyExcel.write(response.getOutputStream()).withTemplate(inputStream).build();
            WriteSheet writeSheet = EasyExcel.writerSheet().build();
            excelWriter.fill(list, writeSheet);
        } catch (Exception e) {
            e.printStackTrace();
        }finally {
            // 关闭流
            if (excelWriter != null) {
                excelWriter.finish();
            }
        }
    }

    /**
     * 导出 导出时间，导出单位
     * @param response
     * @param templateName
     * @param list
     * @param orgName
     */
    public static void excludeTepm(HttpServletResponse response,String templateName,List list,String orgName){
        ExcelWriter excelWriter = null;
        try {
            response.addHeader("Content-Disposition", "attachment;filename=" + System.currentTimeMillis() + ".xlsx");
            response.setContentType("multipart/form-data");
            InputStream inputStream = new ClassPathResource("/static/temp/excel/"+ templateName + ".xlsx").getInputStream();
            excelWriter = EasyExcel.write(response.getOutputStream()).withTemplate(inputStream).build();
            WriteSheet writeSheet = EasyExcel.writerSheet().build();
            excelWriter.fill(list, writeSheet);
            Map<String,Object> map=new HashMap<>();
            map.put("printTime",DateTimeUtils.formatDate(new Date()));
            map.put("orgName",orgName);
            excelWriter.fill(map,writeSheet);
        } catch (Exception e) {
            e.printStackTrace();
        }finally {
            // 关闭流
            if (excelWriter != null) {
                excelWriter.finish();
            }
        }
    }

    /**
     * 本地导出，打印时间，打印单位
     * @param response
     * @param templateName
     * @param list
     * @param orgName
     */
    public static void excludeTepmToLocal(HttpServletResponse response,String templateName,List list,String orgName){
        ExcelWriter excelWriter = null;
        try {
            response.addHeader("Content-Disposition", "attachment;filename=" + System.currentTimeMillis() + ".xlsx");
            response.setContentType("multipart/form-data");
            InputStream inputStream = new ClassPathResource("/static/temp/excel/"+ templateName + ".xlsx").getInputStream();
            String fileName = templateName + System.currentTimeMillis() + ".xlsx";
            String filePath = TestFileUtil.getPath() ;
            excelWriter = EasyExcel.write(filePath + fileName).withTemplate(inputStream).build();
            WriteSheet writeSheet = EasyExcel.writerSheet().build();
            excelWriter.fill(list, writeSheet);
            Map<String,Object> map=new HashMap<>();
            map.put("printTime",DateTimeUtils.formatDate(new Date()));
            map.put("orgName",orgName);
            excelWriter.fill(map,writeSheet);
        } catch (Exception e) {
            e.printStackTrace();
        }finally {
            // 关闭流
            if (excelWriter != null) {
                excelWriter.finish();
            }
        }
    }

    /**
     * 根据模版导出到本地
     */
    public static void excludeTepmToLocal(HttpServletResponse response,String templateName,List list){
        ExcelWriter excelWriter = null;
        try {
            response.addHeader("Content-Disposition", "attachment;filename=" + System.currentTimeMillis() + ".xlsx");
            response.setContentType("multipart/form-data");
            InputStream inputStream = new ClassPathResource("/static/temp/excel/"+ templateName + ".xlsx").getInputStream();
            String fileName = templateName + System.currentTimeMillis() + ".xlsx";
            String filePath = TestFileUtil.getPath() ;
            excelWriter = EasyExcel.write(filePath + fileName).withTemplate(inputStream).build();
            WriteSheet writeSheet = EasyExcel.writerSheet().build();
            excelWriter.fill(list, writeSheet);
        } catch (Exception e) {
            e.printStackTrace();
        }finally {
            // 关闭流
            if (excelWriter != null) {
                excelWriter.finish();
            }
        }
    }

    /**
     *
     * @param list  导出数据集
     * @param T     导出类型
     * @param merge 需要合并列名
     * @param alone 不需要合并列名
     */
    public static void excludeOrIncludeWrite(HttpServletResponse response,List<?> list, Class T, List merge, List alone) {
        String fileName = TestFileUtil.getPath() + "excludeOrIncludeWrite" + System.currentTimeMillis() + ".xlsx";
        //非空处理
        merge = merge == null ? new ArrayList<>() : merge;
        alone = alone == null ? new ArrayList<>() : alone;

        response.addHeader("Content-Disposition", "attachment;filename=" + System.currentTimeMillis() + ".xlsx");
        response.setContentType("multipart/form-data");
        //样式设置
        HorizontalCellStyleStrategy horizontalCellStyleStrategy = getExcelStyle();
        //需要被合并的列
        List<Integer> mergeColumnIndex = new ArrayList<>();
        for (int i = 0; i < merge.size(); i++) {
            mergeColumnIndex.add(i);
        }
        // 导出项：includeColumnFiledNames
        Set<String> includeColumnFiledNames = new HashSet<String>();
        includeColumnFiledNames.add("number");
        includeColumnFiledNames.addAll(merge);
        includeColumnFiledNames.addAll(alone);
        // 排除项excludeColumnFiledNames
        Set<String> excludeColumnFiledNames = new HashSet<String>();
        excludeColumnFiledNames.add("id");
        ExcelWriter excelWriter = null;
        try {
            WriteWorkbook writeWorkbook = new WriteWorkbook();
            writeWorkbook.setOutputStream(response.getOutputStream());
            writeWorkbook.setClazz(T);
            // writeWorkbook.setHead(head(ratingYear+"年"+material.getDeptName()+"评价总体情况分析表"));
            //导出项字段
            if(includeColumnFiledNames.size() > 1){
                writeWorkbook.setIncludeColumnFieldNames(includeColumnFiledNames);
            }
            //排除项
             writeWorkbook.setExcludeColumnFieldNames(excludeColumnFiledNames);
            //是否自动关闭输入流
            writeWorkbook.setAutoCloseStream(Boolean.TRUE);
            //自定义拦截器，设置头部样式
            List<WriteHandler> customWriteHandlerList = new ArrayList<>();
            customWriteHandlerList.add(horizontalCellStyleStrategy);
            customWriteHandlerList.add(new ExcelFillCellMergeStrategy(1, mergeColumnIndex));
            writeWorkbook.setCustomWriteHandlerList(customWriteHandlerList);
            excelWriter = new ExcelWriter(writeWorkbook);
            WriteSheet writeSheet = new WriteSheet();
            writeSheet.setSheetName("sheet");
            excelWriter.write(list, writeSheet);
        } catch (IOException e) {
            e.printStackTrace();
        } finally {
            // 千万别忘记finish 会帮忙关闭流
            if (excelWriter != null) {
                excelWriter.finish();
            }
        }
        // 这里 需要指定写用哪个class去写，然后写到第一个sheet，名字为模板 然后文件流会自动关闭
        /*EasyExcel.write(fileName, ActivityDTO.class)
                .excludeColumnFiledNames(includeColumnFiledNames)
                .registerWriteHandler(new ExcelFillCellMergeStrategy(1,mergeColumnIndex))
                .registerWriteHandler(horizontalCellStyleStrategy)
                .sheet("sheet")
                .doWrite(data());*/
    }

    public static void excludeOrIncludeWrite3(HttpServletResponse response,List<?> list, Class T, List merge, List alone,String fileName,String orgName) {
//        String fileNamePath = TestFileUtil.getPath() + "excludeOrIncludeWrite" + System.currentTimeMillis() + ".xlsx";
        //非空处理
        merge = merge == null ? new ArrayList<>() : merge;
        alone = alone == null ? new ArrayList<>() : alone;

        response.addHeader("Content-Disposition", "attachment;filename=" + System.currentTimeMillis() + ".xlsx");
        response.setContentType("multipart/form-data");
        //样式设置
        HorizontalCellStyleStrategy horizontalCellStyleStrategy = getExcelStyle1();
        //需要被合并的列
        List<Integer> mergeColumnIndex = new ArrayList<>();
        for (int i = 0; i < merge.size(); i++) {
            mergeColumnIndex.add(i);
        }
        // 导出项：includeColumnFiledNames
        Set<String> includeColumnFiledNames = new HashSet<String>();
        includeColumnFiledNames.add("number");
        includeColumnFiledNames.addAll(merge);
        includeColumnFiledNames.addAll(alone);
        // 排除项excludeColumnFiledNames
        Set<String> excludeColumnFiledNames = new HashSet<String>();
        excludeColumnFiledNames.add("id");
        ExcelWriter excelWriter = null;
        try {
            String dyTime = DateTimeUtils.getDayMonthYear(new Date());
            ByteArrayOutputStream outputStream = (ByteArrayOutputStream) getInputStream(orgName,dyTime,fileName);
            ByteArrayInputStream swapStream = new ByteArrayInputStream(outputStream.toByteArray());
            WriteWorkbook writeWorkbook = new WriteWorkbook();
            writeWorkbook.setOutputStream(response.getOutputStream());
//            writeWorkbook.setFile(new File(fileNamePath));
            writeWorkbook.setClazz(T);
            writeWorkbook.setTemplateInputStream(swapStream);
            // writeWorkbook.setHead(head(ratingYear+"年"+material.getDeptName()+"评价总体情况分析表"));
            //导出项字段
            if(includeColumnFiledNames.size() > 1){
                writeWorkbook.setIncludeColumnFieldNames(includeColumnFiledNames);
            }
            //排除项
            writeWorkbook.setExcludeColumnFieldNames(excludeColumnFiledNames);
            //是否自动关闭输入流
            writeWorkbook.setAutoCloseStream(Boolean.TRUE);
            //自定义拦截器，设置头部样式
            List<WriteHandler> customWriteHandlerList = new ArrayList<>();
            customWriteHandlerList.add(horizontalCellStyleStrategy);
            customWriteHandlerList.add(new ExcelFillCellMergeStrategy(1, mergeColumnIndex));
            writeWorkbook.setCustomWriteHandlerList(customWriteHandlerList);
            excelWriter = new ExcelWriter(writeWorkbook);
            WriteSheet writeSheet = new WriteSheet();
            writeSheet.setSheetName("sheet");
            excelWriter.write(list, writeSheet);
        } catch (IOException e) {
            e.printStackTrace();
        } finally {
            // 千万别忘记finish 会帮忙关闭流
            if (excelWriter != null) {
                excelWriter.finish();
            }
        }
    }


    public static void excludeOrIncludeWriteLoacl(HttpServletResponse response,List<?> list, Class T, List merge, List alone) {
        String fileName = TestFileUtil.getPath() + "excludeOrIncludeWrite" + System.currentTimeMillis() + ".xlsx";
        //非空处理
        merge = merge == null ? new ArrayList<>() : merge;
        alone = alone == null ? new ArrayList<>() : alone;

        //response.addHeader("Content-Disposition", "attachment;filename=" + System.currentTimeMillis() + ".xlsx");
        //response.setContentType("multipart/form-data");
        //样式设置
        HorizontalCellStyleStrategy horizontalCellStyleStrategy = getExcelStyle();
        //需要被合并的列
        List<Integer> mergeColumnIndex = new ArrayList<>();
        for (int i = 0; i < merge.size(); i++) {
            mergeColumnIndex.add(i);
        }
        // 导出项：includeColumnFiledNames
        Set<String> includeColumnFiledNames = new HashSet<String>();
        includeColumnFiledNames.add("number");
        includeColumnFiledNames.addAll(merge);
        includeColumnFiledNames.addAll(alone);
        // 排除项excludeColumnFiledNames
        Set<String> excludeColumnFiledNames = new HashSet<String>();
        excludeColumnFiledNames.add("id");
        ExcelWriter excelWriter = null;
        try {
            WriteWorkbook writeWorkbook = new WriteWorkbook();
            writeWorkbook.setFile(new File(fileName));
            writeWorkbook.setClazz(T);
            // writeWorkbook.setHead(head(ratingYear+"年"+material.getDeptName()+"评价总体情况分析表"));
            //导出项字段
            if(includeColumnFiledNames.size() > 1){
                writeWorkbook.setIncludeColumnFieldNames(includeColumnFiledNames);
            }
            //排除项
            writeWorkbook.setExcludeColumnFieldNames(excludeColumnFiledNames);
            //是否自动关闭输入流
            writeWorkbook.setAutoCloseStream(Boolean.TRUE);
            //自定义拦截器，设置头部样式
            List<WriteHandler> customWriteHandlerList = new ArrayList<>();
            customWriteHandlerList.add(horizontalCellStyleStrategy);
            customWriteHandlerList.add(new ExcelFillCellMergeStrategy(1, mergeColumnIndex));
            writeWorkbook.setCustomWriteHandlerList(customWriteHandlerList);
            excelWriter = new ExcelWriter(writeWorkbook);
            WriteSheet writeSheet = new WriteSheet();
            writeSheet.setSheetName("sheet");
            excelWriter.write(list, writeSheet);
        } catch (Exception e) {
            e.printStackTrace();
        } finally {
            // 千万别忘记finish 会帮忙关闭流
            if (excelWriter != null) {
                excelWriter.finish();
            }
        }
    }

    public static void excludeOrIncludeWriteLoacl2(HttpServletResponse response,List<?> list, Class T, List merge, List alone,String fileName,String orgName) throws IOException {
        String fileNamePath = TestFileUtil.getPath() + "excludeOrIncludeWrite" + System.currentTimeMillis() + ".xlsx";
        //非空处理
        merge = merge == null ? new ArrayList<>() : merge;
        alone = alone == null ? new ArrayList<>() : alone;

        response.addHeader("Content-Disposition", "attachment;filename=" + System.currentTimeMillis() + ".xlsx");
        response.setContentType("multipart/form-data");
        //样式设置
        HorizontalCellStyleStrategy horizontalCellStyleStrategy = getExcelStyle1();
        //需要被合并的列
        List<Integer> mergeColumnIndex = new ArrayList<>();
        for (int i = 0; i < merge.size(); i++) {
            mergeColumnIndex.add(i);
        }
        // 导出项：includeColumnFiledNames
        Set<String> includeColumnFiledNames = new HashSet<String>();
        includeColumnFiledNames.add("number");
        includeColumnFiledNames.addAll(merge);
        includeColumnFiledNames.addAll(alone);
        // 排除项excludeColumnFiledNames
        Set<String> excludeColumnFiledNames = new HashSet<String>();
        excludeColumnFiledNames.add("id");
        ExcelWriter excelWriter = null;
        InputStream inputStream = new ClassPathResource("/static/temp/excel/"+fileName+".xlsx").getInputStream();
        try {
            String dyTime = DateTimeUtils.getDayMonthYear(new Date());
            ByteArrayOutputStream outputStream = (ByteArrayOutputStream) getInputStream(orgName,dyTime,fileName);
            ByteArrayInputStream swapStream = new ByteArrayInputStream(outputStream.toByteArray());
            WriteWorkbook writeWorkbook = new WriteWorkbook();
//            writeWorkbook.setOutputStream(response.getOutputStream());
            writeWorkbook.setFile(new File(fileNamePath));
            writeWorkbook.setClazz(T);
            writeWorkbook.setTemplateInputStream(swapStream);
            // writeWorkbook.setHead(head(ratingYear+"年"+material.getDeptName()+"评价总体情况分析表"));
            //导出项字段
            if(includeColumnFiledNames.size() > 1){
                writeWorkbook.setIncludeColumnFieldNames(includeColumnFiledNames);
            }
            //排除项
            writeWorkbook.setExcludeColumnFieldNames(excludeColumnFiledNames);
            //是否自动关闭输入流
            writeWorkbook.setAutoCloseStream(Boolean.TRUE);
            //自定义拦截器，设置头部样式
            List<WriteHandler> customWriteHandlerList = new ArrayList<>();
            customWriteHandlerList.add(horizontalCellStyleStrategy);
            customWriteHandlerList.add(new ExcelFillCellMergeStrategy(1, mergeColumnIndex));
            writeWorkbook.setCustomWriteHandlerList(customWriteHandlerList);
            excelWriter = new ExcelWriter(writeWorkbook);
            WriteSheet writeSheet = new WriteSheet();
            writeSheet.setSheetName("sheet");
            excelWriter.write(list, writeSheet);
        } catch (Exception e) {
            e.printStackTrace();
        } finally {
            // 千万别忘记finish 会帮忙关闭流
            if (excelWriter != null) {
                excelWriter.finish();
            }
        }
    }

    /**
     * 通用样式修改
     * @return
     */
    public static HorizontalCellStyleStrategy getExcelStyle() {
        // 头的策略
        WriteCellStyle headWriteCellStyle = new WriteCellStyle();
        WriteFont headWriteFont = new WriteFont();
        headWriteCellStyle.setBorderBottom(BorderStyle.THIN);
        headWriteCellStyle.setBorderTop(BorderStyle.THIN);
        headWriteCellStyle.setBorderLeft(BorderStyle.THIN);
        headWriteCellStyle.setBorderRight(BorderStyle.THIN);
        headWriteCellStyle.setFillForegroundColor(IndexedColors.WHITE.getIndex());
        //设置头字体大小
        headWriteFont.setFontHeightInPoints((short)11);
        headWriteFont.setFontName("宋体");
        headWriteFont.setBold(false);
        headWriteCellStyle.setWriteFont(headWriteFont);
        headWriteCellStyle.setHorizontalAlignment(HorizontalAlignment.CENTER);
        headWriteCellStyle.setWrapped(true);//设置自动换行


        // 内容的策略
        WriteCellStyle contentWriteCellStyle = new WriteCellStyle();
        WriteFont contentWriteFont = new WriteFont();
        // 字体大小
        contentWriteFont.setFontHeightInPoints((short)11);
        contentWriteFont.setFontName("宋体");
        //设置边框粗细
        contentWriteCellStyle.setBorderBottom(BorderStyle.THIN);
        contentWriteCellStyle.setBorderTop(BorderStyle.THIN);
        contentWriteCellStyle.setBorderLeft(BorderStyle.THIN);
        contentWriteCellStyle.setBorderRight(BorderStyle.THIN);
        //对其方式
        contentWriteCellStyle.setVerticalAlignment(VerticalAlignment.CENTER);
        contentWriteCellStyle.setWriteFont(contentWriteFont);
        // 这个策略是 头是头的样式 内容是内容的样式 其他的策略可以自己实现
        return  new HorizontalCellStyleStrategy(headWriteCellStyle, contentWriteCellStyle);

    }


    public static List<ActivityDTO> data() {
        List<ActivityDTO> list = ListUtils.newArrayList();
        list.add(new ActivityDTO("1","1","1","1","0","0","0"));
        list.add(new ActivityDTO("1","1","1","1","1","1","1"));
        list.add(new ActivityDTO("2","2","2","2","0","0","0"));
        list.add(new ActivityDTO("1","1","1","1","2","2","2"));
        return list;
    }

    /**
     *
     * @param list  导出数据集
     * @param T     导出类型
     * @param merge 需要合并列名
     * @param alone 不需要合并列名
     */
    public static void excludeOrIncludeWrite1(HttpServletResponse response,List<?> list, Class T, List merge, List alone, String fileName,String orgName) throws IOException {
        //String fileName = TestFileUtil.getPath() + "excludeOrIncludeWrite" + System.currentTimeMillis() + ".xlsx";
        //非空处理
        merge = merge == null ? new ArrayList<>() : merge;
        alone = alone == null ? new ArrayList<>() : alone;

        response.addHeader("Content-Disposition", "attachment;filename=" + System.currentTimeMillis() + ".xlsx");
        response.setContentType("multipart/form-data");
        //样式设置
        HorizontalCellStyleStrategy horizontalCellStyleStrategy = getExcelStyle1();
        //需要被合并的列
        List<Integer> mergeColumnIndex = new ArrayList<>();
        for (int i = 0; i < merge.size(); i++) {
            mergeColumnIndex.add(i);
        }
        // 导出项：includeColumnFiledNames
        Set<String> includeColumnFiledNames = new HashSet<String>();
        includeColumnFiledNames.add("number");
        includeColumnFiledNames.addAll(merge);
        includeColumnFiledNames.addAll(alone);
        // 排除项excludeColumnFiledNames
        Set<String> excludeColumnFiledNames = new HashSet<String>();
        excludeColumnFiledNames.add("id");
        ExcelWriter excelWriter = null;
        InputStream inputStream = new ClassPathResource("/static/temp/excel/"+fileName+".xlsx").getInputStream();

        try {
            String dyTime = DateTimeUtils.getDayMonthYear(new Date());
            ByteArrayOutputStream outputStream = (ByteArrayOutputStream) getInputStream(orgName,dyTime,fileName);
            ByteArrayInputStream swapStream = new ByteArrayInputStream(outputStream.toByteArray());
            WriteWorkbook writeWorkbook = new WriteWorkbook();
            writeWorkbook.setOutputStream(response.getOutputStream());
            writeWorkbook.setClazz(T);
            writeWorkbook.setTemplateInputStream(swapStream);

            // writeWorkbook.setHead(head(ratingYear+"年"+material.getDeptName()+"评价总体情况分析表"));
            //导出项字段
            if(includeColumnFiledNames.size() > 1){
                writeWorkbook.setIncludeColumnFieldNames(includeColumnFiledNames);
            }
            //排除项
            writeWorkbook.setExcludeColumnFieldNames(excludeColumnFiledNames);

            //是否自动关闭输入流
            writeWorkbook.setAutoCloseStream(Boolean.TRUE);

            //自定义拦截器，设置头部样式
            List<WriteHandler> customWriteHandlerList = new ArrayList<>();
            customWriteHandlerList.add(horizontalCellStyleStrategy);
            customWriteHandlerList.add(new ExcelFillCellMergeStrategy(1, mergeColumnIndex));
            //customWriteHandlerList.add(new CustomRowWriteHandler("你好世界","2022-12-13"));
            writeWorkbook.setCustomWriteHandlerList(customWriteHandlerList);
            excelWriter = new ExcelWriter(writeWorkbook);
            WriteSheet writeSheet = new WriteSheet();
            writeSheet.setSheetName("sheet1");
            //writeSheet.setRelativeHeadRowIndex(2);
            // 第一次写入会创建头
            excelWriter.write(list, writeSheet);

        } catch (IOException e) {
            e.printStackTrace();
        } finally {
            // 千万别忘记finish 会帮忙关闭流
            if (excelWriter != null) {
                excelWriter.finish();
            }
        }
        // 这里 需要指定写用哪个class去写，然后写到第一个sheet，名字为模板 然后文件流会自动关闭
        /*EasyExcel.write(fileName, ActivityDTO.class)
                .excludeColumnFiledNames(includeColumnFiledNames)
                .registerWriteHandler(new ExcelFillCellMergeStrategy(1,mergeColumnIndex))
                .registerWriteHandler(horizontalCellStyleStrategy)
                .sheet("sheet")
                .doWrite(data());*/
    }

    public static OutputStream getInputStream(String orgName, String time, String fileName) throws IOException {
        InputStream inputStream = new ClassPathResource("/static/temp/excel/"+fileName+".xlsx").getInputStream();
        OutputStream outputStream = new ByteArrayOutputStream();
        Map map = new HashMap();
        map.put("orgName",orgName);
        map.put("dytime",time);
        // 方案1 根据对象填充
        //String fileName1 = TestFileUtil.getPath() + "simpleFill" + System.currentTimeMillis() + ".xlsx";
        EasyExcel.write(outputStream).withTemplate(inputStream).sheet().doFill(map);
        return outputStream;
    }

    /**
     * 通用样式修改
     * @return
     */
    public static HorizontalCellStyleStrategy getExcelStyle1() {
        // 头的策略
        WriteCellStyle headWriteCellStyle = new WriteCellStyle();
        WriteFont headWriteFont = new WriteFont();
        //设置头字体大小
        headWriteFont.setFontHeightInPoints((short)11);
        headWriteFont.setBold(false);
        headWriteCellStyle.setBorderBottom(BorderStyle.THIN);
        headWriteCellStyle.setBorderTop(BorderStyle.THIN);
        headWriteCellStyle.setBorderLeft(BorderStyle.THIN);
        headWriteCellStyle.setBorderRight(BorderStyle.THIN);
        headWriteCellStyle.setFillForegroundColor(IndexedColors.WHITE.getIndex());
        headWriteCellStyle.setWriteFont(headWriteFont);
        headWriteCellStyle.setHorizontalAlignment(HorizontalAlignment.CENTER);
        headWriteCellStyle.setWrapped(true);//设置自动换行

        // 内容的策略
        WriteCellStyle contentWriteCellStyle = new WriteCellStyle();
        WriteFont contentWriteFont = new WriteFont();
        //设置边框粗细
        contentWriteCellStyle.setBorderBottom(BorderStyle.THIN);
        contentWriteCellStyle.setBorderTop(BorderStyle.THIN);
        contentWriteCellStyle.setBorderLeft(BorderStyle.THIN);
        contentWriteCellStyle.setBorderRight(BorderStyle.THIN);
        // 字体大小
        contentWriteFont.setFontHeightInPoints((short)11);
        contentWriteFont.setFontName("宋体");
        //对其方式
        contentWriteCellStyle.setHorizontalAlignment(HorizontalAlignment.CENTER);
        contentWriteCellStyle.setVerticalAlignment(VerticalAlignment.CENTER);
        contentWriteCellStyle.setWriteFont(contentWriteFont);
        contentWriteCellStyle.setWrapped(true);
        // 这个策略是 头是头的样式 内容是内容的样式 其他的策略可以自己实现
        return  new HorizontalCellStyleStrategy(headWriteCellStyle, contentWriteCellStyle);

    }

}











